@@ -175,8 +175,6 @@ OC.L10N.register(
     "Deleted user" : "Usuariu desaniciáu",
     "Unknown number" : "Númberu desconocíu",
     "%s (guest)" : "%s (convidáu)",
-    "You missed a call from {user}" : "Perdiesti una llamada de: {user}",
-    "You tried to call {user}" : "Tentesti de llamar a {user}",
     "Message of {user}" : "Mensaxe de: {user}",
     "Talk conversations" : "Conversaciones de Talk",
     "An error occurred. Please contact your administrator." : "Prodúxose un error. Ponte en contautu cola alministración.",
@@ -216,6 +214,7 @@ OC.L10N.register(
     "Answer call" : "Contestar a la llamada",
     "{user} would like to talk with you" : "{user} quier falar contigo",
     "Call back" : "Devolver la llamad",
+    "You missed a call from {user}" : "Perdiesti una llamada de: {user}",
     "Open settings" : "Abrir la configuración",
     "pending" : "pendiente",
     "error" : "error",
@@ -457,6 +456,12 @@ OC.L10N.register(
     "Zimbabwe" : "Zimbabue",
     "Federation" : "Federación",
     "High-performance backend" : "Backend de rindimientu altu",
+    "Error: Cannot connect to server" : "Error: nun pue conectar al sirvidor",
+    "Error: Certificate expired" : "Error: el certificáu caducó",
+    "Could not get version" : "Nun se pudo consiguir la versión",
+    "Error: Server responded with: {error}" : "Error: el sirvidor respondió con «{error}»",
+    "Error: Unknown error occurred" : "Error: prodúxose un error desconocíu",
+    "SIP configuration" : "Configuración de SIP",
     "Invalid date, date format must be YYYY-MM-DD" : "La data ye inválida, el so formatu ha ser AAAA-MM-DD",
     "Conversation not found" : "Nun s'atopó la converación",
     "Leave call" : "Colar de la llamada",
@@ -471,72 +476,77 @@ OC.L10N.register(
     "Save changes" : "Guardar los cambeos",
     "Saving …" : "Guardando…",
     "Saved!" : "¡Guardóse!",
+    "Description is not provided" : "Nun se fornió la descripción",
+    "Enabled" : "Activóse",
+    "Disabled" : "Desactivóse",
     "Bots settings" : "Configuración de los robós",
     "State" : "Estáu",
     "Name" : "Nome",
     "Description" : "Descripción",
     "Total errors count" : "Númberu d'errores totales",
     "Find more bots" : "Atopar más robós",
-    "Description is not provided" : "Nun se fornió la descripción",
-    "Enabled" : "Activóse",
-    "Disabled" : "Desactivóse",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
-    "General settings" : "Configuración xeneral",
     "All messages" : "Tolos mensaxes",
     "Off" : "Non",
+    "General settings" : "Configuración xeneral",
+    "Enable encryption" : "Activar el cifráu",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Active" : "Activa",
+    "Expired" : "Caducó",
     "Language" : "Llingua",
     "Country" : "País",
     "Status" : "Estáu",
     "Created at" : "Data de creación",
     "Limits" : "Llendes",
-    "Pending" : "Pendiente",
-    "Error" : "Error",
-    "Active" : "Activa",
-    "Expired" : "Caducó",
     "_%n user_::_%n users_" : ["%n usuariu","%n usuarios"],
     "Installed version: {version}" : "Versión instalada: {version}",
     "Downloading …" : "Baxando…",
     "An error occurred while installing the Matterbridge app" : "Prodúxose un error mentanto s'instalaba l'aplicación Matterbridge",
-    "Delete this server" : "Desaniciar esti sirvidor",
     "Status: Checking connection" : "Estáu: comprobando la conexón",
-    "Error: Cannot connect to server" : "Error: nun pue conectar al sirvidor",
-    "Error: Certificate expired" : "Error: el certificáu caducó",
-    "Error: Server responded with: {error}" : "Error: el sirvidor respondió con «{error}»",
-    "Error: Unknown error occurred" : "Error: prodúxose un error desconocíu",
-    "SIP configuration" : "Configuración de SIP",
+    "Delete this server" : "Desaniciar esti sirvidor",
+    "Test this server" : "Probar esti sirvidor",
     "SIP configuration saved!" : "¡Guardóse la configuración de SIP!",
     "High-performance backend URL" : "URL del backend de rindimientu altu",
-    "Could not get version" : "Nun se pudo consiguir la versión",
     "High-performance backend settings saved" : "Guardóse la configuración del backend de rindimientu altu",
     "STUN server URL" : "URL del sirvidor STUN",
     "The server address is invalid" : "La direición del sirvidor ye inválida",
-    "STUN servers" : "Sirvidores STUN",
     "STUN settings saved" : "Guardóse la configuración STUN",
+    "STUN servers" : "Sirvidores STUN",
+    "{option1} and {option2}" : "{option1} y {option2}",
     "TURN server URL" : "URL de sirvidor TURN",
     "TURN server secret" : "Secretu del sirvidor TURN",
     "TURN server protocols" : "Protocolos del sirvidor TURN",
-    "{option1} and {option2}" : "{option1} y {option2}",
-    "Test this server" : "Probar esti sirvidor",
-    "TURN servers" : "Sirvidores TURN",
     "TURN settings saved" : "Guardóse la configuración de TURN",
+    "TURN servers" : "Sirvidores TURN",
     "Failed" : "Falló",
     "OK" : "Normal",
     "Checking …" : "Comprobando…",
     "Federated user" : "Usuariu federáu",
-    "Back" : "Atrás",
-    "Cancel" : "Encaboxar",
     "Confirm" : "Confirmar",
     "Reset" : "Reafitar",
     "Room {roomNumber}" : "Sala {roomNumber}",
+    "Back" : "Atrás",
+    "Cancel" : "Encaboxar",
+    "Now" : "Agora",
+    "Loading …" : "Cargando…",
+    "No upcoming events" : "Nun hai eventos próximos",
+    "From" : "De",
+    "To" : "Pa",
+    "Calendar" : "Calendariu",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "Nun hai nengún resultáu",
+    "Done" : "Fecho",
     "This conversation is read-only" : "Esta conversación ye namás de llectura",
     "{nickName} raised their hand." : "«{nickName}» alzo la mano",
     "A participant raised their hand." : "Un participante alzó la mano.",
     "Previous page of videos" : "Páxina de vídeos anterior",
     "Next page of videos" : "Páxina de vídeos siguiente",
-    "Copy link" : "Copiar l'enllaz",
     "Connecting …" : "Conectando…",
     "Calling …" : "Llamando…",
+    "Copy link" : "Copiar l'enllaz",
     "Error while accessing camera" : "Hebo un error mentanto s'accedía a la cámara",
     "You are not allowed to enable video" : "Nun tienes permisu p'activar el videu",
     "No video. Click to select device" : "Nun hai videu. Calca pa seleicionar un preséu",
@@ -546,29 +556,28 @@ OC.L10N.register(
     "Show screen" : "Amosar la pantalla",
     "Collapse" : "Recoyer",
     "Expand" : "Espander",
-    "Conversation messages" : "Mensaxes de la conversación",
-    "Post message" : "Espublizar el mensaxe",
     "You need to be logged in to upload files" : "Tienes d'aniciar la sesión pa xubir ficheros",
     "Drop your files to upload" : "Suelta los ficheros pa xubilos",
-    "Favorite" : "Meter en Favoritos",
+    "Conversation messages" : "Mensaxes de la conversación",
+    "Post message" : "Espublizar el mensaxe",
     "Federated conversation" : "Conversación federada",
     "Public conversation" : "Conversación pública",
-    "Loading …" : "Cargando…",
+    "Favorite" : "Meter en Favoritos",
+    "Date:" : "Data:",
     "Hide details" : "Anubrir los detalles",
     "Show details" : "Amosar los detalles",
-    "Date:" : "Data:",
+    "Error while updating conversation name" : "Hebo un error mentanto s'anovaba'l nome de la conversación",
+    "Error while updating conversation description" : "Hebo un error mentanto s'anovaba la descripción de la conversación",
     "Enter a name for this conversation" : "Introduz un nome pa esta conversación",
     "Edit conversation name" : "Editar el nome de la conversación",
     "Edit conversation description" : "Editar la descripción de la conversación",
     "Enter a description for this conversation" : "Introduz una descripción pa esta conversación",
     "Picture" : "Semeya",
-    "Error while updating conversation name" : "Hebo un error mentanto s'anovaba'l nome de la conversación",
-    "Error while updating conversation description" : "Hebo un error mentanto s'anovaba la descripción de la conversación",
     "Disable" : "Desactivar",
     "Enable" : "Activar",
-    "The file must be a PNG or JPG" : "El ficheru a ser PNG o JPG",
     "Choose" : "Escoyer",
     "Error removing conversation picture" : "Hebo un error al quitar la semeya de la conversación",
+    "The file must be a PNG or JPG" : "El ficheru a ser PNG o JPG",
     "All permissions" : "Tolos permisos",
     "Restricted" : "Restrinxóse",
     "Advanced permissions" : "Permisos avanzaos",
@@ -578,6 +587,8 @@ OC.L10N.register(
     "Matterbridge" : "Matterbridge",
     "Bots" : "Robós",
     "Danger zone" : "Zona de peligru",
+    "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
+    "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
     "Be careful, these actions cannot be undone." : "Ten curiáu, estes aiciones nun se puen desfacer.",
     "Leave conversation" : "Colar de la conversación",
     "No" : "Non",
@@ -585,159 +596,151 @@ OC.L10N.register(
     "Delete conversation" : "Desaniciar la conversación",
     "Delete chat messages" : "Desaniciar los mensaxes de la charra",
     "Delete all chat messages" : "Desaniciar los mensaxes de toles charres",
-    "Error while deleting conversation" : "Hebo un error mentanto se desaniciaba la conversación",
-    "Error while clearing chat history" : "Hebo un error mentanto se borraba l'historial de la charra",
-    "Message expiration" : "Caducidá de los mensaxes",
-    "Error when trying to set message expiration" : "Hebo un error al tentar d'afitar la caducidá de los mensaxes",
     "_%n hour_::_%n hours_" : ["%n hora","%n hores"],
     "_%n day_::_%n days_" : ["%n día","%n díes"],
     "_%n week_::_%n weeks_" : ["%n selmana","%n selmanes"],
+    "Error when trying to set message expiration" : "Hebo un error al tentar d'afitar la caducidá de los mensaxes",
+    "Message expiration" : "Caducidá de los mensaxes",
     "Password protection" : "Proteición con contraseña",
     "Enter new password" : "Introduz una contraseña nueva",
     "Save password" : "Guardar la contraseña",
-    "Copy conversation link" : "Copiar l'enllaz de la conversación",
-    "Open conversation" : "Abrir la conversación",
     "This conversation is open to registered users" : "Esta conversación ta abierta a los usuarios rexistraos",
     "This conversation is limited to the current participants" : "Esta conversación ta llendada a los participantes actuales",
     "Error occurred when opening or limiting the conversation" : "Prodúxose un error al abrir o llendar la conversación",
+    "Open conversation" : "Abrir la conversación",
     "Error occurred while updating start time" : "Prodúxose un error mentanto s'anovaba la hora de comienzu",
-    "Lock conversation" : "Bloquiar la conversación",
-    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquia la conversación pa impidir que naide espublice mensaxes o anicie llamaes",
     "Error occurred when locking the conversation" : "Prodúxose un error mentanto se bloquiaba la conversación",
     "Error occurred when unlocking the conversation" : "Prodúxose un error mentanto se desbloquiaba la conversación",
-    "Save" : "Guardar",
+    "Lock conversation" : "Bloquiar la conversación",
+    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquia la conversación pa impidir que naide espublice mensaxes o anicie llamaes",
     "Edit" : "Editar",
     "More information" : "Más información",
     "Delete" : "Desaniciar",
-    "Messaging systems" : "Sistemes de mensaxería",
-    "Enable bridge" : "Activar la ponte",
-    "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
-    "Log content" : "Conteníu del rexistru",
     "unknown state" : "estáu desonocíu",
     "running" : "n'execución",
     "not running" : "nun ta n'execución",
     "Bridge saved" : "Guardóse la ponte",
+    "Messaging systems" : "Sistemes de mensaxería",
+    "Enable bridge" : "Activar la ponte",
+    "Show Matterbridge log" : "Amosar el rexistru de Matterbridge",
+    "Log content" : "Conteníu del rexistru",
     "Notifications" : "Avisos",
-    "Login" : "Aniciar la sesión",
-    "Creating the conversation …" : "Creando la conversación…",
+    "Log in" : "Aniciar la sesión",
     "An error occurred while calling a phone number" : "Prodúxose un error mentanto se llamaba a un númberu de teléfonu",
     "Phone number could not be called: {error}" : "Nun se pudo llamar al númberu de teléfonu: {error}",
     "Phone number could not be called" : "Nun se pudo llamar al númberu de teléfonu",
+    "Creating the conversation …" : "Creando la conversación…",
     "Remove from favorites" : "Quitar de Favoritos",
     "Add to favorites" : "Meter en Favoritos",
     "Pending invitations" : "Invitaciones pendientes",
     "Decline invitation" : "Refugar la invitación",
     "Accept invitation" : "Aceptar la invitación",
     "No pending invitations" : "Nun hai nenguna invitación pendiente",
-    "Conversation list" : "Llista de conversaciones",
-    "New personal note" : "Nota personal nueva",
-    "Unread mentions" : "Menciones ensin lleer",
     "No matches found" : "Nun s'atopó nenguna coincidencia",
-    "Open conversations" : "Abrir les conversaciones",
-    "Users" : "Usuarios",
-    "New private conversation" : "Conversación privada nueva",
-    "Groups" : "Grupos",
-    "Teams" : "Equipos",
-    "Federated users" : "Usuarios federaos",
-    "No search results" : "Nun hai nengún resultáu de la busca",
-    "Loading" : "Cargando",
-    "Talk settings" : "Configuración de Talk",
     "No conversations found" : "Nun s'atopó nenguna conversación",
     "You have no unread mentions." : "Nun tienes nenguna mención ensin lleer.",
     "You have no unread messages." : "Nun tienes nengún mensaxe ensin lleer.",
     "Users, groups and teams" : "Usuarios, grupos y equipos",
     "Users and groups" : "Usuarios y grupos",
     "Users and teams" : "Usuarios y equipos",
+    "Users" : "Usuarios",
     "Groups and teams" : "Grupos y equipos",
+    "Groups" : "Grupos",
+    "Teams" : "Equipos",
     "Other sources" : "Otros oríxenes",
     "An error occurred while performing the search" : "Prodúxose un error mentanto se facía la busca",
+    "Conversation list" : "Llista de conversaciones",
+    "New personal note" : "Nota personal nueva",
+    "Unread mentions" : "Menciones ensin lleer",
+    "Open conversations" : "Abrir les conversaciones",
+    "New private conversation" : "Conversación privada nueva",
+    "Federated users" : "Usuarios federaos",
+    "No search results" : "Nun hai nengún resultáu de la busca",
+    "Talk settings" : "Configuración de Talk",
     "You are currently waiting in the lobby" : "Tas na sala d'espera",
+    "None" : "Nada",
     "No microphone available" : "Nun hai nengún micrófonu disponible",
     "No camera available" : "Nun hai nenguna cámara disponible",
-    "None" : "Nada",
+    "Devices" : "Preseos",
+    "Backgrounds" : "Fondos",
     "Media settings" : "Configuración multimedia",
     "The call is being recorded." : "La llamada ta grabándose",
     "Normal call" : "Llamada normal",
-    "Devices" : "Preseos",
-    "Backgrounds" : "Fondos",
+    "Invalid path selected" : "Seleicionóse un camín inválidu",
     "Blur" : "Emborrinar",
     "Upload" : "Xunir",
     "Files" : "Ficheros",
-    "Invalid path selected" : "Seleicionóse un camín inválidu",
-    "Unread messages" : "Mensaxes ensin lleer",
     "Message sent" : "Unvióse'l mensaxe",
     "Deleting message" : "Desaniciando'l mensaxe",
     "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
-    "Reply" : "Responder",
-    "Set reminder" : "Configurar un recordatoriu",
-    "Reply privately" : "Responder per privao",
-    "Edit message" : "Editar el mensaxe",
-    "Copy formatted message" : "Copiar el mensaxe con formatu",
-    "Copy message link" : "Copiar l'enllaz del mensaxe",
-    "Go to file" : "Dir al ficheru",
-    "Translate" : "Traducir",
-    "Close reactions menu" : "Zarrar el menú de les reaiciones",
+    "Unread messages" : "Mensaxes ensin lleer",
+    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
+    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
+    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
     "Message text copied to clipboard" : "El testu del mensaxe copióse nel cartafueyu",
     "Message text could not be copied" : "El testu del mensaxe nun se pudo copiar",
     "A reminder was successfully removed" : "El recordatoriu quitóse correutamente",
     "Error occurred when removing a reminder" : "Prodúxose un error al quitar un recordatoriu",
     "Error occurred when creating a reminder" : "Prodúxose un error al crear un recordatoriu",
+    "Reply" : "Responder",
+    "Set reminder" : "Configurar un recordatoriu",
+    "Reply privately" : "Responder per privao",
+    "Edit message" : "Editar el mensaxe",
+    "Copy message link" : "Copiar l'enllaz del mensaxe",
+    "Go to file" : "Dir al ficheru",
+    "Translate" : "Traducir",
+    "Close reactions menu" : "Zarrar el menú de les reaiciones",
     "Dismiss" : "Escartar",
     "Go to conversation" : "Dir a la conversación",
-    "Translate message" : "Traducir el mensaxe",
-    "Translating" : "Traduciendo",
-    "Copy translated text" : "Copiar el testu traducíu",
     "The message could not be translated" : "Nun se pudo traducir el mensaxe",
     "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
     "Translation could not be copied" : "Nun se pudo copiar la traducción",
+    "Translate message" : "Traducir el mensaxe",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar el testu traducíu",
     "Contact" : "Contautu",
-    "Copy code block" : "Copiar el bloque de códigu",
     "Sending message" : "Unviando'l mensaxe",
     "Not enough free space to upload file" : "Nun hai abondu espaciu llibre pa xubir el ficheru",
     "You are not allowed to share files" : "Nun tienes permisu pa compartir ficheros",
     "You cannot send messages to this conversation at the moment" : "Pel momentu, nun pues unviar mensaxes a esta conversación",
     "Code block copied to clipboard" : "El bloque de códigu copióse nel cartafueyu",
     "Code block could not be copied" : "Nun se pudo copiar el bloque de códigu",
-    "Poll" : "Encuesta",
-    "See results" : "Ver los resultaos",
+    "Copy code block" : "Copiar el bloque de códigu",
     "Open poll • You voted already" : "Encuesta abierta • Yá votesti",
     "Open poll • Click to vote" : "Encuesta abierta • Calca pa votar",
     "Poll • Ended" : "Encuesta • Finó",
+    "Poll" : "Encuesta",
+    "See results" : "Ver los resultaos",
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
     "Reactions" : "Reaiciones",
-    "No messages" : "Nun hai nengún mensaxe",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
     "A week ago" : "Hai una selmana",
     "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
+    "No messages" : "Nun hai nengún mensaxe",
+    "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
     "Create conversation" : "Crear una conversación",
     "Add participants" : "Amestar participantes",
-    "Close" : "Zarrar",
-    "Error while creating the conversation" : "Hebo un error mentanto se creaba la conversación",
     "Conversation visibility" : "Visibilidá de la conversación",
-    "Add emoji" : "Amestar un fustaxe",
     "This conversation has been locked" : "Bloquióse esta conversación",
     "Send message" : "Unviar el mensaxe",
     "Send without notification" : "Unviar ensin avisar",
     "The message could not be edited" : "Nun se pudo editar el mensaxe",
     "File upload is not available in this conversation" : "La xuba de ficheros nun ta disponible nesta conversación",
+    "Add emoji" : "Amestar un fustaxe",
     "Smart picker" : "Selector intelixente",
-    "Name of the new file" : "Nome del ficheru nuevu",
     "New file" : "Ficheru nuevu",
     "Blank" : "Baleru",
     "Error while creating file" : "Hebo un error mentanto se creaba'l ficheru",
-    "Question" : "Entruga",
-    "Ask a question" : "Entrugar",
-    "Answers" : "Rempuestes",
-    "Settings" : "Configuración",
-    "Anonymous poll" : "Encuesta anónima",
-    "Create poll" : "Crear una encuesta",
+    "Name of the new file" : "Nome del ficheru nuevu",
     "{user1} is typing …" : "{user1} ta escribiendo…",
     "{user1} and {user2} are typing …" : "{user1} y {user2} tán escribiendo…",
     "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} y {user3} tán escribiendo…",
-    "Send" : "Unviar",
+    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} y %n más tán escribiendo…","{user1}, {user2}, {user3} y %n más tán escribiendo…"],
     "Add more files" : "Amestar más ficheros",
+    "Send" : "Unviar",
+    "In this conversation <strong>{user}</strong> can:" : "Nesta conversión, <strong>{user}</strong> pue:",
     "Start a call" : "Aniciar una llamada",
     "Skip the lobby" : "Saltar la sala d'espera",
     "Enable the microphone" : "Activar el micrófonu",
@@ -745,18 +748,23 @@ OC.L10N.register(
     "Share the screen" : "Compartir la pantalla",
     "Update permissions" : "Anovar los permisos",
     "Updating permissions" : "Anovando los permisos",
-    "In this conversation <strong>{user}</strong> can:" : "Nesta conversión, <strong>{user}</strong> pue:",
+    "Create poll" : "Crear una encuesta",
+    "Question" : "Entruga",
+    "Ask a question" : "Entrugar",
+    "Answers" : "Rempuestes",
+    "Settings" : "Configuración",
+    "Anonymous poll" : "Encuesta anónima",
+    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultaos de la encuesta • %n votu","Resultaos de la encuesta • %n votos"],
+    "Open poll" : "Abrir la encuesta",
     "You voted for this option" : "Votesti esta opción",
     "Submit vote" : "Unviar el votu",
     "Change your vote" : "Cambiar el votu",
     "End poll" : "Finar la encuesta",
-    "Open poll" : "Abrir la encuesta",
-    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultaos de la encuesta • %n votu","Resultaos de la encuesta • %n votos"],
     "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
-    "Join" : "Xunise",
     "Send a message to \"{roomName}\"" : "¿Quies unviar un mensaxe a «{roomName}»?",
     "Show list of participants" : "Amosar la llista de participantes",
     "The message was sent to \"{roomName}\"" : "El mensaxe unvióse a «{roomName}»",
+    "Join" : "Xunise",
     "Back to main room" : "Volver a la sala principal",
     "Message all rooms" : "Xestionar toles sales",
     "Start session" : "Aniciar la sesión",
@@ -765,69 +773,66 @@ OC.L10N.register(
     "moderator" : "moderador",
     "bot" : "robó",
     "guest" : "convidáu",
+    "Ringing …" : "Sonando…",
+    "Raised their hand" : "Alzó la mano",
     "in the lobby" : "na sala",
     "Resend invitation" : "Volver unviar la invitación",
     "Copy phone number" : "Copiar el númberu de teléfonu",
     "Grant all permissions" : "Conceder tolos permisos",
     "Remove all permissions" : "Quitar tolos permisos",
     "Remove" : "Quitar",
-    "Ringing …" : "Sonando…",
-    "Raised their hand" : "Alzó la mano",
-    "Add users" : "Amestar usuarios",
-    "Add groups" : "Amestar grupos",
-    "Add emails" : "Amestar direiciones de corréu electróniques",
-    "Add teams" : "Amestar equipos",
-    "Integrations" : "Integraciones",
-    "Add federated users" : "Amestar usuarios federaos",
-    "Searching …" : "Buscando…",
-    "No results" : "Nun hai nengún resultáu",
-    "Search for more users" : "Buscar más usuarios",
     "Add users, groups or teams" : "Amestar usuarios, grupos o equipos",
     "Add users or groups" : "Amestar usuarios o grupos",
     "Add users or teams" : "Amestar usuarios o equipos",
+    "Add users" : "Amestar usuarios",
     "Add groups or teams" : "Amestar grupos o equipos",
+    "Add groups" : "Amestar grupos",
+    "Add teams" : "Amestar equipos",
     "Add other sources" : "Amestar otra fonte",
-    "Participants" : "Participantes",
+    "Add emails" : "Amestar direiciones de corréu electróniques",
+    "Integrations" : "Integraciones",
+    "Add federated users" : "Amestar usuarios federaos",
+    "Searching …" : "Buscando…",
+    "Search for more users" : "Buscar más usuarios",
     "Search or add participants" : "Buscar o amestar participantes",
     "An error occurred while adding the participants" : "Prodúxose un error mentanto s'amestaben los participantes",
-    "Chat" : "Charra",
-    "Details" : "Detalles",
-    "Shared items" : "Elementos compartíos",
+    "Participants" : "Participantes",
     "Participants ({count})" : "Participantes ({count})",
     "Open chat" : "Abrir la charra",
     "You have new unread messages in the chat." : "Tienes mensaxes ensin lleer nuevos na charra.",
     "You have been mentioned in the chat." : "Mentáronte na charra.",
+    "Chat" : "Charra",
+    "Details" : "Detalles",
+    "Shared items" : "Elementos compartíos",
+    "No results found" : "Nun s'atopó nengún resultáu",
+    "Load more results" : "Cargar más resultaos",
     "Projects" : "Proyeutos",
     "No shared items" : "Nun hai nengún elementu compartíu",
     "No open conversations found" : "Nun s'atopó nenguna conversación abierta",
-    "Phone numbers" : "Númberos de teléfonu",
     "Number is not valid" : "El númberu nun ye válidu",
+    "Phone numbers" : "Númberos de teléfonu",
     "Save name" : "Guardar el nome",
-    "Display name: {name}" : "Nome visible: {name}",
     "Calls are not supported in your browser" : "Les llamaes nun son compatible col sirvidor",
     "Access to microphone is only possible with HTTPS" : "L'accesu al micrófonu namás ye posible con HTTPS",
     "Access to microphone was denied" : "Negóse l'accesu al micrófonu",
     "Error while accessing microphone" : "Hebo un error mentanto s'accedía al micrófonu",
     "Access to camera is only possible with HTTPS" : "L'accesu a la cámara namás ye posible con HTTPS",
+    "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
+    "Sounds setting saved" : "Guardóse la configuración de los soníos",
+    "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
     "Browse …" : "Restolar…",
+    "Appearance" : "Aspeutu",
     "Privacy" : "Privacidá",
     "Sounds" : "Soníos",
     "Performance" : "Rindimientu",
     "Keyboard shortcuts" : "Atayos del tecláu",
     "Search" : "Buscar",
     "Space bar" : "Barra d'espaciu",
-    "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
-    "Sounds setting saved" : "Guardóse la configuración de los soníos",
-    "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
     "Start call" : "Aniciar la llamada",
     "End call" : "Finar la llamada",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada.",
     "Stop recording" : "Parar la grabación",
     "Send a reaction" : "Unviar una reaición",
-    "Now" : "Agora",
     "_%n participant in call_::_%n participants in call_" : ["%n participante na llamada","%n participantes na llamada"],
-    "Show your screen" : "Amosar la to pantalla",
-    "Stop screensharing" : "Dexar de compartir la pantalla",
     "You are not allowed to enable screensharing" : "Nun tienes permisu p'activar la compartición de pantalla",
     "Screensharing options" : "Opciones de la compartición de pantalla",
     "Enable screensharing" : "Activar la compartición de pantalla",
@@ -841,9 +846,11 @@ OC.L10N.register(
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, prueba a desactivar el desenfoque del fondu.",
     "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete y vete. P'ameyorar esta situación, prueba a desactivar el videu.",
     "Your internet connection or computer are busy and other participants might be unable to understand you." : "La conexón a internet o l'ordenador tán ocupaos y ye probable que los demás participantes nun seyan entendete.",
-    "Start recording" : "Aniciar la grabación",
+    "Show your screen" : "Amosar la to pantalla",
+    "Stop screensharing" : "Dexar de compartir la pantalla",
     "Raise hand" : "Alzar la mano",
     "Lower hand" : "Baxar la mano",
+    "Start recording" : "Aniciar la grabación",
     "Open dialpad" : "Abrir el tecláu numbéricu",
     "Submit" : "Unviar",
     "Search …" : "Buscar…",
@@ -852,9 +859,7 @@ OC.L10N.register(
     "Join a conversation or start a new one!" : "¡Xúnite una conversación o anicia una nueva!",
     "Duplicate session" : "Duplicar la sesión",
     "Join a conversation or start a new one" : "Xúnite a una conversación o anicia otra",
-    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
-    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
+    "Display name: {name}" : "Nome visible: {name}",
     "Nextcloud URL" : "URL de Nextcloud",
     "Nextcloud user" : "Usuariu de Nextcloud",
     "Talk conversation" : "Conversación de Talk",
@@ -872,8 +877,8 @@ OC.L10N.register(
     "API token" : "Pase de l'API",
     "Slack channel" : "Canal de Slack",
     "Server ID or name" : "ID o nome del sirvidor",
-    "Channel ID or name" : "ID o nome de la canal",
     "Channel" : "Canal",
+    "Login" : "Aniciar la sesión",
     "Chat ID" : "ID de la charra",
     "Nickname" : "Nomatu",
     "Connection password" : "Contraseña de la conexón",
@@ -897,11 +902,11 @@ OC.L10N.register(
     "Show all voice messages" : "Amosar tolos mensaxe de voz",
     "Show all locations" : "Amosar tolos llugares",
     "Group" : "Grupu",
+    "Team" : "Equipu",
     "You and {user0} left the call" : "Tu y {user0} colestis de la canal",
     "You: {lastMessage}" : "Tu: {lastMessage}",
     "(edited)" : "(editóse)",
     "In conversation" : "Na conversación",
-    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
     "Error while clearing conversation history" : "Hebo un error mentanto se borraba l'historial de la conversación",
     "Error occurred while allowing guests" : "Prodúxose un error mentanto se permitíen a los convidaos",
     "Conversation password has been saved" : "Guardóse la contraseña de la conversación",
@@ -910,6 +915,7 @@ OC.L10N.register(
     "Could not delete the conversation picture" : "Nun se pudo desaniciar la semeya de la conversación",
     "Error while uploading file \"{fileName}\"" : "Hebo un error mentanto se xubía'l ficheru «{fileName}»",
     "Not enough free space to upload file \"{fileName}\"" : "Nun hai abondu espaciu pa xubir el ficheru «{fileName}»",
+    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
     "Could not post message: {errorMessage}" : "Nun se pudo espublizar el mensaxe: {errorMessage}",
     "Invitations sent" : "Unviáronse les invitaciones",
     "Error occurred when sending invitations" : "Prodúxose un error mentanto s'unviaben les conversaciones",
@@ -925,6 +931,7 @@ OC.L10N.register(
     "_In %n minute_::_In %n minutes_" : ["En %n minutu","En %n minutos"],
     "Conversation link copied to clipboard" : "L'enllaz de la conversación copióse nel cartafueyu",
     "The link could not be copied" : "Nun se pudo copiar l'enllaz",
+    "Please reload the page." : "Volvi cargar la páxina.",
     "Do not disturb" : "Nun molestar",
     "Away" : "Ausente",
     "Default" : "Por defeutu",
@@ -936,27 +943,26 @@ OC.L10N.register(
     "The password is wrong. Try again." : "La contraseña ye incorreuta. Volvi tentalo.",
     "Android app" : "Aplicación p'Android",
     "iOS app" : "Aplicación pa iOS",
+    "__language_name__" : "Asturianu",
+    "Call summary (%s)" : "Resume de llamaes (%s)",
+    "Tasks" : "Xeres",
+    "Notes" : "Notes",
+    "Reports" : "Informes",
+    "Call summary" : "Resume de llamaes",
     "The command does not exist" : "El comandu nun esiste",
     "An error occurred while running the command. Please ask an administrator to check the logs." : "Prodúxose un error mentanto s'executaba'l comandu. Pidi a l'alministración que compruebe los rexistros.",
-    "{actor} added circle {circle}" : "{actor} amestó'l círculu «{circle}»",
-    "You added circle {circle}" : "Amestesti'l círculu «{circle}»",
-    "An administrator added circle {circle}" : "L'alministración amestó'l círculu «{circle}»",
-    "{actor} removed circle {circle}" : "{actor} quitó'l círculu «{circle}»",
-    "You removed circle {circle}" : "Quitesti'l círculu «{circle}»",
-    "An administrator removed circle {circle}" : "L'alministración quitó'l círculu «{circle}»",
-    "More unread mentions" : "Más menciones ensin lleer",
+    "You tried to call {user}" : "Tentesti de llamar a {user}",
+    "Moderators" : "Moderadores",
     "Commands" : "Comandos",
     "Command" : "Comandu",
     "Script" : "Script",
-    "Moderators" : "Moderadores",
     "The message could not be sent" : "Nun se pudo unviar el mensaxe",
-    "Delete Conversation" : "Desaniciar la conversación",
-    "Circles" : "Círculos",
-    "Users, groups and circles" : "Usuarios, grupos y círculos",
-    "Users and circles" : "Usuarioa de círculos",
-    "Groups and circles" : "Grupos y círculos",
+    "Copy conversation link" : "Copiar l'enllaz de la conversación",
+    "Channel ID or name" : "ID o nome de la canal",
+    "Loading" : "Cargando",
+    "Close" : "Zarrar",
     "Private poll" : "Encuesta privada",
-    "Start a conversation" : "Aniciar una conversación",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Anovóse Nextcloud Talk. Tienes de volver cargar la páxina enantes de poder aniciar o xunite a una llamada.",
     "TURN server" : "Sirividor TURN"
 },
 "nplurals=2; plural=(n != 1);");
