@@ -15,7 +15,6 @@ OC.L10N.register(
     "Other activities" : "Oberiantizoù all",
     "Talk" : "Komz",
     "Guest" : "Kouviad",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Donemat war Nextcloud Talk !\nEn diviz-mañ e voc'h kemenet diwar-benn perzhioù nevez a kavoc'h e Nextcloud Talk.",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Micosoft Edge ha Safari a zo posupl implij evit ar gemenadenoù audio a video",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Posupl eo deoc'h gervel tout en dud en diviz en ur skrivañ \"@all\" er chat",
     "- With the \"arrow-up\" key you can repost your last message" : " -Gant an douchenn \"bir-a-uz\" en posupl adkas ar gemenadenn divezhañ",
@@ -29,9 +28,6 @@ OC.L10N.register(
     "- Check out the new grid and call view" : "- Sellit ouzh ar rouedad ha kemener nevez",
     "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Posuple eo deoc'h pelkas ha ruzañ-lakaat restroù diozhtu eus o ardivink er chat",
     "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Restrom rannet a vez igoret diozhtu er chat gant ar lenner maziant",
-    "There are currently no commands available." : "N'ez us linenn urzh ebet evit ar poent",
-    "The command does not exist" : "N'ez eus ket eyus an urzh",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ur fazi a zo bet en ur ober an urzh. Goulennit d'ar merour da sellet ouzh ar gazetenn.",
     "Talk updates ✅" : "Adnevesaden Talk ✅",
     "{actor} created the conversation" : "{actor} en deus krouet an diviz",
     "You created the conversation" : "Krouet o peus an diviz",
@@ -39,8 +35,8 @@ OC.L10N.register(
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} en deus adenvet an diviz eus \"%1$s\" da \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Adenvet o peus an diviz eus \"%1$s\" da \"%2$s\"",
     "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ar merour en deus adenvet an diviz eus \"%1$s\" da \"%2$s\"",
-    "{actor} started a call" : "{actor} en deus kroget ur gemenadenn",
     "You started a call" : "Kroget o peus ur gemenadenn",
+    "{actor} started a call" : "{actor} en deus kroget ur gemenadenn",
     "{actor} joined the call" : "{actor} a zo deuet er gemenadenn",
     "You joined the call" : "Deuet oc'h er gemenaden",
     "{actor} left the call" : "{actor} en deus kuitaet ar gemenadenn",
@@ -95,12 +91,6 @@ OC.L10N.register(
     "{actor} shared a file which is no longer available" : "Restr rannet {actor} n'eo ket posupl kavout kenn",
     "You shared a file which is no longer available" : "Ar restr o peus rannet n'eo ket posupl kavout kenn",
     "%s (guest)" : "%s (kouviat)",
-    "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
     "Talk to %s" : "Komz da %s",
     "File is not shared, or shared but not with the user" : "N'eo ket rannet ar restr, pe n'eo ket rannet gan an implijour",
     "No account available to delete." : "N'ez eus kont ebet da lemel",
@@ -109,6 +99,8 @@ OC.L10N.register(
     "Invalid image" : "N'eo ket aotreet ar skeudenn",
     "Unknown filetype" : "N'eo ket anavezet stumm ar restr",
     "Talk mentions" : "Menegoù Talk",
+    "Say hi to your friends and colleagues!" : "Lâr koukouk d'ho mignoned ha genseurted",
+    "No unread mentions" : "Kemenadenn nan-lennet ebet",
     "Call in progress" : "Kemenadenn en dro",
     "You were mentioned" : "Meneget oc'h bet",
     "Write to conversation" : "Skrivañ d'an diviz",
@@ -122,6 +114,7 @@ OC.L10N.register(
     "Private conversation" : "Diviz prevez",
     "Deleted user (%s)" : "Lemel implijour (%s)",
     "Dismiss notification" : "Arrest ar gemenadennoù",
+    "Accept" : "Asantiñ",
     "{user} in {call}" : "{user} e {call}",
     "Deleted user in {call}" : "Lemel implijer e {call}",
     "{guest} (guest) in {call}" : "{guest} (kouviad) e {call}",
@@ -147,6 +140,7 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} e deus kouviet ac'hnoc'h d'ur strolat diviz : {call}",
     "Answer call" : "Respont d'ar gemenadenn",
     "Call back" : "adober ur gemenadenn",
+    "You missed a call from {user}" : "C'hwitet o peus ur gemenadenn eus {user}",
     "A group call has started in {call}" : "Ur gemenadenn strollat a zo kroget e {call}",
     "You missed a group call in {call}" : "C'hwitet ho peus ur gemenadenn strollat e {call}",
     "{email} is requesting the password to access {file}" : "{email} a goulenn ar ger-tremen evit tizout {restr}",
@@ -157,10 +151,10 @@ OC.L10N.register(
     "The hosted signaling server is now configured and will be used." : "Ar servijour kemenn ostet a zo stummet hag a vo implijet bremañ.",
     "The hosted signaling server was removed and will not be used anymore." : "Lamet eo bet ar servijour kemenn ostet ha ne vo ket implijet kenn.",
     "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Ar servijour kemenn ostet en deus cheñchet eus \"{oldstatus}\" da \"{newstatus}\".",
+    "error" : "fazi",
     "Conversations" : "Diviz",
-    "Messages" : "Kemenadennoù",
     "{user}" : "{user}",
-    "Messages in {conversation}" : "Kemenadennoù e {conversation}",
+    "Messages" : "Kemenadennoù",
     "{user} in {conversation}" : "{user} e {conversation}",
     "Messages in other conversations" : "Kemenadennoù e divizoù all",
     "Failed to request trial because the trial server is unreachable. Please try again later." : "C'hwitet eo bet goulenn an arnodenn, abalamour ne vez ket tizet ar servijour anodañ. klaskit en dro diwezatoc'h.",
@@ -435,14 +429,17 @@ OC.L10N.register(
     "South Africa" : "Suafrika",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Kevread",
+    "High-performance backend" : "Backend a labour buhan",
+    "Error: Server did not respond with proper JSON" : "Fazi : N'eo ket posupl respont gant ur JSON mat",
+    "Error: Server responded with: {error}" : "Fazi : Respont a ra ar servijour gant : {error}",
+    "Error: Unknown error occurred" : "Fazi : Ur fazi dianv a zo bet",
     "Invalid date, date format must be YYYY-MM-DD" : "Deizat fall, stumm an deizat a zo ret bezhañ BBBB-MM-DD",
     "Conversation not found" : "N'eo ket bet kavet an diviz",
-    "Path is already shared with this room" : "An hent a zo dihja bet rannet gant ar sal",
     "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-prezegenn gant WebRTC",
     "Navigating away from the page will leave the call in {conversation}" : "Kuitat ar bajenn a laosko ar pelgomzadenn e {convzersation}",
     "Leave call" : "Kuitat ar gemenadenn",
     "Stay in call" : "Chom er gemenadenn",
-    "Duplicate session" : "Eilan dalc'h",
     "Discuss this file" : "Komz diwar benn ar restr-mañ",
     "Share this file with others to discuss it" : "Rannañ ar restr-mañ da reoù all evit komz diwar e-benn",
     "Share this file" : "Rannañ ar restr",
@@ -450,6 +447,12 @@ OC.L10N.register(
     "Request password" : "Goulenn ar -ger-tremen",
     "Error requesting the password." : "Ur fazi a zo bet en ur gouelenn ar ger-tremen",
     "This conversation has ended" : "Echu ei an diviz-mañ",
+    "Everyone" : "Toud an dud",
+    "Users and moderators" : "Implijourien ha habaskaerienn",
+    "Moderators only" : "Habaskerienn nemetken",
+    "Save changes" : "Enrollañ ar cheñchamantoù",
+    "Saving …" : "Orc'h enrolliñ",
+    "Saved!" : "Enrollet !",
     "Limit to groups" : "Nemet d'ar strolladoù",
     "When at least one group is selected, only people of the listed groups can be part of conversations." : "M'az eo choazet ur strollad d'an neubetañ, ne vo nemet tud ar strollad en diviz.",
     "Guests can still join public conversations." : "Kouviidi a c'hell dont en diviz c'hoaz.",
@@ -459,36 +462,30 @@ OC.L10N.register(
     "Limit starting a call" : "Beven kregiñ ur gemenadenn",
     "Limit starting calls" : "Beven kregiñ kemenadennoù",
     "When a call has started, everyone with access to the conversation can join the call." : "P'en deus kroget ur gemenadenn, tout an dud en diviz a c'hell monet er gemenadenn.",
-    "Everyone" : "Toud an dud",
-    "Users and moderators" : "Implijourien ha habaskaerienn",
-    "Moderators only" : "Habaskerienn nemetken",
-    "Save changes" : "Enrollañ ar cheñchamantoù",
-    "Saving …" : "Orc'h enrolliñ",
-    "Saved!" : "Enrollet !",
-    "Commands" : "Urzhioù",
-    "Beta" : "Beta",
-    "Name" : "Anv",
-    "Command" : "Urzh",
-    "Script" : "Script",
-    "Response to" : "Respont da",
-    "Enabled for" : "reañ evit",
-    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon {linkstart}diellvadur{linkend}.",
-    "None" : "Hini ebet",
-    "User" : "Implijer",
     "Disabled" : "Disaotreañ",
-    "Moderators" : "Habaskaer",
-    "Users" : "Implijer",
+    "State" : "Stad",
+    "Name" : "Anv",
+    "Description" : "Deskrivadur",
+    "Beta" : "Beta",
+    "All messages" : "Pep kemenadenn",
+    "@-mentions only" : "@-meneg nemetkenn",
+    "Off" : "Lac'hañ",
     "General settings" : "Stummoù hollek",
-    "Default notification settings" : "Arventennoù kemenadenn dre ziouer",
+    "Default notification settings" : "Arventennoù kemenadennoù dre ziouer",
     "Default group notification" : "Kemenadenn strollad dre ziouer",
     "Default group notification for new groups" : "Kemenadenn strollad dre ziouer evit ar strolladoù nevez",
     "Integration into other apps" : "Lakaet e-barzh meziantoù all",
     "Allow conversations on files" : "Aotreañ an treiñ restroù",
     "Allow conversations on public shares for files" : "Aotreañ divizoù war ranadennoù publik evit ar restroù",
-    "All messages" : "Pep kemenadenn",
-    "@-mentions only" : "@-meneg nemetkenn",
-    "Off" : "Lac'hañ",
-    "Hosted high-performance backend" : "Backend a labour buhan osted",
+    "Enable encryption" : "Aotreañ ar sifradur",
+    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "En ur klikañ war ar bouton a huz an titouroù ar stumm mañ a vo kaset d'ar servijour Struktur AG. Muioc'h a ditouroù war {linkstart}spreed.eu{linkend}.",
+    "Pending" : "O c'hortoz",
+    "Error" : "Fazi",
+    "Blocked" : "Stanket",
+    "Active" : "O labourat",
+    "Expired" : "Termenet",
+    "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
+    "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "URL of this Nextcloud instance" : "URL an azgoulenn Nextcloud",
     "Full name of the user requesting the trial" : "Tout anv an implijer a goulenn an amprouadenn",
     "Language" : "Yezh",
@@ -500,48 +497,39 @@ OC.L10N.register(
     "Expires at" : "Termen da",
     "Limits" : "Bevennoù",
     "Delete the signaling server account" : "Lemel ar c'hont arhent servijour",
-    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "En ur klikañ war ar bouton a huz an titouroù ar stumm mañ a vo kaset d'ar servijour Struktur AG. Muioc'h a ditouroù war {linkstart}spreed.eu{linkend}.",
-    "Pending" : "O c'hortoz",
-    "Error" : "Fazi",
-    "Blocked" : "Stanket",
-    "Active" : "O labourat",
-    "Expired" : "Termenet",
-    "The trial could not be requested. Please try again later." : "An amprouadenn na c'hell ket bezhañ goulennet. Klaskit en dro goude.",
-    "The account could not be deleted. Please try again later." : "Neo ket posupl lemel ar c'hont. Klaskit en dro goude",
     "_%n user_::_%n users_" : ["%n implijer","%n implijer","%n implijer","%n implijer","%n implijer"],
-    "Validate SSL certificate" : "Sertifikad SSL gwiriet",
-    "Delete this server" : "Lemel ar servijour",
     "Status: Checking connection" : "Stad : Ho gwiriañ ar genstagadenn",
     "OK: Running version: {version}" : "OK : o lakaat da dreiñ ar stumm : {version}",
-    "Error: Server did not respond with proper JSON" : "Fazi : N'eo ket posupl respont gant ur JSON mat",
-    "Error: Server responded with: {error}" : "Fazi : Respont a ra ar servijour gant : {error}",
-    "Error: Unknown error occurred" : "Fazi : Ur fazi dianv a zo bet",
+    "Validate SSL certificate" : "Sertifikad SSL gwiriet",
+    "Delete this server" : "Lemel ar servijour",
+    "Test this server" : "Arnodañ ar servijour-mañ",
     "Shared secret" : "Secret rannet",
     "High-performance backend URL" : "URL ar vackend a labour buhan",
-    "High-performance backend" : "Backend a labour buhan",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
-    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
     "STUN server URL" : "URL ar servijour STUNN",
     "STUN servers" : "Servijour STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Ur servijour STUNN a vez implijet evit anavezout chom-lec'h IP publik an implijourienn a drek an henter.",
-    "TURN server URL" : "URL ar servijour TURN",
-    "TURN server secret" : "Servijour TURN sekret",
-    "TURN server protocols" : "Protokoloù servijour TURN",
     "OK: Successful ICE candidates returned by the TURN server" : "OK : ICE emstriver mat edkaset gant ar servijour TURN",
     "Error: No working ICE candidates returned by the TURN server" : "Fazi : Ne labour ket ICE emstriver adkaset gant ar servijour TURN",
     "Testing whether the TURN server returns ICE candidates" : "Amprouiñ adkasadenn emstriver ICE at servijour TURN",
-    "Test this server" : "Arnodañ ar servijour-mañ",
+    "TURN server URL" : "URL ar servijour TURN",
+    "TURN server secret" : "Servijour TURN sekret",
+    "TURN server protocols" : "Protokoloù servijour TURN",
     "TURN servers" : "Servijour TURN",
+    "Failed" : "C'hwitet",
     "OK" : "OK",
-    "Back" : "Distro",
     "Confirm" : "Kadarnañ",
+    "Back" : "Distro",
     "Cancel" : "Arrest",
-    "Copy link" : "Kopiañ al liamm",
+    "Calendar" : "Deiziadur",
+    "Save" : "Enrollañ",
+    "Search participants" : "Klask implijer",
+    "No results" : "Disoc'h ebet",
+    "Done" : "Graet",
     "Waiting for others to join the call …" : "O c'hortoz ma teuio ar re all er gemenadenn ...",
     "You can invite others in the participant tab of the sidebar" : "Galout a rit kouviañ tud gant an daolenn lodek er verenn gostez",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galout a rit kouviañ tud en dolenn lodek er varenn gostez pe rannañ al liamm-mañ evit kouviañ anezho !",
     "Share this link to invite others!" : "Rannit al liamm-mañ gant ar re all !",
+    "Copy link" : "Kopiañ al liamm",
     "Mute audio" : "Lac'hañ a audio",
     "Unmute audio" : "Lakaat an odio en dro",
     "Access to camera was denied" : "Nac'het eo bet tizhañ ar c'hamera",
@@ -551,120 +539,105 @@ OC.L10N.register(
     "Enable video" : "Lakaat ar video en dro",
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Lakaat ar video en dro. Ho genstagadenn a vo troc'het evit aotreañ ar video evit ar wech kentañ",
     "You" : "C'hwi",
+    "Mute" : "Mut",
     "Show screen" : "Diskwell ar skramm",
     "Stop following" : "Arrest heuliañ",
-    "Mute" : "Mut",
     "You need to be logged in to upload files" : "Ret eo deoc'h bezhañ deuet-tre evit pellkas restroù",
     "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
     "Favorite" : "Pennroll",
-    "Description" : "Deskrivadur",
+    "Hide details" : "Skoachañ ar munudoù",
+    "Show details" : "Diskouel ar munudoù",
+    "Disable" : "Disaotreañ",
+    "Enable" : "Aotreañ",
+    "Choose" : "Dibab",
     "Conversation settings" : "Stummoù diviz",
     "Personal" : "Personel",
-    "Leave conversation" : "Kuitaat an diviz",
-    "Delete conversation" : "Lemel an diviz",
     "Do you really want to delete \"{displayName}\"?" : "Sur oc'h da lemel  \"{displayName}\" ?",
-    "Submit" : "Kinnig",
+    "Leave conversation" : "Kuitaat an diviz",
+    "No" : "Nann",
+    "Delete conversation" : "Lemel an diviz",
     "Password protection" : "Gwareziñ gant ur ger-tremen",
-    "Copy conversation link" : "Eilañ al liamm diviz",
     "Start time (optional)" : "Amzer kregiñ (dibab)",
-    "Save" : "Enrollañ",
     "Edit" : "Cheñch",
     "More information" : "Muioc'h a ditouroù",
     "Delete" : "Lemel",
-    "Password" : "Ger-tremen",
-    "Login" : "Anv arveriad",
-    "Client ID" : "ID kliant",
     "Notifications" : "Kemennadennoù",
+    "Log in" : "Kennaskañ",
     "Remove from favorites" : "Diverkañañ eus ar pennrolloù",
     "Add to favorites" : "Ouzhpennañ er pennrolloù",
-    "You: {lastMessage}" : "C'hwi : {lastMessage}",
-    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "You need to promote a new moderator before you can leave the conversation." : "Ret eo deoc'h lakaat unan bennak da moderatour a-rao kuitaat an diviz.",
-    "Loading" : "Kargañ",
-    "No search results" : "Disoc'h enklask ebet",
-    "Groups" : "Strolladoù",
-    "Circles" : "Kelc'hioù",
-    "Users, groups and circles" : "Implijouirinn, stroladoù ha kelc'hioù.",
     "Users and groups" : "Implijourienn ha strolladoù",
-    "Users and circles" : "Implijourien ha kelc'hioù",
-    "Groups and circles" : "Strolladoù ha kelc'hioù",
+    "Users" : "Implijer",
+    "Groups" : "Strolladoù",
     "Other sources" : "Orin all",
     "An error occurred while performing the search" : "Ur fazi a zo bet en ur ober an enklask",
-    "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
-    "Password protect" : "Ger-tremen gwarezet",
-    "Creating your conversation" : "Krouiñ ho diviz",
-    "All set" : "Staliet pep tra",
-    "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
-    "Create conversation" : "Krouiñ un diviz",
-    "Add participants" : "Ouzhpennan tud",
-    "Close" : "Serriñ",
-    "Search participants" : "Klask implijer",
-    "Conversation name" : "Anv diviz",
+    "No search results" : "Disoc'h enklask ebet",
     "You are currently waiting in the lobby" : "Ho gortoz er sal gortoz emaoc'h",
-    "No microphone available" : "Mikro ebet kavet",
+    "None" : "Hini ebet",
     "Select microphone" : "Choaz ur mikro",
-    "No camera available" : "Kamera ebet kavet",
+    "No microphone available" : "Mikro ebet kavet",
     "Select camera" : "Choaz ur c'hamera",
-    "Done" : "Graet",
+    "No camera available" : "Kamera ebet kavet",
     "No audio" : "Audio ebet",
     "No camera" : "Kamera ebet",
+    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
     "Upload" : "Pellkas",
     "Files" : "Restroù",
-    "File to share" : "Restr da rannañ",
-    "Invalid path selected" : "An hent dibabet n'eus ket anezhañ",
-    "Dismiss" : "Arrest",
     "Reply" : "Respont",
     "Go to file" : "Mont d'ar restr",
     "Translate" : "Treiñ",
+    "Dismiss" : "Arrest",
     "Today" : "Hiziv",
     "Yesterday" : "Dec'h",
+    "_%n day ago_::_%n days ago_" : ["%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo","%n deiz zo"],
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Add emoji" : "Ouzhpennañ un emoji",
+    "Error while creating the conversation" : "Ur fazi a zo bet en ur krouiñ an diviz",
+    "Create a new group conversation" : "Krouiñ un diviz strollad nevez",
+    "Create conversation" : "Krouiñ un diviz",
+    "Add participants" : "Ouzhpennan tud",
     "Send message" : "Kas ur gemenadenn",
-    "Write message, @ to mention someone …" : "Skrivañ ur gemenadenn, @ evit menegiñ unan bennak ...",
-    "Group" : "Stollad",
+    "Add emoji" : "Ouzhpennañ un emoji",
+    "File to share" : "Restr da rannañ",
+    "Share from Files" : "Rannañ diouzh Restroù",
     "Share files to the conversation" : "Rannañ restroù d'an diviz",
     "New file" : "Restr nevez",
-    "Settings" : "Arventennoù",
-    "Send" : "Kas",
     "Add more files" : "Ouzhpennañ muioc'h a restroù",
+    "Send" : "Kas",
+    "Settings" : "Arventennoù",
     "Join" : "Kejañ",
     "moderator" : "habaskaer",
     "guest" : "kouviad",
+    "Remove participant" : "Lemel an den",
     "Demote from moderator" : "Lemel eus ar moderatourienn",
     "Promote to moderator" : "Lakaat da moderatour",
-    "Remove participant" : "Lemel an den",
+    "Add users or groups" : "Ouzhpennañ implijourienn pe strolladoù",
     "Add users" : "Ouzhpennañ implijer ",
     "Add groups" : "Ouzhoennañ strolladoù",
-    "Add emails" : "Ouzhpennañ postelloù",
-    "Add circles" : "Ouzhpennañ kelc'hioù",
-    "Searching …" : "O klask ...",
-    "No results" : "Disoc'h ebet",
-    "Search for more users" : "Klask d evit muioc'h a implijourienn.",
-    "Add users, groups or circles" : "Ouhzpennañ implijourienn, strolladoù pe kelc'hioù",
-    "Add users or groups" : "Ouzhpennañ implijourienn pe strolladoù",
-    "Add users or circles" : "Ouhzpennañ implijourienn pe kelc'hioù",
-    "Add groups or circles" : "Ouhzpennañ strolladoù pe kelc'hioù",
     "Add other sources" : "Ouzhpennañ dre un orin all",
+    "Add emails" : "Ouzhpennañ postelloù",
+    "Searching …" : "O klask ...",
+    "Search for more users" : "Klask d evit muioc'h a implijourienn.",
     "Participants" : "Tud",
     "Chat" : "Chat",
     "Details" : "Munudoù",
+    "Load more results" : "Kagañ muioc'h a disoc'hoù",
     "Projects" : "Raktres",
+    "Link to a conversation" : "Liamm d'an diviz",
     "Search conversations or users" : "Klask divizoù ha implijourienn",
     "Select conversation" : "Choaz un diviz",
-    "Link to a conversation" : "Liamm d'an diviz",
+    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
+    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
+    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
+    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
+    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
+    "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
     "Choose devices" : "Choazit un ardivink",
     "Attachments folder" : "Teuliad stag",
+    "Select location for attachments" : "Choazit ul lec'h evit stagañ",
     "Privacy" : "Prevezder",
     "Search" : "Klask",
-    "Select location for attachments" : "Choazit ul lec'h evit stagañ",
-    "Error while setting attachment folder" : "Ur fazi a zo bet en ur lakaat an teuliad stagañ",
     "Start call" : "Kregiñ ar gemenadenn",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
     "You will be able to join the call only after a moderator starts it." : "Posupl vo deoc'h mont er gemenadenn goude ma vo bet groget gant ar modertator.",
-    "Open sidebar" : "Digori ar varenn gostez",
-    "Show your screen" : "Diskouez ar skramm",
-    "Stop screensharing" : "Echuañ ar rannadenn skramm",
     "Screensharing options" : "Dibaboù rannañ skramm",
     "Enable screensharing" : "Aotreañ ar rannan skramm",
     "Bad sent video and screen quality." : "Fall eo perzh ar skramm ha kasadenn ar video.",
@@ -687,40 +660,39 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Un astenn rannañ-skramm ez eus ezhomm evit rannañ ho srkamm.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Implijit furcherienn disheñvel evel firefox pe Chrome evit rannañ ho skramm.",
     "An error occurred while starting screensharing." : "Ur fazi a zo bet e pad ar rannadenn-skramm.",
-    "Mute others" : "Lakaat ar re all mut",
+    "Show your screen" : "Diskouez ar skramm",
+    "Stop screensharing" : "Echuañ ar rannadenn skramm",
     "Grid view" : "Diskwell ar roued",
-    "No unread mentions" : "Kemenadenn nan-lennet ebet",
-    "Say hi to your friends and colleagues!" : "Lâr koukouk d'ho mignoned ha genseurted",
-    "Start a conversation" : "Kregiñ un diviz",
+    "Mute others" : "Lakaat ar re all mut",
+    "Submit" : "Kinnig",
     "Message without mention" : "Kemenn hp meneg",
     "Mention myself" : "Meneg ac'hanon",
-    "Mention room" : "Sal meneg",
     "The conversation does not exist" : "N'ez eus ket eus an diviz-mañ",
     "Join a conversation or start a new one!" : "Mont en un diviz pe kregiñ unan nevez !",
+    "Duplicate session" : "Eilan dalc'h",
     "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Deuet oc'h en diviz dre ur prenestr pe ardivink all. N'eo ket douget evit ar poent gant Nextcloud Talk neuze eo bet sertet an dalc'h.",
     "Join a conversation or start a new one" : "Mont en un diviz pe kregiñ unan nevez ",
-    "Calls are not supported in your browser" : "N'eo ket douget ar gemenadennoù gant ho vrowser",
-    "Access to microphone is only possible with HTTPS" : "N'eo posupl tizhout ar mikro nemet gant HTTPS",
-    "Access to microphone was denied" : "N'eo ket aotreet tizhout ar mikro",
-    "Error while accessing microphone" : "Ur fazi a zo bet en ur tizhout ar mikro",
-    "Access to camera is only possible with HTTPS" : "Tizhout ar c'hamera n'eo posupl nemet gant HTTPS",
-    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
+    "User" : "Implijer",
+    "Password" : "Ger-tremen",
+    "Login" : "Anv arveriad",
+    "Client ID" : "ID kliant",
     "Media" : "Media",
     "Audio" : "Audio",
     "Other" : "All",
-    "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
-    "Do not disturb" : "Na rannit ket",
-    "Away" : "Pell",
+    "Group" : "Stollad",
+    "You: {lastMessage}" : "C'hwi : {lastMessage}",
+    "{actor}: {lastMessage}" : "{actor} : {lastMessage}",
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
-    "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
+    "An error occurred while fetching the participants" : "Ur fazi a zo bet en ur pakañ an tud",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Ho klask mont en diviz emaoc'h p'ho peus un dalc'h en ur prenestr pe ardivink all. N'eo ket douget c'hoaz gant Nextcloud Talk. Petra o peus c'hoant ober ?",
     "Join here" : "Kejañ amañ",
     "Leave this page" : "Kuitaat ar bajenn",
-    "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
     "Lost connection to signaling server. Trying to reconnect." : "Kenstagadenn gant ar servijour arhent kollet. O klask adkemprenn.",
-    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
     "Establishing signaling connection is taking longer than expected …" : "Lakaat an arhent kenstagañ a zo hiroc'h eget gortozet ...",
     "Failed to establish signaling connection. Retrying …" : "C'hwitet da lakaat an arhent kemprenn. O klask en dro ...",
+    "Please reload the page." : "Mar-plij adkargit ar bajenn",
+    "Do not disturb" : "Na rannit ket",
+    "Away" : "Pell",
     "Default" : "Dre ziouer",
     "Microphone {number}" : "Mikro {number}",
     "Camera {number}" : "Kamera {number}",
@@ -735,23 +707,44 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Implijit furcherienn disheñvel evel Firefox pe Chrome",
     "Error while accessing microphone & camera" : "Ur fazi a zo bet en ur klask tizout ar mikro hag ar c'hamera",
     "The password is wrong. Try again." : "Direizh eo ar ger-tremen. Klaskit en-dro.",
-    "Specify commands the users can use in chats" : "Lakait peseurt urzhioù eo posupl d'an implijer implij er chat",
-    "TURN server" : "Servijour TRUN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Ar servijour TURN a zo implijet evit proksiañ froud an implijaderien a-drek ur voger-dan.",
-    "Signaling servers" : "Arhent Servijour",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour arhent diavaez a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhent diabarzh goullo.",
     "%s Talk on your mobile devices" : "%s Talk war ho ardivinkoù hezoug",
     "Join conversations at any time, anywhere, on any device." : "Kit en diviz n'eus forzh peseurt amzer, lec'h pe ardivink.",
     "Android app" : "Meziant Android",
     "iOS app" : "Meziant iOS",
-    "Name of the user requesting the trial" : "Anv an implijet a goulenn an amprouadenn",
-    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Notennit c''hell an implijourien, evit kemenadennoù gant muioc'h eget 4 implijer gant ur servijour arhent diavaez, kaout kudennoù kenstagadeur ha lakaat kargoù bras var ardivinkoù an impklijour.",
-    "Conversation link copied to clipboard." : "Liamm diviz eilet er golver",
-    "The link could not be copied." : "Ne oa ket posupl eilañ al liamm.",
-    "No matches" : "Kejadenn ebet",
-    "Link copied to the clipboard!" : "Liamm eilet d'ar golver",
-    "Toggle fullscreen" : "Lakat/Kuitaat ar skramm a bezh",
-    "Rename conversation" : "Adenvel an diviz",
-    "Sending signaling message has failed." : "Kasadenn ar gemenadenn arhentañ a zo c'hwitet."
+    "__language_name__" : "Brezhoneg",
+    "Notes" : "Notennoù",
+    "There are currently no commands available." : "N'ez us linenn urzh ebet evit ar poent",
+    "The command does not exist" : "N'ez eus ket eyus an urzh",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ur fazi a zo bet en ur ober an urzh. Goulennit d'ar merour da sellet ouzh ar gazetenn.",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})","Kemenadenn gant %n kouviad (Padelez {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Kemenadenn gant {user1} ha {user2} (Padelez {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Kemenadenn gant {user1}, {user2} ha {user3} (Padelez {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3} ha {user4} (Padelez {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Kemenadenn gant {user1}, {user2}, {user3}, {user4} ha {user5} (Padelez {duration})",
+    "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our {linkstart}documentation{linkend}." : "An urzhioù a zo ur perzh nevez e Nextcloud Talk. Aotreañ a reont da lakaat da dreiñ ur skrip war ho servijour Nextcloud. Galout a rit krouañ anezho en ur implij hon etrafas linenn urzh. Ur skouer skript jederez a zo posupl kaout en hon {linkstart}diellvadur{linkend}.",
+    "Moderators" : "Habaskaer",
+    "Commands" : "Urzhioù",
+    "Command" : "Urzh",
+    "Script" : "Script",
+    "Response to" : "Respont da",
+    "Enabled for" : "reañ evit",
+    "Hosted high-performance backend" : "Backend a labour buhan osted",
+    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour diavaezh arhentañ a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhentañ diabarzh goulo.",
+    "It is highly recommended to set up a distributed cache when using Nextcloud Talk together with a High Performance Back-end." : "Aliet kreñv eo staliañ ur c'hach rannet pa implijer Nextcloud Talk gant ur Vack-End Labour Huel.",
+    "Don't warn about connectivity issues in calls with more than 4 participants" : "N'om pas kemenn diwar ben kudennom kenstagadur er gemennadennoù gant muioc'h eget 4 implijer.",
+    "Copy conversation link" : "Eilañ al liamm diviz",
+    "Loading" : "Kargañ",
+    "Close" : "Serriñ",
+    "Password protect" : "Ger-tremen gwarezet",
+    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Adnevesaet e bet Nextcloud Talk, ret eo deoc'h freskaat ar bajenn a raok kregiñ pe mont en ut gamanadenn.",
+    "Nextcloud Talk was updated, please reload the page" : "Adnevesaet eo bet Nextcloud Talk , adkargit ar bajenn",
+    "Failed to join the conversation. Try to reload the page." : "C'hwitet da mont en diviz. Klaksit adkargañ ar bajenn.",
+    "Nextcloud is in maintenance mode, please reload the page" : "E stumm dalc'h eo Nextcloud, adkargit ar bajenn",
+    "Lost connection to signaling server. Try to reload the page manually." : "Kenstagadenn gant ar servijour arhent kollet. Klaskit adkemprenn gant an dorn.",
+    "Specify commands the users can use in chats" : "Lakait peseurt urzhioù eo posupl d'an implijer implij er chat",
+    "TURN server" : "Servijour TRUN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "Ar servijour TURN a zo implijet evit proksiañ froud an implijaderien a-drek ur voger-dan.",
+    "Signaling servers" : "Arhent Servijour",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Ur servijour arhent diavaez a c'hell bezhañ implijet evit staliadurioù brasoc'h. Laoskit implij ar servijour arhent diabarzh goullo."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
