@@ -19,40 +19,47 @@ OC.L10N.register(
     "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
+    "Limit to groups" : "Limitar a grupos",
+    "Enabled" : "Habilitado",
+    "Disabled" : "Deshabilitado",
     "State" : "Estado",
     "Name" : "Nombre",
     "Description" : "Descripción",
-    "Enabled" : "Habilitado",
-    "Disabled" : "Deshabilitado",
     "Beta" : "Beta",
     "Permissions" : "Permisos",
-    "General settings" : "Configuraciones generales",
     "Off" : "Apagado",
+    "General settings" : "Configuraciones generales",
+    "Enable encryption" : "Habilitar encripción",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
-    "Pending" : "Pendiente",
-    "Error" : "Error",
-    "Blocked" : "Bloqueado",
     "TURN server protocols" : "Protocolos del servidor TURN",
     "Failed" : "Error",
     "OK" : "OK",
-    "Back" : "Atrás",
-    "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
-    "Copy link" : "Copiar enlace",
+    "Back" : "Atrás",
+    "Cancel" : "Cancelar",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "Sin resultados",
+    "Done" : "Terminado",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
+    "Copy link" : "Copiar enlace",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "You" : "Usted",
     "Collapse" : "Colapsar",
     "Favorite" : "Favorito",
+    "Note:" : "Nota:",
     "Hide details" : "Ocultar detalles",
     "Show details" : "Mostrar detalles",
     "Disable" : "Deshabilitar",
@@ -64,18 +71,17 @@ OC.L10N.register(
     "Yes" : "Sí",
     "Delete conversation" : "Eliminar conversación",
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
+    "Set a password" : "Establecer una contraseña",
     "Edit" : "Editar",
     "More information" : "Más información",
     "Delete" : "Eliminar",
     "Log content" : "Contenido del registro",
     "Notifications" : "Notificaciones",
-    "Login" : "Inicio de sesión",
+    "Log in" : "Iniciar sesión",
     "Remove from favorites" : "Eliminado de favoritos",
     "Add to favorites" : "Agregar a favoritos",
     "Users" : "Ususarios",
     "Groups" : "Grupos",
-    "Loading" : "Cargando",
     "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
@@ -87,34 +93,33 @@ OC.L10N.register(
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
-    "Close" : "Cerrar",
-    "Password protect" : "Proteger con contraseña",
     "Send message" : "Enviar mensaje",
     "New file" : "Nuevo archivo",
-    "Settings" : "Ajustes",
     "Send" : "Enviar",
+    "Settings" : "Ajustes",
     "Remove" : "Eliminar",
-    "Searching …" : "Buscando ...",
-    "No results" : "Sin resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
+    "Searching …" : "Buscando ...",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Details" : "Detalles",
+    "Load more results" : "Cargar más resultados",
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos de teclado",
     "Search" : "Buscar",
-    "Show your screen" : "Mostrar su pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Favor de usar un navegador diferente como Firefox o Chrome para compartir su pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Show your screen" : "Mostrar su pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Grid view" : "Vista de cuadrícula",
     "Submit" : "Enviar",
     "User" : "Usuario",
     "Password" : "Contraseña",
     "API token" : "Ficha del API",
+    "Login" : "Inicio de sesión",
     "Nickname" : "Apodo",
     "Client ID" : "ID del cliente",
     "Media" : "Media",
@@ -122,6 +127,7 @@ OC.L10N.register(
     "Audio" : "Audio",
     "Other" : "Otro",
     "Group" : "Grupo",
+    "Please reload the page." : "Favor de volver a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Lejos",
     "Default" : "Predeterminado",
@@ -133,8 +139,13 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "Circles" : "Círculos",
-    "Start a conversation" : "Iniciar una conversación",
+    "__language_name__" : "Español (Argentina)",
+    "Tasks" : "Tareas",
+    "Notes" : "Notas",
+    "Reports" : "Reportes",
+    "Loading" : "Cargando",
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. "
 },
