@@ -12,25 +12,22 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["%n otro","otros %n","otros %n"],
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una<strong>conversación</strong> o tuviste una <strong>llamada</strong>",
+    "Other activities" : "Otras actividades",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bienvenido a Nextcloud Talk!\nEn esta conversación se te informará sobre nuevas características disponibles en Nextcloud Talk.",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge y Safari ahora pueden ser usados para participar en llamdas de audio y video llamadas",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes notificar a todos los participantes comentando \"@all\" en el chat",
     "- With the \"arrow-up\" key you can repost your last message" : "- Puedes reenviar tu último mensaje con la tecla \"flecha arriba\"",
     "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk ahora puede recibir comandos, envia \"/help\" como mensaje en el chat para ver si tu administrador configuro algunos",
     "- With projects you can create quick links between conversations, files and other items" : "- Con projects puedes crear ligas entre conversaciones, archivos y otros artículos.",
     "- You can now mention guests in the chat" : "- Ahora puedes mencionar a invitados en el chat",
-    "There are currently no commands available." : "No hay comandos disponibles actualmente",
-    "The command does not exist" : "El comando no existe",
-    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
     "Talk updates ✅" : "Actualizaciones de Talk  ✅",
     "{actor} created the conversation" : "{actor} creó la conversación",
     "You created the conversation" : "Creaste la conversación",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} renombró la conversación de \"%1$s\" a \"%2$s\"",
     "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Renombraste la conversación de \"%1$s\" a \"%2$s\"",
-    "{actor} started a call" : "{actor} inició una llamada",
     "You started a call" : "Iniciaste una llamada",
+    "{actor} started a call" : "{actor} inició una llamada",
     "{actor} joined the call" : "{actor} se unió a la llamada",
     "You joined the call" : "Te uniste a la llamada",
     "{actor} left the call" : "{actor} abandonó la llamada",
@@ -70,12 +67,8 @@ OC.L10N.register(
     "{actor} demoted you from moderator" : "{actor} te degradó de moderador",
     "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
     "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
+    "Message deleted by author" : "Mensaje eliminado por el autor",
     "%s (guest)" : "%s (invitado)",
-    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
-    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
-    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
-    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
     "Talk conversations" : "Conversaciones de Talk",
     "Talk to %s" : "Hablar con %s",
     "File is not shared, or shared but not with the user" : "Archivo no compartido, o compartido pero no con el usuario.",
@@ -84,7 +77,7 @@ OC.L10N.register(
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
     "Talk mentions" : "Menciones en Talk",
-    "More unread mentions" : "Más menciones no leídas",
+    "No unread mentions" : "No hay menciones sin leer",
     "%s invited you to a conversation." : "%s te invitó a una conversación",
     "You were invited to a conversation." : "fuiste invitado a una conversación",
     "Conversation invitation" : "invitación a una conversación",
@@ -94,6 +87,8 @@ OC.L10N.register(
     "Private conversation" : "Conversación privada",
     "Deleted user (%s)" : "Usuario eliminado (%s)",
     "Dismiss notification" : "Descartar notificación",
+    "Accept" : "Aceptar",
+    "Decline" : "Rechazar",
     "{user} sent you a private message" : "{user} te envió un mensaje privado",
     "{user} mentioned you in a private conversation" : "{user} te mencionó en una conversación privada",
     "{user} invited you to a private conversation" : " {user} te invitó a una conversación privada",
@@ -101,116 +96,374 @@ OC.L10N.register(
     "{user} invited you to a group conversation: {call}" : "{user} te invitó a una conversación de grupo: {call}",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
+    "error" : "error",
     "Conversations" : "Conversaciones",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Andorra" : "Andorra",
+    "United Arab Emirates" : "Emiratos Árabes Unidos",
+    "Afghanistan" : "Afghanistán",
+    "Antigua and Barbuda" : "Antigua y Barbuda",
+    "Anguilla" : "Anguila",
+    "Albania" : "Albania",
+    "Armenia" : "Armenia",
+    "Angola" : "Angola",
+    "Antarctica" : "Antártida",
+    "Argentina" : "Argentina",
+    "American Samoa" : "Samoa Americana",
+    "Austria" : "Austria",
+    "Australia" : "Australia",
+    "Aruba" : "Aruba",
+    "Åland Islands" : "Islas Åland",
+    "Azerbaijan" : "Azerbaiyán",
+    "Bosnia and Herzegovina" : "Bosnia y Herzegovina",
+    "Barbados" : "Barbados",
+    "Bangladesh" : "Bangladesh",
+    "Belgium" : "Bélgica",
+    "Burkina Faso" : "Burkina Faso",
+    "Bulgaria" : "Bulgaria",
+    "Bahrain" : "Baréin",
+    "Burundi" : "Burundi",
+    "Benin" : "Benín",
+    "Saint Barthélemy" : "San Bartolomé",
+    "Bermuda" : "Bermudas",
+    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio y Saba",
+    "Brazil" : "Brasil",
+    "Bahamas" : "Bahamas",
+    "Bhutan" : "Bután",
+    "Bouvet Island" : "Isla Bouvet",
+    "Botswana" : "Botsuana",
+    "Belarus" : "Bielorrusia",
+    "Belize" : "Belice",
+    "Canada" : "Canadá",
+    "Cocos (Keeling) Islands" : "Islas Cocos (Keeling)",
+    "Central African Republic" : "República Centroafricana",
+    "Congo" : "Congo",
+    "Switzerland" : "Suiza",
+    "Cook Islands" : "Islas Cook",
+    "Chile" : "Chile",
+    "Cameroon" : "Camerún",
+    "China" : "China",
+    "Colombia" : "Colombia",
+    "Costa Rica" : "Costa Rica",
+    "Cuba" : "Cuba",
+    "Cabo Verde" : "Cabo Verde",
+    "Curaçao" : "Curazao",
+    "Christmas Island" : "Islas Navidad",
+    "Cyprus" : "Chipre",
+    "Germany" : "Alemania",
+    "Djibouti" : "Djibouti",
+    "Denmark" : "Dinamarca",
+    "Dominican Republic" : "República Dominicana",
+    "Algeria" : "Algeria",
+    "Ecuador" : "Ecuador",
+    "Estonia" : "Estonia",
+    "Egypt" : "Egipto",
+    "Eritrea" : "Eritrea",
+    "Spain" : "España",
+    "Ethiopia" : "Etiopía",
+    "Finland" : "Finlandia",
+    "Fiji" : "Fiji",
+    "Faroe Islands" : "Islas Faroe",
+    "France" : "Francia",
+    "Gabon" : "Gabón",
+    "Grenada" : "Granada",
+    "Georgia" : "Georgia",
+    "French Guiana" : "Guyana Francesa",
+    "Guernsey" : "Guernesey",
+    "Ghana" : "Ghana",
+    "Gibraltar" : "Gibraltar",
+    "Greenland" : "Groenlandia",
+    "Gambia" : "Gambia",
+    "Guinea" : "Guinea",
+    "Guadeloupe" : "Guadalupe",
+    "Equatorial Guinea" : "Guinea Ecuatorial",
+    "Greece" : "Grecia",
+    "South Georgia and the South Sandwich Islands" : "Islas Georgia del Sur y Sandwich del Sur",
+    "Guatemala" : "Guatemala",
+    "Guam" : "Guam",
+    "Guinea-Bissau" : "Guinea-Bissau",
+    "Guyana" : "Guyana",
+    "Hong Kong" : "Hong Kong",
+    "Heard Island and McDonald Islands" : "Isla Heard e Islas McDonald",
+    "Honduras" : "Honduras",
+    "Croatia" : "Croacia",
+    "Haiti" : "Haití",
+    "Hungary" : "Hungría",
+    "Indonesia" : "Indonesia",
+    "Ireland" : "Irlanda",
+    "Israel" : "Israel",
+    "Isle of Man" : "Isla de Man",
+    "India" : "India",
+    "British Indian Ocean Territory" : "Territorio Británico del Océano Índico",
+    "Iraq" : "Iraq",
+    "Iceland" : "Islandia",
+    "Italy" : "Italia",
+    "Jamaica" : "Jamaica",
+    "Jordan" : "Jordania",
+    "Japan" : "Japón",
+    "Kenya" : "Kenia",
+    "Kyrgyzstan" : "Kirguistán",
+    "Cambodia" : "Camboya",
+    "Kiribati" : "Kiribati",
+    "Saint Kitts and Nevis" : "San Cristóbal y Nieves",
+    "Kuwait" : "Kuwait",
+    "Cayman Islands" : "Islas Caimán",
+    "Kazakhstan" : "Kazajistán",
+    "Lebanon" : "Líbano",
+    "Saint Lucia" : "Santa Lucía",
+    "Liechtenstein" : "Liechtenstein",
+    "Sri Lanka" : "Sri Lanka",
+    "Liberia" : "Liberia",
+    "Lesotho" : "Lesoto",
+    "Lithuania" : "Lituania",
+    "Luxembourg" : "Luxemburgo",
+    "Latvia" : "Letonia",
+    "Libya" : "Libia",
+    "Morocco" : "Marruecos",
+    "Monaco" : "Mónaco",
+    "Montenegro" : "Montenegro",
+    "Madagascar" : "Madagascar",
+    "Marshall Islands" : "Islas Marshall",
+    "Mali" : "Malí",
+    "Myanmar" : "Birmania",
+    "Mongolia" : "Mongolia",
+    "Macao" : "Macao",
+    "Northern Mariana Islands" : "Islas Marianas del Norte",
+    "Mauritania" : "Mauritania",
+    "Montserrat" : "Montserrat",
+    "Malta" : "Malta",
+    "Mauritius" : "Mauricio",
+    "Maldives" : "Maldivas",
+    "Malawi" : "Malawi",
+    "Mexico" : "México",
+    "Malaysia" : "Malasia",
+    "Mozambique" : "Mozambique",
+    "Namibia" : "Namibia",
+    "New Caledonia" : "Nueva Caledonia",
+    "Niger" : "Níger",
+    "Norfolk Island" : "Isla Norfolk",
+    "Nigeria" : "Nigeria",
+    "Nicaragua" : "Nicaragua",
+    "Netherlands" : "Países Bajos",
+    "Norway" : "Noruega",
+    "Nepal" : "Nepal",
+    "Nauru" : "Nauru",
+    "Niue" : "Niue",
+    "New Zealand" : "Nueva Zelanda",
+    "Oman" : "Omán",
+    "Panama" : "Panamá",
+    "Peru" : "Perú",
+    "French Polynesia" : "Polinesia Francesa",
+    "Papua New Guinea" : "Papúa Nueva Guinea",
+    "Philippines" : "Filipinas",
+    "Pakistan" : "Pakistán",
+    "Poland" : "Polonia",
+    "Saint Pierre and Miquelon" : "San Pedro y Miquelón",
+    "Pitcairn" : "Pitcairn",
+    "Puerto Rico" : "Puerto Rico",
+    "Portugal" : "Portugal",
+    "Palau" : "Palau",
+    "Paraguay" : "Paraguay",
+    "Qatar" : "Catar",
+    "Réunion" : "Reunión",
+    "Romania" : "Rumanía",
+    "Serbia" : "Serbia",
+    "Rwanda" : "Ruanda",
+    "Saudi Arabia" : "Arabia Saudita",
+    "Solomon Islands" : "Islas Salomón",
+    "Seychelles" : "Seychelles",
+    "Sudan" : "Sudán",
+    "Sweden" : "Suecia",
+    "Singapore" : "Singapur",
+    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Elena, Ascensión y Tristán de Acuña",
+    "Slovenia" : "Eslovenia",
+    "Svalbard and Jan Mayen" : "Svalbard y Jan Mayen",
+    "Slovakia" : "Eslovaquia",
+    "Sierra Leone" : "Sierra Leona",
+    "San Marino" : "San Marino",
+    "Senegal" : "Senegal",
+    "Somalia" : "Somalia",
+    "Suriname" : "Surinam",
+    "South Sudan" : "Sudán del Sur",
+    "Sao Tome and Principe" : "Santo Tomé y Príncipe",
+    "El Salvador" : "El Salvador",
+    "Turks and Caicos Islands" : "Islas Turcas y Caicos",
+    "Chad" : "Chad",
+    "Togo" : "Togo",
+    "Thailand" : "Tailandia",
+    "Tajikistan" : "Tayikistán",
+    "Tokelau" : "Tokelau",
+    "Timor-Leste" : "Timor Oriental",
+    "Turkmenistan" : "Turkmenistán",
+    "Tunisia" : "Túnez",
+    "Tonga" : "Tonga",
+    "Turkey" : "Turquía",
+    "Trinidad and Tobago" : "Trinidad y Tobago",
+    "Tuvalu" : "Tuvalu",
+    "Ukraine" : "Ucrania",
+    "Uganda" : "Uganda",
+    "United States Minor Outlying Islands" : "Islas menores alejadas de los Estados Unidos",
+    "Uruguay" : "Uruguay",
+    "Uzbekistan" : "Uzbekistán",
+    "Holy See" : "Santa Sede",
+    "Saint Vincent and the Grenadines" : "San Vicente y las Granadinas",
+    "Vanuatu" : "Vanuatu",
+    "Wallis and Futuna" : "Wallis and Futuna",
+    "Samoa" : "Samoa",
+    "Yemen" : "Yemen",
+    "Mayotte" : "Mayotte",
+    "South Africa" : "Sudáfrica",
+    "Zambia" : "Zambia",
+    "Zimbabwe" : "Zimbabue",
+    "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "This conversation has ended" : "Esta conversación ha terminado",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
+    "Saving …" : "Guardando ...",
     "Saved!" : "¡Guardado!",
-    "Name" : "Nombre",
-    "None" : "Ninguno",
-    "User" : "Usuario",
+    "Limit to groups" : "Limitar a grupos",
+    "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
-    "Users" : " Usuarios",
-    "General settings" : "Configuraciones generales",
+    "State" : "Estado",
+    "Name" : "Nombre",
+    "Description" : "Descripción",
+    "Beta" : "Beta",
+    "Permissions" : "Permisos",
     "@-mentions only" : "Solo menciones con @",
+    "Off" : "Desactivado",
+    "General settings" : "Configuraciones generales",
+    "Enable encryption" : "Habilitar encripción",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
+    "Active" : "Activo",
+    "Expired" : "Expirado",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
-    "Pending" : "Pendiente",
-    "Error" : "Error",
-    "Blocked" : "Bloqueado",
-    "Expired" : "Expirado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
     "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se está usando para determinar la IP pública de los participantes que estén detrás de un ruteador. ",
     "TURN server protocols" : "Protocolos del servidor TURN",
+    "Failed" : "Falló",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
-    "Back" : "Atrás",
+    "Federated user" : "Usuario federado",
     "Confirm" : "Confirmar",
     "Reset" : "Reiniciar",
+    "Back" : "Atrás",
     "Cancel" : "Cancelar",
-    "Copy link" : "Copiar liga",
+    "Loading …" : "Cargando …",
+    "No upcoming events" : "No hay eventos próximos",
+    "From" : "De",
+    "To" : "Para",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "Sin resultados",
+    "Done" : "Terminado",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
     "You" : "Tú",
     "Show screen" : "Mostrar pantalla",
     "Collapse" : "Colapsar",
+    "Drop your files to upload" : "Arrastre sus archivos para cargar",
     "Favorite" : "Hacer favorito",
-    "Description" : "Descripción",
+    "Date:" : "Fecha:",
+    "Note:" : "Nota:",
+    "Hide details" : "Ocultar detalles",
+    "Show details" : "Mostrar detalles",
+    "Disable" : "Deshabilitar",
+    "Enable" : "Activar",
+    "Choose" : "Seleccionar",
+    "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
-    "Permissions" : "Permisos",
+    "Meeting" : "Reunión",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
-    "Submit" : "Enviar",
+    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
+    "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
+    "Set a password" : "Establecer una contraseña",
     "Edit" : "Editar",
     "Delete" : "Eliminar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
+    "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
+    "Enter your name" : "Ingrese su nombre",
+    "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
-    "Loading" : "Cargando",
+    "Users" : " Usuarios",
     "Groups" : "Grupos",
-    "Circles" : "Círculos",
+    "Teams" : "Equipos",
+    "Clear filter" : "Limpiar filtro",
     "Unread mentions" : "Menciones sin leer",
-    "Password protect" : "Proteger con contraseña",
-    "Close" : "Cerrar",
-    "Conversation name" : "Nombre de la conversación",
+    "No search results" : "No hay resultados de búsqueda",
+    "None" : "Ninguno",
+    "Select a device" : "Seleccionar un dispositivo",
     "Devices" : "Dispositivos",
-    "Done" : "Terminado",
     "No audio" : "Sin audio",
+    "Invalid path selected" : "Ruta seleccionada no válida.",
+    "Blur" : "Difuminar",
     "Upload" : "Cargar",
     "Files" : "Archivos",
-    "Invalid path selected" : "Ruta seleccionada no válida.",
-    "Dismiss" : "Descartar",
+    "Set reminder for later today" : "Configurar recordatorio para hoy, más tarde",
+    "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
+    "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
+    "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
     "Reply" : "Responder",
+    "Set reminder" : "Establecer recordatorio",
     "Translate" : "Traducir",
+    "Dismiss" : "Descartar",
+    "Translate from" : "Traducir desde",
     "Contact" : "Contacto",
+    "Copy code block" : "Copiar bloque de código",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
-    "Group" : "Grupo",
+    "No messages" : "Sin mensajes",
+    "Share from Files" : "Compartir desde Archivos",
+    "Upload from device" : "Cargar desde el dispositivo",
     "Create new poll" : "Crear nueva encuesta",
+    "Smart picker" : "Selector inteligente",
     "New file" : "Archivo nuevo",
     "Blank" : "Vacío",
-    "Settings" : "Configuraciones ",
-    "Create poll" : "Crear encuesta",
+    "Add more files" : "Añadir más archivos",
     "Send" : "Enviar",
+    "Create poll" : "Crear encuesta",
+    "Settings" : "Configuraciones ",
     "moderator" : "moderador",
     "guest" : "invitado",
+    "Remove participant" : "Eliminar participante",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
-    "Remove participant" : "Eliminar participante",
-    "Searching …" : "Buscando  …",
-    "No results" : "Sin resultados",
+    "Remove" : "Borrar",
     "Add users or groups" : "Agregar usuarios o grupos",
+    "Searching …" : "Buscando  …",
+    "Search for more users" : "Buscar más usuarios",
     "Participants" : "Participantes",
     "Chat" : "Chat",
     "Details" : "Detalles",
+    "Load more results" : "Cargar más resultados",
+    "Projects" : "Proyectos",
+    "Edit display name" : "Editar el nombre para mostrar",
+    "Appearance" : "Apariencia",
     "Privacy" : "Privacidad",
+    "Performance" : "Desempeño",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Open sidebar" : "Abrir barra lateral",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -218,14 +471,30 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
+    "Exit full screen (F)" : "Salir de pantalla completa (F)",
     "Grid view" : "Vista de cuadrícula",
-    "No unread mentions" : "No hay menciones sin leer",
+    "Submit" : "Enviar",
     "Join a conversation or start a new one" : "Únete a la conversación o incia una nueva",
+    "Talk conversation" : "Conversación de Talk",
+    "User" : "Usuario",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Media" : "Multimedia",
     "Polls" : "Encuestas",
     "Locations" : "Ubicaciones",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Show all files" : "Mostrar todos los archivos",
+    "Group" : "Grupo",
+    "Team" : "Equipo",
+    "Error while sharing file" : "Error al compartir el archivo",
+    "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Do not disturb" : "No molestar",
     "Away" : "Ausente",
     "Default" : "Predeterminado",
@@ -236,13 +505,27 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "%s Talk on your mobile devices" : "%s Habla en tus dispositivos móviles",
     "Android app" : "Aplicación Android",
     "iOS app" : "Aplicación iOS",
-    "More actions" : "Más acciones",
-    "Rename conversation" : "Renombrar conversación"
+    "__language_name__" : "Español (México)",
+    "Tasks" : "Tareas",
+    "Notes" : "Notas",
+    "Reports" : "Informes",
+    "There are currently no commands available." : "No hay comandos disponibles actualmente",
+    "The command does not exist" : "El comando no existe",
+    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ocurrió un error al ejecutar el comando. Por favor solicite al administrador revisar los logs",
+    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Llamada con %n invitado (Duración {duration})","Llamada con %n invitados (Duración {duration})","Llamada con %n invitados (Duración {duration})"],
+    "Call with {user1} and {user2} (Duration {duration})" : "Llamada con {user1} y {user2} (Duración {duration})",
+    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} (Duración {duration})",
+    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
+    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
+    "Command" : "Comando",
+    "Loading" : "Cargando",
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
+    "TURN server" : "Servidor TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
