@@ -17,29 +17,33 @@ OC.L10N.register(
     "Invalid file provided" : "Archivo proporcionado inválido",
     "Invalid image" : "Imagen inválida",
     "Unknown filetype" : "Tipo de archivo desconocido",
+    "Accept" : "Aceptar",
+    "Decline" : "Declinar",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
     "Avatar image is not square" : "La imagen del avatar no es un cuadrado",
+    "Federation" : "Federación",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, por favor sigue el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
-    "Limit to groups" : "Limitar a grupos",
     "Everyone" : "Todos",
     "Save changes" : "Guardar cambios",
     "Saved!" : "¡Guardado!",
-    "Name" : "Nombre",
-    "None" : "Ninguno",
-    "User" : "Usuario",
+    "Limit to groups" : "Limitar a grupos",
+    "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
-    "Users" : "Usuarios",
+    "Name" : "Nombre",
+    "Description" : "Descripción",
+    "Permissions" : "Permisos",
     "General settings" : "Configuraciones generales",
+    "Enable encryption" : "Habilitar encripción",
+    "Pending" : "Pendiente",
+    "Error" : "Error",
+    "Blocked" : "Bloqueado",
     "Language" : "Idioma",
     "Country" : "País",
     "Status" : "Estatus",
     "Created at" : "Creado en",
-    "Pending" : "Pendiente",
-    "Error" : "Error",
-    "Blocked" : "Bloqueado",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Secreto compartido",
     "STUN servers" : "Servidores STUN",
@@ -47,14 +51,18 @@ OC.L10N.register(
     "TURN server protocols" : "Protocolos del servidor TURN",
     "OK" : "OK",
     "Checking …" : "Verificando ...",
-    "Back" : "Atrás",
     "Confirm" : "Confirmar",
     "Reset" : "Restablecer",
+    "Back" : "Atrás",
     "Cancel" : "Cancelar",
-    "Copy link" : "Copiar liga",
+    "Calendar" : "Calendario",
+    "Attendees" : "Asistentes",
+    "Save" : "Guardar",
+    "No results" : "No hay resultados",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "Share this link to invite others!" : "¡Comparte esta liga para invitar a otras personas!",
+    "Copy link" : "Copiar liga",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
     "Enable video" : "Habilitar el video",
@@ -62,47 +70,40 @@ OC.L10N.register(
     "Show screen" : "Mostrar pantalla",
     "Collapse" : "Colapsar",
     "Favorite" : "Hacer favorito",
-    "Description" : "Descripción",
+    "Hide details" : "Ocultar detalles",
+    "Disable" : "Deshabilitar",
+    "Choose" : "Seleccionar",
     "Restricted" : "Restringido",
     "Personal" : "Personal",
-    "Permissions" : "Permisos",
-    "Submit" : "Enviar",
     "Password protection" : "Protección con contraseña",
-    "Save" : "Guardar",
     "Edit" : "Editar",
     "Delete" : "Borrar",
-    "Password" : "Contraseña",
-    "API token" : "Ficha del API",
-    "Login" : "Iniciar sesión",
-    "Nickname" : "Apodo",
-    "Client ID" : "ID del cliente",
+    "Log content" : "Contenido de bitácoras",
     "Notifications" : "Notificaciones",
+    "Log in" : "Ingresar",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a tus favoritos",
-    "Loading" : "Cargando",
+    "Users" : "Usuarios",
     "Groups" : "Grupos",
-    "Circles" : "Círculos",
-    "Password protect" : "Proteger con contraseña",
-    "Close" : "Cerrar",
+    "None" : "Ninguno",
     "Devices" : "Dispositivos",
     "Upload" : "Cargar",
     "Files" : "Archivos",
-    "Dismiss" : "Descartar",
     "Reply" : "Responder",
     "Translate" : "Traducir",
+    "Dismiss" : "Descartar",
     "Contact" : "Contacto",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
-    "Group" : "Grupo",
+    "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
     "Create new poll" : "Crear nueva encuesta",
-    "Settings" : "Configuraciones ",
-    "Create poll" : "Crear encuesta",
     "Send" : "Enviar",
+    "Create poll" : "Crear encuesta",
+    "Settings" : "Configuraciones ",
     "moderator" : "moderador",
+    "Remove participant" : "Eliminar participante",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
-    "Remove participant" : "Eliminar participante",
-    "No results" : "No hay resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
@@ -110,9 +111,6 @@ OC.L10N.register(
     "Privacy" : "Privacidad",
     "Keyboard shortcuts" : "Atajos del teclado",
     "Search" : "Buscar",
-    "Open sidebar" : "Abrir barra lateral",
-    "Show your screen" : "Mostrar tu pantalla",
-    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
@@ -120,11 +118,22 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor usa un navegador diferente como Firefox o Chrome para compartir tu pantalla.",
     "An error occurred while starting screensharing." : "Se presentó un error al comenzar a compartir la pantalla. ",
+    "Show your screen" : "Mostrar tu pantalla",
+    "Stop screensharing" : "Dejar de compartir la pantalla",
     "Grid view" : "Vista de cuadrícula",
+    "Submit" : "Enviar",
+    "User" : "Usuario",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Polls" : "Encuestas",
     "Locations" : "Ubicaciones",
     "Audio" : "Audio",
     "Other" : "Otro",
+    "Group" : "Grupo",
+    "Please reload the page." : "Por favor vuelve a cargar la página.",
     "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
@@ -132,11 +141,15 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "TURN server" : "Servidor TURN",
-    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
     "Android app" : "Aplicación android",
     "iOS app" : "Aplicación iOS",
-    "More actions" : "Más acciones"
+    "__language_name__" : "Español (Paraguay)",
+    "Tasks" : "Tareas",
+    "Loading" : "Cargando",
+    "Close" : "Cerrar",
+    "Password protect" : "Proteger con contraseña",
+    "TURN server" : "Servidor TURN",
+    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
