@@ -4,99 +4,129 @@ OC.L10N.register(
     "_%n guest_::_%n guests_" : ["%n külaline","%n külalist"],
     "Talk" : "Talk",
     "Guest" : "Külaline",
+    "Message deleted by author" : "Sõnum autori poolt kustutatud",
     "File is too big" : "Fail on liiga suur",
     "Invalid file provided" : "Vigane fail",
     "Invalid image" : "Vigane pilt",
     "Unknown filetype" : "Tundmatu failitüüp",
+    "Accept" : "Nõustu",
+    "Decline" : "Keeldu",
+    "error" : "viga",
     "Avatar image is not square" : "Avatari pilt pole ruut",
+    "Federation" : "Liidendus",
     "Invalid date, date format must be YYYY-MM-DD" : "Vigane kuupäev, formaat peab olema YYYY-MM-DD",
-    "Limit to groups" : "Luba gruppidele",
     "Everyone" : "Igaüks",
     "Save changes" : "Salvesta muudatused",
     "Saving …" : "Salvestamine …",
     "Saved!" : "Salvestatud!",
-    "Name" : "Nimi",
-    "None" : "Pole",
-    "User" : "Kasutaja",
+    "Limit to groups" : "Luba gruppidele",
+    "Enabled" : "Sisse lülitatud",
     "Disabled" : "Keelatud",
-    "Users" : "Kasutajad",
-    "Language" : "Keel",
-    "Country" : "Riik",
-    "Status" : "Staatus",
-    "Created at" : "Loodud",
+    "Name" : "Nimi",
+    "Description" : "Kirjeldus",
+    "Enable encryption" : "Luba krüpteerimine",
     "Pending" : "Ootel",
     "Error" : "Viga",
     "Blocked" : "Blokeeritud",
     "Expired" : "Aegunud",
+    "Language" : "Keel",
+    "Country" : "Riik",
+    "Status" : "Staatus",
+    "Created at" : "Loodud",
     "Delete this server" : "Kustuta see server",
     "OK" : "OK",
-    "Back" : "Tagasi",
     "Confirm" : "Kinnita",
     "Reset" : "Lähtesta",
+    "Back" : "Tagasi",
     "Cancel" : "Loobu",
+    "Loading …" : "Laadimine ...",
+    "No upcoming events" : "Tulekul sündmuseid pole",
+    "From" : "Saatja",
+    "To" : "Saaja",
+    "Calendar" : "Kalender",
+    "Attendees" : "Osalejad",
+    "Save" : "Salvesta",
+    "No results" : "Vasteid ei leitud",
+    "Done" : "Valmis",
     "Copy link" : "Kopeeri link",
     "You" : "Sina",
     "Collapse" : "Sulge",
     "Favorite" : "Lemmik",
-    "Description" : "Kirjeldus",
+    "Date:" : "Kuupäev:",
+    "Hide details" : "Peida üksikasjad",
+    "Show details" : "Näita üksikasju",
+    "Disable" : "Lülita välja",
+    "Choose" : "Vali",
     "Restricted" : "Piiratud",
     "Personal" : "Isiklik",
-    "Submit" : "Saada",
     "Password protection" : "Password protection",
-    "Save" : "Salvesta",
     "Edit" : "Redigeeri",
     "Delete" : "Kustuta",
+    "Log content" : "Logi sisu",
+    "Notifications" : "Teavitused",
+    "Log in" : "Logi sisse",
+    "Remove from favorites" : "Eemalda lemmikutest",
+    "Add to favorites" : "Lisa lemmikutesse",
+    "Users" : "Kasutajad",
+    "Groups" : "Grupid",
+    "Teams" : "Tiimid",
+    "None" : "Pole",
+    "Select a device" : "Vali seade",
+    "Devices" : "Seadmed",
+    "Blur" : "Hägusus",
+    "Upload" : "Lae üles",
+    "Files" : "Failid",
+    "Reply" : "Vasta",
+    "Translate" : "Tõlgi",
+    "Dismiss" : "Jäta vahele",
+    "Copy translated text" : "Kopeeri tõlgitud tekst",
+    "Contact" : "Kontakt",
+    "Today" : "Täna",
+    "Yesterday" : "Eile",
+    "_%n day ago_::_%n days ago_" : ["%n päev tagasi","%n päeva tagasi"],
+    "Upload from device" : "Laadi üles seadmest",
+    "Create new poll" : "Loo uus küsitlus",
+    "New file" : "Uus fail",
+    "Blank" : "Tühi",
+    "Send" : "Saada",
+    "Create poll" : "Loo küsitlus",
+    "Settings" : "Seaded",
+    "Anonymous poll" : "Anonüümne küsitlus",
+    "guest" : "külaline",
+    "Add users or groups" : "Add users or groups",
+    "Searching …" : "Otsin ...",
+    "Participants" : "Osalejad",
+    "Details" : "Üksikasjad",
+    "Privacy" : "Privaatsus",
+    "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Search" : "Otsi",
+    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
+    "Grid view" : "Ruudustikvaade",
+    "Submit" : "Saada",
+    "Talk conversation" : "Talk suhtlus",
+    "User" : "Kasutaja",
     "Password" : "Parool",
     "API token" : "API kood",
     "Login" : "Logi sisse",
     "Nickname" : "Hüüdnimi",
     "Client ID" : "Kliendi ID",
-    "Notifications" : "Teavitused",
-    "Remove from favorites" : "Eemalda lemmikutest",
-    "Add to favorites" : "Lisa lemmikutesse",
-    "Loading" : "Laadimine",
-    "Groups" : "Grupid",
-    "Password protect" : "Parooliga kaitsmine",
-    "Close" : "Sulge",
-    "Devices" : "Seadmed",
-    "Done" : "Valmis",
-    "Upload" : "Lae üles",
-    "Files" : "Failid",
-    "Dismiss" : "Jäta vahele",
-    "Reply" : "Vasta",
-    "Translate" : "Tõlgi",
-    "Copy translated text" : "Kopeeri tõlgitud tekst",
-    "Contact" : "Kontakt",
-    "Today" : "Täna",
-    "Yesterday" : "Eile",
-    "Group" : "Grupp",
-    "Create new poll" : "Loo uus küsitlus",
-    "New file" : "Uus fail",
-    "Blank" : "Tühi",
-    "Settings" : "Seaded",
-    "Create poll" : "Loo küsitlus",
-    "Send" : "Saada",
-    "guest" : "külaline",
-    "Searching …" : "Otsin ...",
-    "No results" : "Vasteid ei leitud",
-    "Add users or groups" : "Add users or groups",
-    "Details" : "Üksikasjad",
-    "Privacy" : "Privaatsus",
-    "Keyboard shortcuts" : "Klaviatuuri otseteed",
-    "Search" : "Otsi",
-    "Open sidebar" : "Ava külgriba",
-    "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
-    "Grid view" : "Ruudustikvaade",
     "Media" : "Meedia",
     "Polls" : "Küsitlused",
     "Locations" : "Asukohad",
     "Audio" : "Helid",
     "Other" : "Muu",
+    "Group" : "Grupp",
+    "Please reload the page." : "Palun laadi leht uuesti.",
     "Do not disturb" : "Mitte segada",
     "Away" : "Eemal",
     "Default" : "Vaikeväärtus",
     "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
     "Android app" : "Androidi rakendus",
-    "iOS app" : "iOS-i rakendus"
+    "iOS app" : "iOS-i rakendus",
+    "__language_name__" : "Eesti",
+    "Tasks" : "Ülesanded",
+    "Loading" : "Laadimine",
+    "Close" : "Sulge",
+    "Password protect" : "Parooliga kaitsmine"
 },
 "nplurals=2; plural=(n != 1);");
