@@ -14,8 +14,6 @@ OC.L10N.register(
     "Other activities" : "Aktivitas lain",
     "Talk" : "Talk",
     "Guest" : "Tamu",
-    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Selamat datang di Nextcloud Talk!\nDalam percakapan ini Anda akan diberitahu tentang fitur baru yang tersedia di Nextcloud Talk.",
-    "New in Talk %s" : "Terbaru di Talk %s",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge dan Safari sekarang dapat digunakan untuk berpartisipasi dalam panggilan audio dan video",
     "- You can now notify all participants by posting \"@all\" into the chat" : "- Sekarang Anda dapat memberi tahu semua peserta dengan memposting \"@all\" ke dalam obrolan",
     "- With the \"arrow-up\" key you can repost your last message" : "- Dengan tombol \"panah-atas\" Anda dapat memposting ulang pesan terakhir Anda",
@@ -23,12 +21,17 @@ OC.L10N.register(
     "- You can now mention guests in the chat" : "- Anda sekarang dapat menyebut tamu di obrolan",
     "{actor} created the conversation" : "{actor} membuat sebuah percakapan",
     "You created the conversation" : "Anda membuat sebuah percakapan",
+    "Message deleted by author" : "Pesan dihapus oleh penyusun",
     "File is too big" : "Berkas terlalu besar",
     "Invalid file provided" : "Berkas tidak valid",
     "Invalid image" : "Gambar tidak valid",
     "Unknown filetype" : "Tipe berkas tak dikenal",
+    "Say hi to your friends and colleagues!" : "Katakan halo kepada teman dan kolega Anda!",
     "You were mentioned" : "Anda disebutkan",
     "Dismiss notification" : "Abaikan notifikasi",
+    "Accept" : "Terima",
+    "Decline" : "Tolak",
+    "error" : "galat",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Uni Emirat Arab",
     "Afghanistan" : "Afganistan",
@@ -245,102 +248,133 @@ OC.L10N.register(
     "South Africa" : "Afrika Selatan",
     "Zambia" : "Zambia",
     "Zimbabwe" : "Zimbabwe",
+    "Federation" : "Federasi",
     "Invalid date, date format must be YYYY-MM-DD" : "Tanggal salah, format tanggal harus TTTT-BB-HH",
     "Request password" : "Minta kata sandi",
-    "Limit to groups" : "Batasi ke grup",
     "Everyone" : "Semua orang",
     "Save changes" : "Simpan perubahan",
     "Saving …" : "Menyimpan ...",
-    "Name" : "Nama",
-    "None" : "Tidak ada",
-    "User" : "Pengguna",
+    "Limit to groups" : "Batasi ke grup",
+    "Enabled" : "Diaktifkan",
     "Disabled" : "Dinonaktifkan",
-    "Users" : "Pengguna",
+    "State" : "Kondisi",
+    "Name" : "Nama",
+    "Description" : "Deskrisi",
     "Off" : "Nonaktif",
+    "Enable encryption" : "Aktifkan enkripsi",
+    "Pending" : "Tunggu",
+    "Error" : "Kesalahan",
     "Language" : "Bahasa",
     "Country" : "Negara",
     "Status" : "Status",
     "Created at" : "Dibuat saat",
-    "Pending" : "Tunggu",
-    "Error" : "Kesalahan",
+    "Failed" : "Gagal",
     "OK" : "OK",
-    "Back" : "Kembali",
     "Confirm" : "Konfirmasi",
     "Reset" : "Setel ulang",
+    "Back" : "Kembali",
     "Cancel" : "Membatalkan",
+    "No upcoming events" : "Tdak ada acara mendatang",
+    "Calendar" : "Kalender",
+    "Attendees" : "Peserta",
+    "Save" : "Simpan",
+    "No results" : "Tidak ada hasil",
+    "Done" : "Selesai",
     "Copy link" : "Salin tautan",
     "Collapse" : "Tutup",
+    "Expand" : "Perluas",
     "Drop your files to upload" : "Lepas berkas Anda untuk mengunggah",
     "Favorite" : "Favorit",
-    "Description" : "Deskrisi",
+    "Date:" : "Tanggal:",
+    "Hide details" : "Sembunyikan detail",
+    "Show details" : "Tampilkan detail",
+    "Disable" : "Nonaktifkan",
+    "Enable" : "Aktifkan",
+    "Choose" : "Pilih",
     "Restricted" : "Terbatas",
     "Personal" : "Pribadi",
     "Meeting" : "Rapat",
     "Password protection" : "Password protection",
-    "Save" : "Simpan",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
-    "Password" : "Kata kunci",
-    "Login" : "Log masuk",
-    "Nickname" : "Nama panggilan",
-    "Client ID" : "ID Klien",
     "Notifications" : "Pemberitahuan",
+    "Log in" : "Masuk",
     "Mark as read" : "tandai sudah dibaca",
+    "Mark as unread" : "Tandai belum dibaca",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Tambah ke favorit",
-    "Loading" : "Memuat",
+    "Users" : "Pengguna",
     "Groups" : "Grup",
-    "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
-    "Password protect" : "Lindungi dengan kata sandi",
-    "Create conversation" : "Buat percakapan",
-    "Add participants" : "Tambahkan peserta",
-    "Close" : "Tutup",
-    "Conversation name" : "Nama percakapan",
-    "Done" : "Selesai",
+    "Clear filter" : "Bersihkan filter",
+    "No search results" : "Tidak ada hasil pencarian",
+    "None" : "Tidak ada",
+    "Invalid path selected" : "Jalur terpilih invalid",
     "Upload" : "Unggah",
     "Files" : "Berkas",
-    "Invalid path selected" : "Jalur terpilih invalid",
     "Unread messages" : "Pesan belum dibaca",
-    "Dismiss" : "Batal",
     "Reply" : "Balas",
     "Translate" : "Terjemahkan",
+    "Dismiss" : "Batal",
+    "Contact" : "Kontak",
     "Today" : "Hari ini",
     "Yesterday" : "Kemarin",
-    "Group" : "Grup",
+    "_%n day ago_::_%n days ago_" : ["%n hari yang lalu"],
+    "Create conversation" : "Buat percakapan",
+    "Add participants" : "Tambahkan peserta",
+    "Allow guests to join via link" : "Izinkan tamu untuk bergabung melalui tautan",
     "New file" : "File baru",
     "Blank" : "Kosong",
-    "Settings" : "Setelan",
     "Send" : "Kirim",
+    "Settings" : "Setelan",
     "Join" : "Gabung",
     "guest" : "pengunjung",
-    "No results" : "Tidak ada hasil",
+    "Remove" : "Hapus",
     "Add users or groups" : "Add users or groups",
+    "Integrations" : "Integrasi",
     "Search or add participants" : "Cari atau tambah peserta",
     "An error occurred while adding the participants" : "Terjadi kesalahan saat menambahkan peserta",
+    "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
     "Details" : "Detail",
+    "Load more results" : "Muat lebih banyak hasil",
     "Projects" : "Proyek",
     "Search conversations or users" : "Cari percakapan atau pengguna",
     "Choose devices" : "Pilih perangkat",
     "Attachments folder" : "Folder lampiran",
+    "Appearance" : "Tampilan",
     "Privacy" : "Privasi",
+    "Performance" : "Performa",
     "Keyboard shortcuts" : "Pintasan keyboard",
     "Search" : "Cari",
-    "Open sidebar" : "Buka jendela samping",
-    "You have new unread messages in the chat." : "Anda memiliki pesan baru yang belum dibaca dalam obrolan.",
     "Grid view" : "Tampilan kotak",
-    "Say hi to your friends and colleagues!" : "Katakan halo kepada teman dan kolega Anda!",
     "Join a conversation or start a new one!" : "Gabung dengan percakapan atau mulai yang baru!",
     "Join a conversation or start a new one" : "Gabung dengan percakapan atau mulai yang baru",
+    "User" : "Pengguna",
+    "Password" : "Kata kunci",
+    "API token" : "Token API",
+    "Login" : "Log masuk",
+    "Nickname" : "Nama panggilan",
+    "Client ID" : "ID Klien",
     "Media" : "Media",
     "Locations" : "Lokasi",
     "Audio" : "Audio",
     "Other" : "Lainnya",
+    "Show all files" : "Tampilkan semua berkas",
+    "Group" : "Grup",
+    "Please reload the page." : "Silakan muat ulang halaman.",
     "Do not disturb" : "Jangan diganggu",
     "Away" : "Jauh",
     "Default" : "Bawaan",
     "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
     "Android app" : "Aplikasi Android",
     "iOS app" : "Aplikasi iOS",
-    "Rename conversation" : "Ganti nama percakapan"
+    "__language_name__" : "Bahasa Indonesia",
+    "Call summary (%s)" : "Ringkasan panggilan ( %s )",
+    "Tasks" : "Tugas",
+    "Notes" : "Catatan",
+    "Reports" : "Laporan",
+    "Call summary - {title}" : "Ringkasan panggilan - {judul}",
+    "Loading" : "Memuat",
+    "Close" : "Tutup",
+    "Password protect" : "Lindungi dengan kata sandi"
 },
 "nplurals=1; plural=0;");
