@@ -348,59 +348,70 @@ OC.L10N.register(
     "Request password" : "Biðja um lykilorð",
     "Error requesting the password." : "Villa kom upp við að biðja um lykilorð.",
     "This conversation has ended" : "Þessu samtali er lokið",
-    "Limit to groups" : "Takmarka við hópa",
-    "Guests can still join public conversations." : "Gestir geta komið inn í opinber samtöl.",
     "Everyone" : "Allir",
     "Users and moderators" : "Notendur og umsjónarmenn",
     "Moderators only" : "Aðeins umsjónarmenn",
     "Save changes" : "Vista breytingar",
     "Saving …" : "Vista …",
     "Saved!" : "Vistað!",
+    "Limit to groups" : "Takmarka við hópa",
+    "Guests can still join public conversations." : "Gestir geta komið inn í opinber samtöl.",
+    "Enabled" : "Virkt",
+    "Disabled" : "Óvirkt",
     "State" : "Staða",
     "Name" : "Nafn",
     "Description" : "Lýsing",
-    "Enabled" : "Virkt",
-    "Disabled" : "Óvirkt",
     "Beta" : "BETA-prófunarútgáfa",
     "Permissions" : "Heimildir",
-    "General settings" : "Almennar stillingar",
     "All messages" : "Öll skilaboð",
     "@-mentions only" : "@-mentions only",
     "Off" : "Slökkt",
-    "Language" : "Tungumál",
-    "Country" : "Country",
-    "Status" : "Staða",
-    "Created at" : "Búið til",
+    "General settings" : "Almennar stillingar",
+    "Enable encryption" : "Virkja dulritun",
     "Pending" : "Í bið",
     "Error" : "Villa",
     "Blocked" : "Útilokaður",
     "Active" : "Virkt",
     "Expired" : "Útrunnið",
+    "Language" : "Tungumál",
+    "Country" : "Country",
+    "Status" : "Staða",
+    "Created at" : "Búið til",
     "Validate SSL certificate" : "Sannreyna SSL-skilríki",
     "Delete this server" : "Eyða þessum þjóni",
+    "Test this server" : "Prófa þennan þjón",
     "Shared secret" : "Sameiginlegur leynilykill",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
     "STUN server URL" : "URL-slóð STUN-þjóns",
     "STUN servers" : "STUN-þjónar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN-miðlari er notaður til að ákvarða opinbert vistfang þátttakenda á bak við beini.",
     "TURN server URL" : "URL-slóð TURN-þjóns",
     "TURN server secret" : "Leynilykill á TURN-miðlara",
     "TURN server protocols" : "Samskiptareglur TURN-þjóns",
-    "Test this server" : "Prófa þennan þjón",
     "TURN servers" : "TURN-miðlarar",
     "OK" : "Í lagi",
     "Checking …" : "Athuga …",
-    "Back" : "Til baka",
-    "Cancel" : "Hætta við",
+    "Federated user" : "Notandi í skýjasambandi",
     "Confirm" : "Staðfesta",
     "Reset" : "Endurstilla",
+    "Back" : "Til baka",
+    "Cancel" : "Hætta við",
+    "Now" : "Núna",
+    "Loading …" : "Hleð inn …",
+    "No upcoming events" : "Engir atburðir á næstunni",
+    "From" : "Frá",
+    "To" : "Til",
+    "Calendar" : "Dagatal",
+    "Attendees" : "Þátttakendur",
+    "Save" : "Vista",
+    "No results" : "Engar niðurstöður",
+    "Done" : "Lokið",
     "This conversation is read-only" : "This conversation is read-only",
-    "Copy link" : "Afrita tengil",
     "Connecting …" : "Tengist ...",
     "Waiting for others to join the call …" : "Bíð eftir að fleiri komi inn í símtalið …",
     "You can invite others in the participant tab of the sidebar" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Þú getur boðið öðrum að taka þátt af þátttakendaflipa hliðarspjaldsins eða deilt þessum tengli til að bjóða öðrum!",
     "Share this link to invite others!" : "Deildu þessum tengli til að bjóða öðrum!",
+    "Copy link" : "Afrita tengil",
     "Mute audio" : "Þagga hljóð",
     "You have been muted by a moderator" : "You have been muted by a moderator",
     "Disable video" : "Gera myndskeið óvirk",
@@ -408,112 +419,133 @@ OC.L10N.register(
     "You" : "Þú",
     "Show screen" : "Birta skjá",
     "Collapse" : "Fella saman",
+    "Expand" : "Fletta út",
     "Drop your files to upload" : "Slepptu skrám til að senda þær inn",
     "Favorite" : "Eftirlæti",
-    "Loading …" : "Hleð inn …",
-    "Hide details" : "Fela nánari upplýsingar",
-    "Show details" : "Birta nánari upplýsingar",
     "Date:" : "Dagsetning:",
     "Note:" : "Athugaðu:",
+    "Hide details" : "Fela nánari upplýsingar",
+    "Show details" : "Birta nánari upplýsingar",
     "Disable" : "Gera óvirkt",
-    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
     "Choose" : "Velja",
+    "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
     "Restricted" : "Takmarkað",
     "Personal" : "Persónulegt",
     "Meeting" : "Fundur",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
+    "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
     "Password protection" : "Verndun með lykilorði",
+    "Set a password" : "Setja lykilorð",
     "Start time (optional)" : "Upphafstími (valfrjálst)",
-    "Save" : "Vista",
     "Edit" : "Breyta",
     "More information" : "Nánari upplýsingar",
     "Delete" : "Eyða",
     "Log content" : "Efni atvikaskrár",
     "Notifications" : "Tilkynningar",
     "Enter your name" : "Settu inn nafnið þitt",
-    "Login" : "Innskráning",
+    "Log in" : "Skrá inn",
     "Mark as read" : "Merkja sem lesið",
     "Mark as unread" : "Merkja allt sem ólesið",
     "Remove from favorites" : "Fjarlægja úr eftirlætum",
     "Add to favorites" : "Bæta í eftirlæti",
     "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
-    "Clear filter" : "Hreinsa síu",
     "No matches found" : "Engar samsvaranir fundust",
-    "New group conversation" : "Nýtt hópsamtal…",
     "Users" : "Notendur",
     "Groups" : "Hópar",
+    "Teams" : "Teymi",
+    "Create a new conversation" : "Hefja nýtt samtal",
+    "Clear filter" : "Hreinsa síu",
+    "New group conversation" : "Nýtt hópsamtal…",
     "No search results" : "Engar leitarniðurstöður",
-    "Loading" : "Hleð inn",
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
     "None" : "Enginn",
+    "Select a device" : "Veldu tæki",
     "Devices" : "Tæki",
     "No audio" : "Ekkert hljóð",
+    "Invalid path selected" : "Ógild slóð valin",
     "Blur" : "Móða",
     "Upload" : "Senda inn",
     "Files" : "Skrár",
-    "Invalid path selected" : "Ógild slóð valin",
-    "Unread messages" : "Ólesin skilaboð",
     "Message sent" : "Skilaboðin hafa verið send",
+    "Unread messages" : "Ólesin skilaboð",
+    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
+    "Set reminder for later today" : "Setja áminningu seinna í dag",
+    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
+    "Set reminder for tomorrow" : "Setja áminningu fyrir morgundaginn",
+    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
+    "Set reminder for this weekend" : "Setja áminningu fyrir þessa helgi",
+    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
+    "Set reminder for next week" : "Setja áminningu fyrir í næstu viku",
     "Reply" : "Svara",
     "Set reminder" : "Setja áminningu",
+    "Edit message" : "Breyta skilaboðum",
     "Copy message link" : "Afrita skilaboðatengil",
     "Go to file" : "Fara í skrá",
     "Translate" : "Þýða",
     "Dismiss" : "Hafna",
+    "The message could not be translated" : "Ekki var hægt að þýða skilaboðin",
+    "Translation copied to clipboard" : "Þýðing afrituð á klippispjald",
+    "Translation could not be copied" : "Ekki tókst að afrita þýðinguna",
+    "Translate message" : "Þýða skilaboð",
+    "Source language to translate from" : "Upprunatungumál til að þýða af",
     "Translate from" : "Þýða úr",
+    "Target language to translate into" : "Marktungumál til að þýða yfir á",
+    "Translate to" : "Þýða yfir á",
+    "Translating" : "Þýðing",
+    "Copy translated text" : "Afrita þýddan texta",
     "Contact" : "Tengiliður",
     "{stack} in {board}" : "{stack} á {board}",
+    "Copy code block" : "Afrita kóðablokk",
     "Poll" : "Poll",
-    "No messages" : "Engin skilaboð",
     "Today" : "Í dag",
     "Yesterday" : "Í gær",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["fyrir %n degi síðan","fyrir %n dögum síðan"],
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "No messages" : "Engin skilaboð",
     "Create a new group conversation" : "Create a new group conversation",
     "Add participants" : "Bæta við þátttakanda",
-    "Close" : "Loka",
-    "Password protect" : "Verja með lykilorði",
     "Enter password" : "Enter password",
-    "File to share" : "Skrá til að deila",
     "Send message" : "Senda skilaboð",
+    "Add emoji" : "Bæta við tjáningartákni",
+    "File to share" : "Skrá til að deila",
+    "Share from Files" : "Deila úr skrám",
     "Upload from device" : "Senda inn frá tæki",
     "Create new poll" : "Búa til nýja könnun",
     "Smart picker" : "Snjall-veljari",
-    "Share from Files" : "Deila úr skrám",
     "New file" : "Ný skrá",
     "Blank" : "Tóm",
+    "Send" : "Senda",
+    "Create poll" : "Búa til könnun",
     "Settings" : "Stillingar",
     "Anonymous poll" : "Nafnlaus könnun",
-    "Create poll" : "Búa til könnun",
-    "Send" : "Senda",
     "End poll" : "End poll",
     "Join" : "Taka þátt",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
+    "Remove participant" : "Fjarlægja þátttakanda",
     "Demote from moderator" : "Láta hætta sem umsjónarmann",
     "Promote to moderator" : "Gera að umsjónarmanni",
-    "Remove participant" : "Fjarlægja þátttakanda",
+    "Remove" : "Fjarlægja",
+    "Add users or groups" : "Bæta við notendum eða hópum",
     "Integrations" : "Samþættingar",
     "Searching …" : "Leita …",
-    "No results" : "Engar niðurstöður",
-    "Add users or groups" : "Bæta við notendum eða hópum",
     "Participants" : "Þátttakendur",
+    "Open chat" : "Opna spjall",
     "Chat" : "Spjall",
     "Details" : "Details",
-    "Open chat" : "Opna spjall",
+    "Load more results" : "Hlaða inn fleiri niðurstöðum",
     "Projects" : "Verkefni",
     "No shared items" : "No shared items",
-    "Select conversation" : "Veldu samtal",
     "Link to a conversation" : "Tengill á samtal",
+    "Select conversation" : "Veldu samtal",
     "Edit display name" : "Breyta birtingarnafni",
+    "Appearance" : "Útlit",
     "Privacy" : "Gagnaleynd",
     "Performance" : "Afköst",
     "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
     "Search" : "Search",
     "Start call" : "Hefja samtal",
-    "Show your screen" : "Birta skjáinn þinn",
-    "Stop screensharing" : "Hætta skjádeilingu",
     "Screensharing options" : "Valkostir skjádeilingar",
     "Enable screensharing" : "Virkja skjádeilingu",
     "Screensharing requires the page to be loaded through HTTPS." : "Deiling á skjá krefst þess að síðunni sé hlaðið inn með HTTPS.",
@@ -521,21 +553,21 @@ OC.L10N.register(
     "Screensharing extension is required to share your screen." : "Það þarf skjádeili-viðaukann til að hægt sé að deila skjánum.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Veldu einhvern annan vafra eins og Firefox eða Chrome til að deila skjánum þínum.",
     "An error occurred while starting screensharing." : "Villa kom upp við að hefja skjádeilingu.",
+    "Show your screen" : "Birta skjáinn þinn",
+    "Stop screensharing" : "Hætta skjádeilingu",
     "Grid view" : "Reitasýn",
     "Select a region" : "Veldu svæði",
     "Submit" : "Senda inn",
     "Duplicate session" : "Duplicate session",
     "Join a conversation or start a new one" : "Taktu þátt í samtali eða byrjaðu nýtt samtal",
-    "Next week – {timeLocale}" : "Í næstu viku – {timeLocale}",
-    "This weekend – {timeLocale}" : "Þessa helgi – {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
-    "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
     "Talk conversation" : "Samtal í Talk-spjalli",
     "User" : "Notandi",
     "Password" : "Lykilorð",
     "API token" : "API-teikn",
+    "Login" : "Innskráning",
     "Nickname" : "Stuttnefni",
     "Client ID" : "Biðlaraauðkenni",
+    "Team ID" : "Auðkenni teymis",
     "Media" : "Margmiðlunargögn",
     "Polls" : "Kannanir",
     "Locations" : "Staðsetningar",
@@ -543,7 +575,10 @@ OC.L10N.register(
     "Other" : "Annað",
     "Show all files" : "Sýna allar skrár",
     "Group" : "Hópur",
+    "Team" : "Teymi",
     "Error while sharing file" : "Villa við deilingu skráar",
+    "Error while parsing a PROPFIND error" : "Villa við þáttun á PROPFIND-villu",
+    "Please reload the page." : "Þú ættir að hlaða síðunni aftur inn.",
     "Do not disturb" : "Ónáðið ekki",
     "Away" : "Fjarverandi",
     "Default" : "Sjálfgefið",
@@ -557,20 +592,25 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Talaðu á snjalltækjunum þínum",
     "Android app" : "Android-forrit",
     "iOS app" : "iOS-forrit",
+    "__language_name__" : "Íslenska",
+    "Tasks" : "Verkefni",
+    "Notes" : "Minnispunktar",
     "There are currently no commands available." : "Það eru engarskipanir tiltækar í augnablikinu.",
     "The command does not exist" : "Skipunin er ekki til",
     "Call with {user1} and {user2} (Duration {duration})" : "Samtal við {user1} og {user2} (tímalengd {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal við {user1}, {user2} og {user3} (tímalengd {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3} og {user4} (tímalengd {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal við {user1}, {user2}, {user3}, {user4} og {user5} (tímalengd {duration})",
+    "Moderators" : "Umsjónarmenn",
     "Commands" : "Skipanir",
     "Command" : "Skipun",
     "Script" : "Skrifta",
     "Response to" : "Svar til",
     "Enabled for" : "Virkjað fyrir",
-    "Moderators" : "Umsjónarmenn",
-    "Circles" : "Hringir",
-    "Start a conversation" : "Hefja samtal",
+    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Mögulegt er að nota utanaðkomandi merkjasendingaþjón fyrir mjög stórar uppsetningar. Skildu þetta eftir autt til að nota innbyggða merkjasendingaþjóninn.",
+    "Loading" : "Hleð inn",
+    "Close" : "Loka",
+    "Password protect" : "Verja með lykilorði",
     "Specify commands the users can use in chats" : "Tilgreindu hvaða skipanir notendur geta notað í spjalli",
     "TURN server" : "TURN-þjónn",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-miðlari er notaður sem milliþjónn umferðar þátttakenda á bak við eldvegg.",
