@@ -41,13 +41,14 @@ OC.L10N.register(
     "{actor} added {user}" : "{actor} pievienoja {user}",
     "You joined the conversation" : "Jūs pievienojaties sarunai",
     "{actor} joined the conversation" : "{actor} pievienojās sarunai",
-    "You added {user}" : "Jūs pievienojāt {user}",
+    "You added {user}" : "Tu pievienoji {user}",
     "{actor} added you" : "{actor} jūs pievienoja",
     "You left the conversation" : "Jūs atstājāt sarunu",
     "{actor} left the conversation" : "{actor} atstāja sarunu",
     "{actor} removed {user}" : "{actor} noņēma {user}",
     "You removed {user}" : "Jūs noņēmāt {user}",
     "{actor} removed you" : "{actor} jūs noņēma",
+    "You added {phone}" : "Tu pievienoji {phone}",
     "{actor} promoted {user} to moderator" : "{actor} paaugstināja {user} par regulētāju",
     "You promoted {user} to moderator" : "Jūs paaugstinājāt {user} par regulētāju",
     "{actor} promoted you to moderator" : "{actor} paaugstināja jūs par regulētāju",
@@ -85,7 +86,7 @@ OC.L10N.register(
     "A guest sent a message in conversation {call}" : "Viesis nosūtījis ziņojumu sarunā {call}",
     "{user} mentioned you in a private conversation" : "{user} tevi pieminēja privātā sarunā",
     "{user} mentioned you in conversation {call}" : "{user} pieminēja jūs sarunā {call}",
-    "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs jūs pieminēja sarunā {call}",
+    "A deleted user mentioned you in conversation {call}" : "Izdzēsts lietotājs pieminēja Tevi sarunā {call}",
     "A guest mentioned you in conversation {call}" : "Kāds viesis jūs pieminēja sarunā {call}",
     "{user} invited you to a private conversation" : "{user} uzaicināja jūs uz privātu sarunu",
     "Join call" : "Pievienoties zvanam",
@@ -338,52 +339,58 @@ OC.L10N.register(
     "Request password" : "Pieprasīt paroli",
     "Error requesting the password." : "Kļūda, pieprasot paroli.",
     "This conversation has ended" : "Šī saruna ir beigusies",
-    "Limit to groups" : "Grupu ierobežojums",
-    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai personas no sarakstā minētajām grupām var piedalīties sarunās.",
-    "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
-    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
     "Everyone" : "Visi",
     "Save changes" : "Saglabāt izmaiņas",
     "Saving …" : "Saglabā ...",
     "Saved!" : "Saglabāts!",
+    "Limit to groups" : "Grupu ierobežojums",
+    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Ja ir atlasīta vismaz viena grupa, tikai personas no sarakstā minētajām grupām var piedalīties sarunās.",
+    "Guests can still join public conversations." : "Viesi joprojām var pievienoties publiskām sarunām.",
+    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Lietotāji, kas vairs nevar izmantot Talk, joprojām tiks uzrādīti kā dalībnieki viņu iepriekšējās sarunās, kā arī tiks paturētas viņu ziņas.",
+    "Enabled" : "Iespējots",
+    "Disabled" : "Atspējots",
     "State" : "Stāvoklis",
     "Name" : "Nosaukums",
     "Description" : "Apraksts",
-    "Enabled" : "Iespējots",
-    "Disabled" : "Atspējots",
     "Beta" : "Beta",
     "Permissions" : "Atļaujas",
     "General settings" : "Vispārīgie iestatījumi",
+    "Enable encryption" : "Ieslēgt šifrēšanu",
+    "Pending" : "Gaida",
+    "Error" : "Kļūda",
     "Language" : "Valoda",
     "Country" : "Valsts",
     "Status" : "Status",
     "Created at" : "Izveidots plkst.",
-    "Pending" : "Gaida",
-    "Error" : "Kļūda",
     "Validate SSL certificate" : "Pārbaudīt SSL sertifikātu",
     "Delete this server" : "Dzēst šo serveri",
+    "Test this server" : "Testēt šo serveri",
     "Shared secret" : "Koplietojams noslēpums",
-    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Lielāka izmēra instalācijām pēc izvēles jāizmanto ārējais signalizēšanas serveris. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri.",
-    "Don't warn about connectivity issues in calls with more than 4 participants" : "Nebrīdināt par savienojamības problēmām zvanos ar vairāk nekā 4 dalībniekiem",
     "STUN server URL" : "STUN servera URL",
     "STUN servers" : "STUN serveris",
     "A STUN server is used to determine the public IP address of participants behind a router." : "STUN serveris tiek izmantots, lai noteiktu maršrutētāja dalībnieku publisko IP adresi.",
     "TURN server URL" : "TURN servera URL",
     "TURN server secret" : "TURN servera noslēpums",
     "TURN server protocols" : "TURN servera protokols",
-    "Test this server" : "Testēt šo serveri",
     "TURN servers" : "TURN serveris",
     "Failed" : "Neizdevās",
     "OK" : "Labi",
-    "Back" : "Atpakaļ",
-    "Cancel" : "Atcelt",
     "Confirm" : "Apstiprināt",
     "Reset" : "Atiestatīt",
-    "Copy link" : "Kopēt saiti",
+    "Back" : "Atpakaļ",
+    "Cancel" : "Atcelt",
+    "Loading …" : "Ielādē…",
+    "No upcoming events" : "Nav gaidāmu notikumu",
+    "Calendar" : "Kalendārs",
+    "Attendees" : "Apmeklētāji",
+    "Save" : "Saglabāt",
+    "No results" : "Nav rezultātu",
+    "Done" : "Pabeigts",
     "Waiting for others to join the call …" : "Gaidot citus pievienoties zvanam …",
     "You can invite others in the participant tab of the sidebar" : "Sānjoslā, dalībnieku cilnē var uzaicināt citus dalībniekus",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Sānjoslas dalībnieku cilnē varat uzaicināt citus lietotājus vai kopīgot šo saiti, lai uzaicinātu citus.",
     "Share this link to invite others!" : "Kopīgojiet šo saiti, lai uzaicinātu citus!",
+    "Copy link" : "Kopēt saiti",
     "Mute audio" : "Izslēgt audio skaņu",
     "Disable video" : "Atspējot video",
     "Enable video" : "Iespējot video",
@@ -391,14 +398,13 @@ OC.L10N.register(
     "Show screen" : "Rādīt ekrānu",
     "Collapse" : "Sakļaut",
     "Favorite" : "Izlasē",
-    "Loading …" : "Ielādē…",
+    "Date:" : "Datums:",
     "Hide details" : "Slēpt detaļas",
     "Show details" : "Rādīt detaļas",
-    "Date:" : "Datums:",
     "Disable" : "Deaktivēt",
     "Enable" : "Iespējot",
+    "Choose" : "Izvēlēties",
     "The file must be a PNG or JPG" : "Failam jābūt PNG vai JPG",
-    "Choose" : "Izvēlies",
     "Restricted" : "Ierobežota",
     "Personal" : "Personīgs",
     "Setup overview" : "Uzstādīšanas pārskats",
@@ -408,19 +414,17 @@ OC.L10N.register(
     "Yes" : "Jā",
     "Delete conversation" : "Dzēst sarunu",
     "Password protection" : "Password protection",
-    "Save" : "Saglabāt",
     "Edit" : "Labot",
     "Delete" : "Dzēst",
     "Notifications" : "Paziņojumi",
-    "Login" : "Autorizēties",
+    "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
     "You need to promote a new moderator before you can leave the conversation." : "Pirms sarunas atstāšanas ir jāieceļ jauns regulētājs.",
-    "Clear filter" : "Notīrīt atlasi",
+    "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
-    "Loading" : "Ielādē",
-    "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
+    "Clear filter" : "Notīrīt atlasi",
     "None" : "Nav",
     "Devices" : "Ierīces",
     "No audio" : "Nav audio",
@@ -433,54 +437,54 @@ OC.L10N.register(
     "Contact" : "Kontakts",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["%n dienas atpakaļ","%n dienas atpakaļ","%n dienām"],
-    "Close" : "Aizvērt",
-    "Password protect" : "Aizsargāt ar paroli",
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "File to share" : "Kopīgojamā datne",
     "Upload from device" : "Augšupielādēt no ierīces",
     "New file" : "Jauna datne",
-    "Settings" : "Iestatījumi",
     "Send" : "Sūtīt",
+    "Settings" : "Iestatījumi",
     "Join" : "Pievienoties",
     "moderator" : "moderators",
     "guest" : "viesis",
+    "Remove participant" : "Noņemt dalībnieku",
     "Demote from moderator" : "Pazemināt no regulētāja",
     "Promote to moderator" : "Paaugstināt par regulētāju",
     "Remove" : "Izņemt",
-    "Remove participant" : "Noņemt dalībnieku",
-    "Searching …" : "Meklē...",
-    "No results" : "Nav rezultātu",
     "Add users or groups" : "Add users or groups",
+    "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
     "Chat" : "Tērzēt",
     "Details" : "Detaļas",
+    "Load more results" : "Ielādēt vairāk iznākumu",
     "Projects" : "Projekti",
-    "Select conversation" : "Izvēlēties sarunu",
     "Link to a conversation" : "Saite uz sarunu",
+    "Select conversation" : "Izvēlēties sarunu",
+    "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
+    "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
+    "Appearance" : "Izskats",
     "Privacy" : "Privātums",
     "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
-    "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
-    "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
     "Start call" : "Sākt zvanu",
-    "Show your screen" : "Rādīt savu ekrānu",
-    "Stop screensharing" : "Apturēt ekrāna koplietošanu",
-    "Screensharing options" : "Ekrāna koplietošanas opcijas",
+    "Screensharing options" : "Ekrāna kopīgošanas iespējas",
     "Enable screensharing" : "Iespējot ekrāna koplietošanu",
     "Screensharing requires the page to be loaded through HTTPS." : "Lai koplietotu ekrānu, lapa jāielādē, izmantojot HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
     "Screensharing extension is required to share your screen." : "Lai koplietotu ekrānu, ir nepieciešams ekrāna koplietošanas paplašinājums.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Lai koplietotu ekrānu, lūdzu, izmantojiet citu pārlūkprogrammu, piemēram, Firefox vai Chrome.",
     "An error occurred while starting screensharing." : "Startējot ekrāna koplietošanu, radās kļūda.",
-    "Start recording" : "Uzsākt ierakstīšanu",
+    "Show your screen" : "Rādīt savu ekrānu",
+    "Stop screensharing" : "Apturēt ekrāna koplietošanu",
     "Grid view" : "Režģa izkārtojums",
+    "Start recording" : "Uzsākt ierakstīšanu",
     "Select a region" : "Izvēlieties reģionu",
     "Submit" : "Iesniegt",
     "Join a conversation or start a new one" : "Pievienoties sarunai vai sākt jaunu",
     "User" : "Lietotājs",
     "Password" : "Parole",
     "API token" : "API pilnvara",
+    "Login" : "Autorizēties",
     "Nickname" : "Iesauka",
     "Client ID" : "Klienta ID",
     "Audio" : "Audio",
@@ -488,6 +492,7 @@ OC.L10N.register(
     "Group" : "Grupa",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
+    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
     "Default" : "Noklusējuma",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, restartējiet pārlūkprogrammu, jo ir audio un video kļūme",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
@@ -500,19 +505,28 @@ OC.L10N.register(
     "%s Talk on your mobile devices" : "%s Sarunas mobilajās ierīcēs",
     "Android app" : "Android lietotne",
     "iOS app" : "iOS lietotne",
+    "__language_name__" : "Latviešu",
+    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Zvanu apkopojuma robotprogrammatūra izveido pārskata ziņojumu pēc zvana, uzskaitot visus dalībniekus un izklāstot uzdevumus",
+    "Tasks" : "Uzdevumi",
+    "Notes" : "Piezīmes",
+    "Reports" : "Atskaites",
     "There are currently no commands available." : "Pašlaik nav pieejamas komandas.",
     "The command does not exist" : "Šī komanda nepastāv",
     "Call with {user1} and {user2} (Duration {duration})" : "Saruna ar {user1} un {user2} ( Ilgums {duration})",
     "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Saruna ar {user1}, {user2} un {user3} ( Ilgums {duration})",
     "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3} un {user4} ( Ilgums {duration})",
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Saruna ar {user1}, {user2}, {user3}, {user4} un {user5} ( Ilgums {duration})",
+    "Moderators" : "Regulētāji",
     "Commands" : "Komandas",
     "Command" : "Komanda",
     "Script" : "Skripts",
     "Response to" : "Atbilde uz",
     "Enabled for" : "Iespējots",
-    "Moderators" : "Regulētāji",
-    "Start a conversation" : "Sākt sarunu",
+    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "Lielāka izmēra instalācijām pēc izvēles jāizmanto ārējais signalizēšanas serveris. Atstājiet tukšu, lai izmantotu iekšējo signalizēšanas serveri.",
+    "Don't warn about connectivity issues in calls with more than 4 participants" : "Nebrīdināt par savienojamības problēmām zvanos ar vairāk nekā 4 dalībniekiem",
+    "Loading" : "Ielādē",
+    "Close" : "Aizvērt",
+    "Password protect" : "Aizsargāt ar paroli",
     "Specify commands the users can use in chats" : "Komandu norādīšana, kuras lietotāji var izmantot tērzēšanā",
     "TURN server" : "TURN serveris",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveris tiek izmantots, lai bloķētu dalībnieku datplūsmu aiz ugunsmūra.",
