@@ -7,82 +7,127 @@ OC.L10N.register(
     "Invalid file provided" : "Ugyldig fil",
     "Invalid image" : "Ugyldig bilete",
     "Unknown filetype" : "Ukjend filtype",
+    "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
     "Open settings" : "Opne instillingar",
     "Messages" : "Meldingar",
+    "Albania" : "Albania",
+    "Armenia" : "Armenia",
+    "Angola" : "Angola",
+    "Argentina" : "Argentina",
+    "Austria" : "Austerrike",
+    "Australia" : "Australia",
+    "Belgium" : "Belgia",
+    "Bulgaria" : "Bulgaria",
+    "Bahamas" : "Bahamas",
+    "Chile" : "Chile",
+    "Germany" : "Tyskland",
+    "Denmark" : "Danmark",
+    "Estonia" : "Estland",
+    "Egypt" : "Egypt",
+    "Finland" : "Finland",
+    "France" : "Frankrike",
+    "Georgia" : "Georgia",
+    "Greece" : "Hellas",
+    "Indonesia" : "Indonesia",
+    "Ireland" : "Irland",
+    "Israel" : "Israel",
+    "India" : "India",
+    "Iceland" : "Island",
+    "Jordan" : "Jordan",
+    "Japan" : "Japan",
+    "Kenya" : "Kenya",
+    "Kuwait" : "Kuwait",
+    "Lebanon" : "Libanon",
+    "Lithuania" : "Litauen",
+    "Latvia" : "Latvia",
+    "Libya" : "Libya",
+    "Mexico" : "Mexico",
+    "Nigeria" : "Nigeria",
+    "Netherlands" : "Nederland",
+    "Norway" : "Noreg",
     "Everyone" : "Alle",
-    "Name" : "Namn",
-    "None" : "Ingen",
-    "User" : "Bruker",
     "Disabled" : "Deaktivert",
-    "Users" : "Brukarare",
+    "Name" : "Namn",
+    "Description" : "Skildring",
+    "Enable encryption" : "Aktiver kryptering",
+    "Pending" : "Under vegs",
+    "Error" : "Feil",
     "Language" : "Språk",
     "Country" : "Land",
     "Status" : "Status",
     "Created at" : "Skapt den",
-    "Pending" : "Under vegs",
-    "Error" : "Feil",
     "OK" : "OK",
     "Back" : "Tilbake",
     "Cancel" : "Avbryt",
+    "Calendar" : "Kalendar",
+    "Attendees" : "Deltakarar",
+    "Save" : "Lagre",
     "Copy link" : "Kopier lenkje",
     "Favorite" : "Favoritt",
-    "Description" : "Skildring",
+    "Disable" : "Slå av",
+    "Enable" : "SLå på",
+    "Choose" : "Vel",
     "Personal" : "Personleg",
     "Leave conversation" : "Forlat samtalen",
     "Delete conversation" : "Slett samtale",
     "Password protection" : "Password protection",
-    "Save" : "Lagre",
+    "Set a password" : "Lag eit passord",
     "Edit" : "Endra",
     "More information" : "Meir informasjon",
     "Delete" : "Slett",
+    "Notifications" : "Varsel",
+    "Log in" : "Logg inn",
+    "Remove from favorites" : "Remove from favorites",
+    "Add to favorites" : "Add to favorites",
+    "Users" : "Brukarare",
+    "Groups" : "Grupper",
+    "None" : "Ingen",
+    "Upload" : "Last opp",
+    "Files" : "Filer",
+    "Message sent" : "Melding sendt",
+    "Unread messages" : "Meldingar er ikkje lest",
+    "Reply" : "Svare",
+    "Reply privately" : "Svar privat",
+    "Dismiss" : "Forkast",
+    "Contact" : "Kontakt",
+    "Today" : "I dag",
+    "Yesterday" : "i går",
+    "_%n day ago_::_%n days ago_" : ["%n dag sidan","%n dagar sidan"],
+    "Add participants" : "Legg til deltakarar",
+    "Send message" : "Send melding",
+    "Record voice message" : "Ta opp lyd melding ",
+    "Send" : "Send",
+    "Settings" : "Instillingar",
+    "Remove group and members" : "Eksterne gruppe og medlemmar",
+    "Remove participant" : "Eksterne deltakarar",
+    "Demote from moderator" : "Nedrykk frå moderator",
+    "Promote to moderator" : "Fremje til moderator",
+    "Add users or groups" : "Add users or groups",
+    "Participants" : "Deltakarar",
+    "Open chat" : "Start lynmelding",
+    "Chat" : "Lynmelding",
+    "Details" : "Detaljar",
+    "Appearance" : "Utsjånad",
+    "Privacy" : "Personvern",
+    "Keyboard shortcuts" : "Tastatursnarvegar",
+    "Search" : "Search",
+    "Grid view" : "Rutenett visning",
+    "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
+    "User" : "Bruker",
     "Password" : "Passord",
     "Login" : "Login",
     "Nickname" : "Kallenamn",
     "Client ID" : "Klient-ID",
-    "Notifications" : "Varsel",
-    "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites",
-    "Loading" : "Loading",
-    "Groups" : "Grupper",
-    "Circles" : "Sirklar",
-    "Password protect" : "Vern med passord",
-    "Add participants" : "Legg til deltakarar",
-    "Close" : "Lukk",
-    "Conversation name" : "Samtale namn",
-    "Upload" : "Last opp",
-    "Files" : "Filer",
-    "Unread messages" : "Meldingar er ikkje lest",
-    "Message sent" : "Melding sendt",
-    "Dismiss" : "Forkast",
-    "Reply" : "Svare",
-    "Reply privately" : "Svar privat",
-    "Today" : "I dag",
-    "Yesterday" : "i går",
-    "Send message" : "Send melding",
-    "Group" : "Gruppe",
-    "Record voice message" : "Ta opp lyd melding ",
-    "Settings" : "Instillingar",
-    "Send" : "Send",
-    "Demote from moderator" : "Nedrykk frå moderator",
-    "Promote to moderator" : "Fremje til moderator",
-    "Remove group and members" : "Eksterne gruppe og medlemmar",
-    "Remove participant" : "Eksterne deltakarar",
-    "Add users or groups" : "Add users or groups",
-    "Participants" : "Deltakarar",
-    "Chat" : "Lynmelding",
-    "Details" : "Detaljar",
-    "Privacy" : "Personvern",
-    "Keyboard shortcuts" : "Tastatursnarvegar",
-    "Search" : "Search",
-    "Open sidebar" : "Opne sidestolpe",
-    "Open chat" : "Start lynmelding",
-    "Grid view" : "Rutenett visning",
-    "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
-    "Join a conversation or start a new one" : "Delta i ein samtale eller start ein ny ein",
     "Other" : "Anna",
+    "Group" : "Gruppe",
+    "Please reload the page." : "Ver venleg og last sida på nytt.",
     "Away" : "Borte",
     "Default" : "Standard",
     "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
-    "Rename conversation" : "Eksterne samtalar "
+    "__language_name__" : "Nynorsk",
+    "Tasks" : "Oppgåver",
+    "Loading" : "Loading",
+    "Close" : "Lukk",
+    "Password protect" : "Vern med passord"
 },
 "nplurals=2; plural=(n != 1);");
