@@ -18,6 +18,12 @@ OC.L10N.register(
     "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre as novidades disponíveis no Nextcloud Talk.",
     "## New in Talk %s" : "## Novo no Talk %s",
     "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
+    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Agora as conversas individuais são persistentes e já não podem ser convertidas em conversas de grupo por acidente. Além disso, quando um dos participantes deixa a conversa, esta passa a não ser apagada automaticamente. A conversa só é apagada do servidor se ambos os participantes a deixarem.",
+    "- You can now notify all participants by posting \"@all\" into the chat" : "- Agora pode notificar todos os participantes ao escrever \"@all\" na conversa",
+    "- With the \"arrow-up\" key you can repost your last message" : "- Com a tecla \"seta para cima\" você pode repostar sua última mensagem",
+    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Agora o Talk aceita comandos, envie \"/help\" como mensagem na conversa para ver se o seu administrador configurou algum",
+    "- With projects you can create quick links between conversations, files and other items" : "- Com projetos pode criar links rápidos entre conversas, ficheiros e outros itens",
+    "- You can now mention guests in the chat" : "- Agora pode mencionar convidados na conversa",
     "Talk updates ✅" : "Atualizações do Falar ✅",
     "System created the conversation" : "O sistema criou a conversa",
     "Message deleted by author" : "Mensagem apagada pelo autor",
@@ -224,123 +230,135 @@ OC.L10N.register(
     "Federation" : "Federação",
     "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
     "Leave call" : "Sair da chamada",
-    "Limit to groups" : "Limitado a grupos",
     "Everyone" : "Para todos",
     "Save changes" : "Guardar alterações",
     "Saving …" : "A guardar...",
     "Saved!" : "Gravado!",
+    "Limit to groups" : "Limitado a grupos",
+    "Enabled" : "Ativado",
+    "Disabled" : "Desativado",
     "State" : "Estado",
     "Name" : "Nome",
     "Description" : "Descrição",
-    "Enabled" : "Activo",
-    "Disabled" : "Desactivado",
     "General settings" : "Definições Gerais",
-    "Language" : "Idioma",
-    "Country" : "País",
-    "Status" : "Estado",
-    "Created at" : "Criado em",
+    "Enable encryption" : "Ativar a encriptação",
     "Pending" : "Pendente",
     "Error" : "Erro",
     "Blocked" : "Bloqueado",
     "Expired" : "Expirado",
+    "Language" : "Idioma",
+    "Country" : "País",
+    "Status" : "Estado",
+    "Created at" : "Criado em",
+    "Downloading …" : "A transferir…",
     "Validate SSL certificate" : "Validar certificado SSL",
     "Shared secret" : "Segredo partilhado",
     "TURN server protocols" : "Protocolos do servidor TURN",
     "OK" : "Ok",
     "Checking …" : "A verificar...",
-    "Back" : "Anterior",
-    "Cancel" : "Cancelar",
+    "Federated user" : "Utilizador federado",
     "Confirm" : "Confirmar",
     "Reset" : "Reiniciar",
-    "Copy link" : "Copiar ligação",
+    "Back" : "Anterior",
+    "Cancel" : "Cancelar",
+    "From" : "De",
+    "To" : "Para",
+    "Calendar" : "Calendário",
+    "Attendees" : "Participantes",
+    "Save" : "Guardar",
+    "No results" : "Sem resultados",
+    "Done" : "Concluído",
     "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
     "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
     "Share this link to invite others!" : "Envie este link para convidar outros!",
+    "Copy link" : "Copiar ligação",
     "Mute audio" : "Silenciar áudio",
-    "Disable video" : "desactivar vídeo",
-    "Enable video" : "activar vídeo",
+    "Disable video" : "desativar vídeo",
+    "Enable video" : "ativar vídeo",
     "You" : "Você",
     "Show screen" : "Mostrar ecrã",
     "Collapse" : "Expandir",
     "Favorite" : "Favorito",
+    "Date:" : "Data:",
     "Hide details" : "Ocultar detalhes",
     "Show details" : "Mostrar detalhes",
-    "Date:" : "Data:",
     "Disable" : "Desativar",
-    "Enable" : "Activar",
+    "Enable" : "Ativar",
     "Choose" : "Escolher",
     "Restricted" : "Restrito",
     "Personal" : "Pessoal",
     "Leave conversation" : "Sair da conversação",
     "Delete conversation" : "Eliminar conversação",
     "Password protection" : "Protegido por palavra-passe",
-    "Save" : "Guardar",
+    "Set a password" : "Definir uma palavra-passe",
     "Edit" : "Editar",
     "Delete" : "Apagar",
     "Notifications" : "Notificações",
-    "Login" : "Iniciar sessão",
+    "Log in" : "Iniciar sessão",
     "Remove from favorites" : "Remover de favoritos",
     "Add to favorites" : "Adicionar aos favoritos",
-    "Create a new conversation" : "Criar nova conversa",
-    "Join open conversations" : "Juntar-me a conversas abertas",
-    "Clear filter" : "Limpar filtro",
     "Users" : "Utilizadores",
     "Groups" : "Grupos",
     "Teams" : "Grupos",
-    "Loading" : "A carregar",
+    "Create a new conversation" : "Criar nova conversa",
+    "Join open conversations" : "Juntar-me a conversas abertas",
+    "Clear filter" : "Limpar filtro",
     "Talk settings" : "Definições do Falar",
     "None" : "Nenhum",
+    "Invalid path selected" : "Caminho inválido selecionado",
     "Upload" : "Enviar",
     "Files" : "Ficheiros",
-    "Invalid path selected" : "Caminho inválido selecionado",
-    "Reply" : "Resposta",
-    "Translate" : "Traduzir",
     "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
     "Error while forwarding message to \"Note to self\"" : "Erro ao reencaminhar mensagem para \"Nota a mim\"",
+    "Reply" : "Resposta",
+    "Download file" : "Transferir ficheiro",
+    "Translate" : "Traduzir",
     "Dismiss" : "Dispensar",
     "Contact" : "Contacto",
-    "No messages" : "Sem mensagens",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
-    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "_%n day ago_::_%n days ago_" : ["%n dia atrás","%n dias atrás","%n dias atrás"],
+    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "No messages" : "Sem mensagens",
     "Create a new group conversation" : "Criar nova conversa de grupo",
-    "Close" : "Fechar",
-    "Password protect" : "Proteger com palavra-passe",
     "Send message" : "Enviar mensagem",
     "New file" : "Ficheiro novo",
-    "Settings" : "Definições",
     "Send" : "Enviar",
+    "Settings" : "Definições",
     "Join" : "Aderir",
     "moderator" : "moderador",
     "guest" : "convidado",
+    "Remove participant" : "Remover participante",
     "Demote from moderator" : "Relegar de moderador",
     "Promote to moderator" : "Promover a moderador",
     "Remove" : "Remover",
-    "Remove participant" : "Remover participante",
-    "Searching …" : "À procura …",
-    "No results" : "Sem resultados",
     "Add users or groups" : "Add users or groups",
+    "Integrations" : "Integrações",
+    "Searching …" : "À procura …",
     "Participants" : "Participantes",
+    "Search in {name}" : "Procurar em {name}",
     "Chat" : "Conversa",
     "Details" : "Detalhes",
+    "Load more results" : "Mostrar mais resultados",
     "No shared items" : "Sem itens partilhados",
     "Privacy" : "Privacidade",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
     "Screensharing options" : "Opções de partilha de ecrã",
-    "Enable screensharing" : "Activar partilha de ecrã",
+    "Enable screensharing" : "Ativar partilha de ecrã",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
     "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
     "Grid view" : "Vista em grelha",
+    "Download attendance list" : "Transferir lista de presenças",
     "Select a region" : "Selecione uma região",
     "Submit" : "Submeter",
     "User" : "Utilizador",
     "Password" : "Palavra-passe",
     "API token" : "Token de API",
+    "Login" : "Iniciar sessão",
     "Nickname" : "Alcunha",
     "Client ID" : "Id. do Cliente",
     "Media" : "Media",
@@ -349,6 +367,7 @@ OC.L10N.register(
     "Other" : "Outro",
     "Group" : "Grupo",
     "Error while sharing file" : "Erro ao partilhar ficheiro",
+    "Please reload the page." : "Por favor, recarregue a página.",
     "Do not disturb" : "Não incomodar",
     "Away" : "Ausente",
     "Default" : "Predefinida",
@@ -360,7 +379,12 @@ OC.L10N.register(
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
-    "Circles" : "Círculos",
-    "Start a conversation" : "Iniciar uma conversação"
+    "__language_name__" : "Português",
+    "Tasks" : "Tarefas",
+    "Notes" : "Notas",
+    "Reports" : "Relatórios",
+    "Loading" : "A carregar",
+    "Close" : "Fechar",
+    "Password protect" : "Proteger com palavra-passe"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
