@@ -1,93 +1,119 @@
 OC.L10N.register(
     "spreed",
     {
+    "Other activities" : "กิจกรรมอื่น ๆ",
+    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
+    "You set up Matterbridge to synchronize this conversation with other chats" : "คุณได้ตั้งค่า Matterbridge เพื่อซิงโครไนซ์การสนทนานี้กับแชทอื่น ๆ",
+    "Message deleted by author" : "ข้อความถูกลบโดยผู้เขียน",
     "File is too big" : "ไฟล์ใหญ่เกินไป",
     "Invalid file provided" : "ไฟล์ที่ระบุไม่ถูกต้อง",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
     "Unknown filetype" : "ชนิดไฟล์ที่ไม่รู้จัก",
     "Dismiss notification" : "ปิดการแจ้งเตือน",
+    "Accept" : "ยอมรับ",
+    "Decline" : "ปฏิเสธ",
     "Open settings" : "เปิดการตั้งค่า",
+    "error" : "ข้อผิดพลาด",
+    "Federation" : "ที่ติดต่อกับภายนอก",
     "Invalid date, date format must be YYYY-MM-DD" : "วันที่ไม่ถูกต้อง รูปแบบวันที่จะต้องเป็น ปปปป-ดด-วว",
     "Conversation not found" : "ไม่พบการสนทนา",
     "Everyone" : "ทุกคน",
     "Save changes" : "บันทึกการเปลี่ยนแปลง",
     "Saving …" : "กำลังบันทึก …",
-    "Name" : "ชื่อ",
-    "None" : "ไม่มี",
-    "User" : "ผู้ใช้",
+    "Enabled" : "เปิดใช้งาน",
     "Disabled" : "ปิดใช้งาน",
-    "Users" : "ผู้ใช้",
+    "Name" : "ชื่อ",
+    "Description" : "รายละเอียด",
     "All messages" : "ข้อความทั้งหมด",
     "@-mentions only" : "เฉพาะการกล่าวถึงแบบ @",
+    "Enable encryption" : "เปิดใช้งานการเข้ารหัส",
+    "Pending" : "รอดำเนินการ",
+    "Error" : "ข้อผิดพลาด",
     "Language" : "ภาษา",
     "Country" : "ประเทศ",
     "Status" : "สถานะ",
     "Created at" : "สร้างเมื่อ",
-    "Pending" : "รอดำเนินการ",
-    "Error" : "ข้อผิดพลาด",
     "OK" : "ตกลง",
-    "Back" : "ย้อนกลับ",
     "Confirm" : "ยืนยัน",
     "Reset" : "รีเซ็ต",
+    "Back" : "ย้อนกลับ",
     "Cancel" : "ยกเลิก",
+    "Calendar" : "ปฏิทิน",
+    "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Save" : "บันทึก",
+    "No results" : "ไม่มีผลลัพธ์",
     "Copy link" : "คัดลอกลิงก์",
     "Collapse" : "ย่อ",
     "Favorite" : "รายการโปรด",
-    "Description" : "รายละเอียด",
+    "Hide details" : "ซ่อนข้อมูล",
+    "Show details" : "แสดงข้อมูล",
+    "Disable" : "ปิดใช้งาน",
+    "Choose" : "เลือก",
     "Restricted" : "ถูกจำกัด",
     "Personal" : "ส่วนตัว",
-    "Submit" : "ส่ง",
+    "No" : "ไม่ตกลง",
+    "Yes" : "ใช่",
     "Password protection" : "ป้องกันด้วยรหัสผ่าน",
-    "Save" : "บันทึก",
     "Edit" : "แก้ไข",
     "Delete" : "ลบ",
+    "Notifications" : "การแจ้งเตือน",
+    "Log in" : "เข้าสู่ระบบ",
+    "Remove from favorites" : "เอาออกจากรายการโปรด",
+    "Add to favorites" : "เพิ่มในรายการโปรด",
+    "Users" : "ผู้ใช้",
+    "Groups" : "กลุ่ม",
+    "None" : "ไม่มี",
+    "Devices" : "อุปกรณ์",
+    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
+    "Upload" : "อัปโหลด",
+    "Files" : "ไฟล์",
+    "Reply" : "ตอบกลับ",
+    "Translate" : "แปลภาษา",
+    "Dismiss" : "ปิดทิ้ง",
+    "Today" : "วันนี้",
+    "Yesterday" : "เมื่อวาน",
+    "_%n day ago_::_%n days ago_" : ["%n วันที่ผ่านมา"],
+    "Add participants" : "เพิ่มผู้เข้าร่วม",
+    "New file" : "ไฟล์ใหม่",
+    "Blank" : "ว่าง",
+    "Send" : "ส่ง",
+    "Settings" : "การตั้งค่า",
+    "bot" : "บอต",
+    "guest" : "ผู้เยี่ยมชม",
+    "Remove" : "ลบออก",
+    "Add users or groups" : "เพิ่มผู้ใช้หรือกลุ่ม",
+    "Searching …" : "กำลังค้นหา …",
+    "Chat" : "แชท",
+    "Details" : "รายละเอียด",
+    "Load more results" : "โหลดผลลัพธ์เพิ่มเติม",
+    "Appearance" : "ลักษณะที่ปรากฏ",
+    "Privacy" : "ความเป็นส่วนตัว",
+    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
+    "Search" : "ค้นหา",
+    "Grid view" : "มุมมองแบบตาราง",
+    "Submit" : "ส่ง",
+    "User" : "ผู้ใช้",
     "Password" : "รหัสผ่าน",
     "Login" : "เข้าสู่ระบบ",
     "Nickname" : "ชื่อเล่น",
     "Client ID" : "รหัสไคลเอ็นต์",
-    "Notifications" : "การแจ้งเตือน",
-    "Remove from favorites" : "เอาออกจากรายการโปรด",
-    "Add to favorites" : "เพิ่มในรายการโปรด",
-    "Loading" : "กำลังโหลด",
-    "Groups" : "กลุ่ม",
-    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
-    "Add participants" : "เพิ่มผู้เข้าร่วม",
-    "Close" : "ปิด",
-    "Devices" : "อุปกรณ์",
-    "Upload" : "อัปโหลด",
-    "Files" : "ไฟล์",
-    "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
-    "Dismiss" : "ปิดทิ้ง",
-    "Reply" : "ตอบกลับ",
-    "Translate" : "แปลภาษา",
-    "Today" : "วันนี้",
-    "Yesterday" : "เมื่อวาน",
-    "Group" : "กลุ่ม",
-    "New file" : "ไฟล์ใหม่",
-    "Blank" : "ว่าง",
-    "Settings" : "การตั้งค่า",
-    "Send" : "ส่ง",
-    "bot" : "บอต",
-    "guest" : "ผู้เยี่ยมชม",
-    "Searching …" : "กำลังค้นหา …",
-    "No results" : "ไม่มีผลลัพธ์",
-    "Add users or groups" : "เพิ่มผู้ใช้หรือกลุ่ม",
-    "Chat" : "แชท",
-    "Details" : "รายละเอียด",
-    "Privacy" : "ความเป็นส่วนตัว",
-    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
-    "Search" : "ค้นหา",
-    "Open sidebar" : "เปิดแถบด้านข้าง",
-    "Grid view" : "มุมมองแบบตาราง",
     "Media" : "สื่อ",
     "Locations" : "สถานที่",
     "Audio" : "เสียง",
     "Other" : "อื่น ๆ",
+    "Group" : "กลุ่ม",
+    "Please reload the page." : "โปรดโหลดหน้าเว็บใหม่",
     "Do not disturb" : "ห้ามรบกวน",
     "Away" : "ไม่อยู่",
     "Default" : "ค่าเริ่มต้น",
     "The password is wrong. Try again." : "รหัสผ่านไม่ถูกต้อง กรุณาลองอีกครั้ง",
     "Android app" : "แอป Android",
-    "iOS app" : "แอป iOS"
+    "iOS app" : "แอป iOS",
+    "__language_name__" : "ไทย",
+    "Tasks" : "งาน",
+    "Notes" : "โน้ต",
+    "Loading" : "กำลังโหลด",
+    "Close" : "ปิด",
+    "Password protect" : "ป้องกันด้วยรหัสผ่าน"
 },
 "nplurals=1; plural=0;");
