@@ -65,6 +65,7 @@ use OCP\IL10N;
 use OCP\IRequest;
 use OCP\IUserManager;
 use OCP\RichObjectStrings\InvalidObjectExeption;
+use OCP\RichObjectStrings\IRichTextFormatter;
 use OCP\RichObjectStrings\IValidator;
 use OCP\Security\ITrustedDomainHelper;
 use OCP\Security\RateLimiting\IRateLimitExceededException;
@@ -84,9 +85,10 @@ use Psr\Log\LoggerInterface;
  * @psalm-import-type TalkChatMessage from ResponseDefinitions
  * @psalm-import-type TalkChatMessageWithParent from ResponseDefinitions
  * @psalm-import-type TalkChatReminder from ResponseDefinitions
+ * @psalm-import-type TalkRichObjectParameter from ResponseDefinitions
  * @psalm-import-type TalkRoom from ResponseDefinitions
  */
-class ChatController extends AEnvironmentAwareController {
+class ChatController extends AEnvironmentAwareOCSController {
 	/** @var string[] */
 	protected array $guestNames;
 
@@ -122,6 +124,7 @@ class ChatController extends AEnvironmentAwareController {
 		protected Authenticator $federationAuthenticator,
 		protected ProxyCacheMessageService $pcmService,
 		protected Notifier $notifier,
+		protected IRichTextFormatter $richTextFormatter,
 		protected ITaskProcessingManager $taskProcessingManager,
 		protected IAppConfig $appConfig,
 		protected LoggerInterface $logger,
@@ -196,7 +199,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $replyTo Parent id which this message is a reply to
 	 * @psalm-param non-negative-int $replyTo
 	 * @param bool $silent If sent silent the chat message will not create any notifications
-	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE|Http::STATUS_TOO_MANY_REQUESTS, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE|Http::STATUS_TOO_MANY_REQUESTS, array{error: string}, array{}>
 	 *
 	 * 201: Message sent successfully
 	 * 400: Sending message is not possible
@@ -218,12 +221,12 @@ class ChatController extends AEnvironmentAwareController {
 		}
 
 		if (trim($message) === '') {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
 		}
 
 		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
 		}
 
 		$parent = $parentMessage = null;
@@ -232,13 +235,13 @@ class ChatController extends AEnvironmentAwareController {
 				$parent = $this->chatManager->getParentComment($this->room, (string)$replyTo);
 			} catch (NotFoundException $e) {
 				// Someone is trying to reply cross-rooms or to a non-existing message
-				return new DataResponse([], Http::STATUS_BAD_REQUEST);
+				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
 			}
 
 			$parentMessage = $this->messageParser->createMessage($this->room, $this->participant, $parent, $this->l);
 			$this->messageParser->parseMessage($parentMessage);
 			if (!$parentMessage->isReplyable()) {
-				return new DataResponse([], Http::STATUS_BAD_REQUEST);
+				return new DataResponse(['error' => 'reply-to'], Http::STATUS_BAD_REQUEST);
 			}
 		}
 
@@ -248,11 +251,11 @@ class ChatController extends AEnvironmentAwareController {
 		try {
 			$comment = $this->chatManager->sendMessage($this->room, $this->participant, $actorType, $actorId, $message, $creationDateTime, $parent, $referenceId, $silent);
 		} catch (MessageTooLongException) {
-			return new DataResponse([], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (IRateLimitExceededException) {
-			return new DataResponse([], Http::STATUS_TOO_MANY_REQUESTS);
+			return new DataResponse(['error' => 'mentions'], Http::STATUS_TOO_MANY_REQUESTS);
 		} catch (\Exception $e) {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
 		}
 
 		return $this->parseCommentToResponse($comment, $parentMessage);
@@ -269,7 +272,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param string $metaData Additional metadata
 	 * @param string $actorDisplayName Guest name
 	 * @param string $referenceId Reference ID
-	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_CREATED, ?TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_NOT_FOUND|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 *
 	 * 201: Object shared successfully
 	 * 400: Sharing object is not possible
@@ -284,11 +287,13 @@ class ChatController extends AEnvironmentAwareController {
 	public function shareObjectToChat(string $objectType, string $objectId, string $metaData = '', string $actorDisplayName = '', string $referenceId = ''): DataResponse {
 		[$actorType, $actorId] = $this->getActorInfo($actorDisplayName);
 		if (!$actorId) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+			return new DataResponse(['error' => 'actor'], Http::STATUS_NOT_FOUND);
 		}
 
+		/** @var TalkRichObjectParameter $data */
 		$data = $metaData !== '' ? json_decode($metaData, true) : [];
 		if (!is_array($data)) {
+			/** @var TalkRichObjectParameter $data */
 			$data = [];
 		}
 		$data['type'] = $objectType;
@@ -296,18 +301,18 @@ class ChatController extends AEnvironmentAwareController {
 		$data['icon-url'] = $this->avatarService->getAvatarUrl($this->room);
 
 		if (isset($data['link']) && !$this->trustedDomainHelper->isTrustedUrl($data['link'])) {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'link'], Http::STATUS_BAD_REQUEST);
 		}
 
 		try {
 			$this->richObjectValidator->validate('{object}', ['object' => $data]);
 		} catch (InvalidObjectExeption $e) {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'object'], Http::STATUS_BAD_REQUEST);
 		}
 
 		if ($data['type'] === 'geo-location'
 			&& !preg_match(ChatManager::GEO_LOCATION_VALIDATOR, $data['id'])) {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'object'], Http::STATUS_BAD_REQUEST);
 		}
 
 		$this->participantService->ensureOneToOneRoomIsFilled($this->room);
@@ -325,9 +330,9 @@ class ChatController extends AEnvironmentAwareController {
 		try {
 			$comment = $this->chatManager->addSystemMessage($this->room, $actorType, $actorId, $message, $creationDateTime, true, $referenceId);
 		} catch (MessageTooLongException $e) {
-			return new DataResponse([], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (\Exception $e) {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
+			return new DataResponse(['error' => 'message'], Http::STATUS_BAD_REQUEST);
 		}
 
 		return $this->parseCommentToResponse($comment);
@@ -408,7 +413,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param 0|1 $includeLastKnown Include the $lastKnownMessageId in the messages when 1 (default 0)
 	 * @param 0|1 $noStatusUpdate When the user status should not be automatically set to online set to 1 (default 0)
 	 * @param 0|1 $markNotificationsAsRead Set to 0 when notifications should not be marked as read (default 1)
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMessageWithParent[], array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, array<empty>, array<empty>>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 *
 	 * 200: Messages returned
 	 * 304: No messages
@@ -506,14 +511,10 @@ class ChatController extends AEnvironmentAwareController {
 	 * Required capability: `chat-summary-api`
 	 *
 	 * @param positive-int $fromMessageId Offset from where on the summary should be generated
-	 * @return DataResponse<Http::STATUS_CREATED, array{taskId: int, nextOffset?: int}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'ai-no-provider'|'ai-error'}, array{}>|DataResponse<Http::STATUS_NO_CONTENT, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_CREATED, array{taskId: int, nextOffset?: int}, array{}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: 'ai-no-provider'|'ai-error'}, array{}>|DataResponse<Http::STATUS_NO_CONTENT, null, array{}>
 	 * @throws \InvalidArgumentException
 	 *
-	 * 201: Summary was scheduled, use the returned taskId to get the status
-	 *   information and output from the TaskProcessing API:
-	 *   https://docs.nextcloud.com/server/latest/developer_manual/client_apis/OCS/ocs-taskprocessing-api.html#fetch-a-task-by-id
-	 *   If the response data contains nextOffset, not all messages could be handled in a single request.
-	 *   After receiving the response a second summary should be requested with the provided nextOffset.
+	 * 201: Summary was scheduled, use the returned taskId to get the status information and output from the TaskProcessing API: [OCS TaskProcessing API](https://docs.nextcloud.com/server/latest/developer_manual/client_apis/OCS/ocs-taskprocessing-api.html#fetch-a-task-by-id). If the response data contains nextOffset, not all messages could be handled in a single request. After receiving the response a second summary should be requested with the provided nextOffset.
 	 * 204: No messages found to summarize
 	 * 400: No AI provider available or summarizing failed
 	 */
@@ -569,7 +570,7 @@ class ChatController extends AEnvironmentAwareController {
 				continue;
 			}
 
-			$parsedMessage = $this->richToParsed(
+			$parsedMessage = $this->richTextFormatter->richToParsed(
 				$message->getMessage(),
 				$message->getMessageParameters(),
 			);
@@ -594,7 +595,7 @@ class ChatController extends AEnvironmentAwareController {
 		}
 
 		if (empty($messages)) {
-			return new DataResponse([], Http::STATUS_NO_CONTENT);
+			return new DataResponse(null, Http::STATUS_NO_CONTENT);
 		}
 
 		$task = new Task(
@@ -633,25 +634,7 @@ class ChatController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * Function is copied from Nextcloud 31 \OCP\RichObjectStrings\IRichTextFormatter::richToParsed
-	 * @deprecated
-	 */
-	protected function richToParsed(string $message, array $parameters): string {
-		$placeholders = [];
-		$replacements = [];
-		foreach ($parameters as $placeholder => $parameter) {
-			$placeholders[] = '{' . $placeholder . '}';
-			$replacements[] = match($parameter['type']) {
-				'user' => '@' . $parameter['name'],
-				'file' => $parameter['path'] ?? $parameter['name'],
-				default => $parameter['name'],
-			};
-		}
-		return str_replace($placeholders, $replacements, $message);
-	}
-
-	/**
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_NOT_MODIFIED, TalkChatMessageWithParent[], array{X-Chat-Last-Common-Read?: numeric-string, X-Chat-Last-Given?: numeric-string}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 */
 	protected function prepareCommentsAsDataResponse(array $comments, int $lastCommonReadId = 0): DataResponse {
 		if (empty($comments)) {
@@ -666,7 +649,7 @@ class ChatController extends AEnvironmentAwareController {
 					return new DataResponse([], Http::STATUS_OK, $headers);
 				}
 			}
-			return new DataResponse([], Http::STATUS_NOT_MODIFIED);
+			return new DataResponse(null, Http::STATUS_NOT_MODIFIED);
 		}
 
 		$this->preloadShares($comments);
@@ -787,7 +770,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $messageId The focused message which should be in the "middle" of the returned context
 	 * @psalm-param non-negative-int $messageId
 	 * @param int<1, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMessageWithParent[], array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, array<empty>, array<empty>>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
 	 *
 	 * 200: Message context returned
 	 * 304: No messages
@@ -815,6 +798,12 @@ class ChatController extends AEnvironmentAwareController {
 		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
 	}
 
+	/**
+	 * @psalm-template T as list
+	 * @psalm-param T $messages
+	 * @param array $commentIdToIndex
+	 * @psalm-return T
+	 */
 	protected function loadSelfReactions(array $messages, array $commentIdToIndex): array {
 		// Get message ids with reactions
 		$messageIdsWithReactions = array_map(
@@ -842,7 +831,7 @@ class ChatController extends AEnvironmentAwareController {
 
 		// Inject the reactions self into the $messages array
 		foreach ($reactionsById as $messageId => $reactions) {
-			if (isset($commentIdToIndex[$messageId]) && isset($messages[$commentIdToIndex[$messageId]])) {
+			if (isset($commentIdToIndex[$messageId], $messages[$commentIdToIndex[$messageId]])) {
 				$messages[$commentIdToIndex[$messageId]]['reactionsSelf'] = $reactions;
 			}
 
@@ -856,6 +845,7 @@ class ChatController extends AEnvironmentAwareController {
 			}
 		}
 
+		/** @psalm-var T $messages */
 		return $messages;
 	}
 
@@ -864,7 +854,7 @@ class ChatController extends AEnvironmentAwareController {
 	 *
 	 * @param int $messageId ID of the message
 	 * @psalm-param non-negative-int $messageId
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST|Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED, array{error: string}, array{}>
 	 *
 	 * 200: Message deleted successfully
 	 * 202: Message deleted successfully, but a bot or Matterbridge is configured, so the information can be replicated elsewhere
@@ -892,8 +882,8 @@ class ChatController extends AEnvironmentAwareController {
 
 		try {
 			$message = $this->chatManager->getComment($this->room, (string)$messageId);
-		} catch (NotFoundException $e) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		} catch (NotFoundException) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
 		}
 
 		$attendee = $this->participant->getAttendee();
@@ -907,12 +897,12 @@ class ChatController extends AEnvironmentAwareController {
 				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE
 				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER)) {
 			// Actor is not a moderator or not the owner of the message
-			return new DataResponse([], Http::STATUS_FORBIDDEN);
+			return new DataResponse(['error' => 'permission'], Http::STATUS_FORBIDDEN);
 		}
 
 		if ($message->getVerb() !== ChatManager::VERB_MESSAGE && $message->getVerb() !== ChatManager::VERB_OBJECT_SHARED) {
 			// System message (since the message is not parsed, it has type "system")
-			return new DataResponse([], Http::STATUS_METHOD_NOT_ALLOWED);
+			return new DataResponse(['error' => 'message'], Http::STATUS_METHOD_NOT_ALLOWED);
 		}
 
 		try {
@@ -922,8 +912,8 @@ class ChatController extends AEnvironmentAwareController {
 				$this->participant,
 				$this->timeFactory->getDateTime()
 			);
-		} catch (ShareNotFound $e) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		} catch (ShareNotFound) {
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
 		}
 
 		$systemMessage = $this->messageParser->createMessage($this->room, $this->participant, $systemMessageComment, $this->l);
@@ -955,7 +945,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $messageId ID of the message
 	 * @param string $message the message to send
 	 * @psalm-param non-negative-int $messageId
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessageWithParent, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_BAD_REQUEST, array{error: string}, array{}>|DataResponse<Http::STATUS_FORBIDDEN|Http::STATUS_NOT_FOUND|Http::STATUS_METHOD_NOT_ALLOWED|Http::STATUS_REQUEST_ENTITY_TOO_LARGE, array{error: string}, array{}>
 	 *
 	 * 200: Message edited successfully
 	 * 202: Message edited successfully, but a bot or Matterbridge is configured, so the information can be replicated to other services
@@ -986,7 +976,7 @@ class ChatController extends AEnvironmentAwareController {
 		try {
 			$comment = $this->chatManager->getComment($this->room, (string)$messageId);
 		} catch (NotFoundException $e) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
+			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
 		}
 
 		$attendee = $this->participant->getAttendee();
@@ -995,17 +985,21 @@ class ChatController extends AEnvironmentAwareController {
 
 		// Special case for if the message is a bridged message, then the message is the bridge bot's message.
 		$isOwnMessage = $isOwnMessage || ($comment->getActorType() === Attendee::ACTOR_BRIDGED && $attendee->getActorId() === MatterbridgeManager::BRIDGE_BOT_USERID);
-		if (!$isOwnMessage
+		$isBotInOneToOne = $comment->getActorType() === Attendee::ACTOR_BOTS
+			&& str_starts_with($comment->getActorId(), Attendee::ACTOR_BOT_PREFIX)
+			&& ($this->room->getType() === Room::TYPE_ONE_TO_ONE
+				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER);
+		if (!($isOwnMessage || $isBotInOneToOne)
 			&& (!$this->participant->hasModeratorPermissions(false)
 				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE
 				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER)) {
 			// Actor is not a moderator or not the owner of the message
-			return new DataResponse([], Http::STATUS_FORBIDDEN);
+			return new DataResponse(['error' => 'permission'], Http::STATUS_FORBIDDEN);
 		}
 
 		if ($comment->getVerb() !== ChatManager::VERB_MESSAGE && $comment->getVerb() !== ChatManager::VERB_OBJECT_SHARED) {
 			// System message (since the message is not parsed, it has type "system")
-			return new DataResponse([], Http::STATUS_METHOD_NOT_ALLOWED);
+			return new DataResponse(['error' => 'message'], Http::STATUS_METHOD_NOT_ALLOWED);
 		}
 
 		if ($this->room->getType() !== Room::TYPE_NOTE_TO_SELF) {
@@ -1025,10 +1019,10 @@ class ChatController extends AEnvironmentAwareController {
 				$message
 			);
 		} catch (MessageTooLongException) {
-			return new DataResponse([], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
+			return new DataResponse(['error' => 'message'], Http::STATUS_REQUEST_ENTITY_TOO_LARGE);
 		} catch (\InvalidArgumentException $e) {
 			if ($e->getMessage() === 'object_share') {
-				return new DataResponse([], Http::STATUS_METHOD_NOT_ALLOWED);
+				return new DataResponse(['error' => 'message'], Http::STATUS_METHOD_NOT_ALLOWED);
 			}
 			return new DataResponse(['error' => $e->getMessage()], Http::STATUS_BAD_REQUEST);
 		}
@@ -1180,10 +1174,10 @@ class ChatController extends AEnvironmentAwareController {
 	/**
 	 * Clear the chat history
 	 *
-	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessage, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_FORBIDDEN, array<empty>, array{}>
+	 * @return DataResponse<Http::STATUS_OK|Http::STATUS_ACCEPTED, TalkChatMessage, array{X-Chat-Last-Common-Read?: numeric-string}>|DataResponse<Http::STATUS_FORBIDDEN, null, array{}>
 	 *
 	 * 200: History cleared successfully
-	 * 202: History cleared successfully, but Matterbridge is configured, so the information can be replicated elsewhere
+	 * 202: History cleared successfully, but Federation or Matterbridge is configured, so the information can be replicated elsewhere
 	 * 403: Missing permissions to clear history
 	 */
 	#[NoAdminRequired]
@@ -1191,11 +1185,16 @@ class ChatController extends AEnvironmentAwareController {
 	#[RequireReadWriteConversation]
 	public function clearHistory(): DataResponse {
 		$attendee = $this->participant->getAttendee();
-		if (!$this->participant->hasModeratorPermissions(false)
-				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE
-				|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
-			// Actor is not a moderator or not the owner of the message
-			return new DataResponse([], Http::STATUS_FORBIDDEN);
+		if (!$this->participant->hasModeratorPermissions(false)) {
+			// Actor is not a moderator
+			return new DataResponse(null, Http::STATUS_FORBIDDEN);
+		}
+
+		if (!$this->appConfig->getAppValueBool('delete_one_to_one_conversations')
+				&& ($this->room->getType() === Room::TYPE_ONE_TO_ONE
+					|| $this->room->getType() === Room::TYPE_ONE_TO_ONE_FORMER)) {
+			// Not allowed to purge one-to-one conversations
+			return new DataResponse(null, Http::STATUS_FORBIDDEN);
 		}
 
 		$systemMessageComment = $this->chatManager->clearHistory(
@@ -1332,7 +1331,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * Get objects that are shared in the room overview
 	 *
 	 * @param int<1, 20> $limit Maximum number of objects
-	 * @return DataResponse<Http::STATUS_OK, array<string, TalkChatMessage[]>, array{}>
+	 * @return DataResponse<Http::STATUS_OK, array<string, list<TalkChatMessage>>, array{}>
 	 *
 	 * 200: List of shared objects messages of each type returned
 	 */
@@ -1358,7 +1357,7 @@ class ChatController extends AEnvironmentAwareController {
 		// Get all attachments
 		foreach ($objectTypes as $objectType) {
 			$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, 0, $limit);
-			$messageIdsByType[$objectType] = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
+			$messageIdsByType[$objectType] = array_map(static fn (Attachment $attachment): string => (string)$attachment->getMessageId(), $attachments);
 		}
 
 		$messages = $this->getMessagesForRoom(array_merge(...array_values($messageIdsByType)));
@@ -1385,7 +1384,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param int $lastKnownMessageId ID of the last known message
 	 * @psalm-param non-negative-int $lastKnownMessageId
 	 * @param int<1, 200> $limit Maximum number of objects
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMessage[], array{X-Chat-Last-Given?: numeric-string}>
+	 * @return DataResponse<Http::STATUS_OK, array<string, TalkChatMessage>, array{X-Chat-Last-Given?: numeric-string}>
 	 *
 	 * 200: List of shared objects messages returned
 	 */
@@ -1399,7 +1398,6 @@ class ChatController extends AEnvironmentAwareController {
 		$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, $offset, $limit);
 		$messageIds = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
 
-		/** @var TalkChatMessage[] $messages */
 		$messages = $this->getMessagesForRoom($messageIds);
 
 		$headers = [];
@@ -1412,7 +1410,7 @@ class ChatController extends AEnvironmentAwareController {
 	}
 
 	/**
-	 * @return TalkChatMessage[]
+	 * @return array<string, TalkChatMessage>
 	 */
 	protected function getMessagesForRoom(array $messageIds): array {
 		$comments = $this->chatManager->getMessagesForRoomById($this->room, $messageIds);
@@ -1435,7 +1433,7 @@ class ChatController extends AEnvironmentAwareController {
 				continue;
 			}
 
-			$messages[(int)$comment->getId()] = $message->toArray($this->getResponseFormat());
+			$messages[$comment->getId()] = $message->toArray($this->getResponseFormat());
 		}
 
 		return $messages;
@@ -1447,7 +1445,7 @@ class ChatController extends AEnvironmentAwareController {
 	 * @param string $search Text to search for
 	 * @param int $limit Maximum number of results
 	 * @param bool $includeStatus Include the user statuses
-	 * @return DataResponse<Http::STATUS_OK, TalkChatMentionSuggestion[], array{}>
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMentionSuggestion>, array{}>
 	 *
 	 * 200: List of mention suggestions returned
 	 */
@@ -1503,8 +1501,8 @@ class ChatController extends AEnvironmentAwareController {
 
 	/**
 	 * @param array $results
-	 * @param IUserStatus[] $statuses
-	 * @return TalkChatMentionSuggestion[]
+	 * @param array<string, IUserStatus> $statuses
+	 * @return list<TalkChatMentionSuggestion>
 	 */
 	protected function prepareResultArray(array $results, array $statuses): array {
 		$output = [];
