@@ -11,7 +11,9 @@ namespace OCA\Talk\Dashboard;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Chat\MessageParser;
 use OCA\Talk\Config;
+use OCA\Talk\Events\BeforeRoomsFetchEvent;
 use OCA\Talk\Manager;
+use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\BreakoutRoom;
 use OCA\Talk\Model\Message;
 use OCA\Talk\Participant;
@@ -19,6 +21,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Service\ProxyCacheMessageService;
+use OCA\Talk\Webinary;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Dashboard\IAPIWidget;
@@ -31,6 +34,7 @@ use OCP\Dashboard\Model\WidgetButton;
 use OCP\Dashboard\Model\WidgetItem;
 use OCP\Dashboard\Model\WidgetItems;
 use OCP\Dashboard\Model\WidgetOptions;
+use OCP\EventDispatcher\IEventDispatcher;
 use OCP\IL10N;
 use OCP\IURLGenerator;
 use OCP\IUser;
@@ -50,6 +54,7 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 		protected MessageParser $messageParser,
 		protected ChatManager $chatManager,
 		protected ProxyCacheMessageService $pcmService,
+		protected IEventDispatcher $dispatcher,
 		protected ITimeFactory $timeFactory,
 	) {
 	}
@@ -95,7 +100,7 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 	}
 
 	/**
-	 * @return \OCP\Dashboard\Model\WidgetButton[]
+	 * @return list<WidgetButton>
 	 */
 	public function getWidgetButtons(string $userId): array {
 		$buttons = [];
@@ -129,6 +134,9 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 	}
 
 	public function getItems(string $userId, ?string $since = null, int $limit = 7): array {
+		$event = new BeforeRoomsFetchEvent($userId);
+		$this->dispatcher->dispatchTyped($event);
+
 		$rooms = $this->manager->getRoomsForUser($userId, [], true);
 
 		$rooms = array_filter($rooms, function (Room $room) use ($userId) {
@@ -136,13 +144,18 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 				return false;
 			}
 
-			if ($room->getCallFlag() !== Participant::FLAG_DISCONNECTED) {
-				return true;
-			}
-
 			$participant = $this->participantService->getParticipant($room, $userId);
 			$attendee = $participant->getAttendee();
 
+			if ($room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+				return false;
+			}
+
+			if (!$attendee->isArchived() && $room->getCallFlag() !== Participant::FLAG_DISCONNECTED) {
+				return true;
+			}
+
 			if (($room->isFederatedConversation() && $attendee->getLastMentionMessage())
 				|| (!$room->isFederatedConversation() && $attendee->getLastMentionMessage() > $attendee->getLastReadMessage())) {
 				return true;
@@ -169,6 +182,9 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 	 * @inheritDoc
 	 */
 	public function getItemsV2(string $userId, ?string $since = null, int $limit = 7): WidgetItems {
+		$event = new BeforeRoomsFetchEvent($userId);
+		$this->dispatcher->dispatchTyped($event);
+
 		$allRooms = $this->manager->getRoomsForUser($userId, [], true);
 
 		$rooms = [];
@@ -177,16 +193,25 @@ class TalkWidget implements IAPIWidget, IIconWidget, IButtonWidget, IOptionWidge
 			if ($room->getObjectType() === BreakoutRoom::PARENT_OBJECT_TYPE) {
 				continue;
 			}
-			$rooms[] = $room;
 
 			$participant = $this->participantService->getParticipant($room, $userId);
 			$attendee = $participant->getAttendee();
-			if ($room->getCallFlag() !== Participant::FLAG_DISCONNECTED) {
-				// Call in progress
-				$mentions[] = $room;
+
+			if ($room->getLobbyState() !== Webinary::LOBBY_NONE
+				&& !($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
 				continue;
 			}
 
+			if (!$attendee->isArchived()) {
+				$rooms[] = $room;
+
+				if ($room->getCallFlag() !== Participant::FLAG_DISCONNECTED) {
+					// Call in progress
+					$mentions[] = $room;
+					continue;
+				}
+			}
+
 			if (($room->isFederatedConversation() && $attendee->getLastMentionMessage())
 				|| (!$room->isFederatedConversation() && $attendee->getLastMentionMessage() > $attendee->getLastReadMessage())) {
 				// Really mentioned
