@@ -25,6 +25,7 @@ use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\Comments\ICommentsManager;
 use OCP\Comments\NotFoundException;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\ICache;
@@ -317,6 +318,30 @@ class Manager {
 		return $rooms;
 	}
 
+	/**
+	 * @return list<Room>
+	 */
+	public function getInactiveRooms(\DateTime $inactiveSince): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query);
+		$query->from('talk_rooms', 'r')
+			->andWhere($query->expr()->lte('r.last_activity', $query->createNamedParameter($inactiveSince, IQueryBuilder::PARAM_DATETIME_MUTABLE)))
+			->andWhere($query->expr()->neq('r.read_only', $query->createNamedParameter(Room::READ_ONLY, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->in('r.type', $query->createNamedParameter([Room::TYPE_PUBLIC, Room::TYPE_GROUP], IQueryBuilder::PARAM_INT_ARRAY)))
+			->andWhere($query->expr()->emptyString('remoteServer'))
+			->orderBy('r.id', 'ASC');
+		$result = $query->executeQuery();
+
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			$rooms[] = $this->createRoomObject($row);
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * @param string $userId
 	 * @param array $sessionIds A list of talk sessions to consider for loading (otherwise no session is loaded)
@@ -1082,9 +1107,10 @@ class Manager {
 	 * @param string $name
 	 * @param string $objectType
 	 * @param string $objectId
+	 * @param string $password
 	 * @return Room
 	 */
-	public function createRoom(int $type, string $name = '', string $objectType = '', string $objectId = ''): Room {
+	public function createRoom(int $type, string $name = '', string $objectType = '', string $objectId = '', string $password = ''): Room {
 		$token = $this->getNewToken();
 
 		$insert = $this->db->getQueryBuilder();
@@ -1094,6 +1120,7 @@ class Manager {
 					'name' => $insert->createNamedParameter($name),
 					'type' => $insert->createNamedParameter($type, IQueryBuilder::PARAM_INT),
 					'token' => $insert->createNamedParameter($token),
+					'password' => $insert->createNamedParameter($password),
 				]
 			);
 
@@ -1111,6 +1138,7 @@ class Manager {
 			'token' => $token,
 			'object_type' => $objectType,
 			'object_id' => $objectId,
+			'password' => $password
 		]);
 
 		$event = new RoomCreatedEvent($room);
@@ -1385,4 +1413,18 @@ class Manager {
 		$query->selectAlias('c.expire_date', 'comment_expire_date');
 		$query->selectAlias('c.meta_data', 'comment_meta_data');
 	}
+
+	/**
+	 * @param int $roomId
+	 * @param string $password
+	 * @throws Exception
+	 */
+	public function setPublic(int $roomId, string $password = ''): void {
+		$update = $this->db->getQueryBuilder();
+		$update->update('talk_rooms')
+			->set('type', $update->createNamedParameter(Room::TYPE_PUBLIC, IQueryBuilder::PARAM_INT))
+			->set('password', $update->createNamedParameter($password, IQueryBuilder::PARAM_STR))
+			->where($update->expr()->eq('id', $update->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)));
+		$update->executeStatement();
+	}
 }
