@@ -2,23 +2,8 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2020 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2020 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Model;
@@ -33,22 +18,15 @@ use OCP\IDBConnection;
 /**
  * @method Attendee mapRowToEntity(array $row)
  * @method Attendee findEntity(IQueryBuilder $query)
- * @method Attendee[] findEntities(IQueryBuilder $query)
+ * @method list<Attendee> findEntities(IQueryBuilder $query)
  * @template-extends QBMapper<Attendee>
  */
 class AttendeeMapper extends QBMapper {
-	/**
-	 * @param IDBConnection $db
-	 */
 	public function __construct(IDBConnection $db) {
 		parent::__construct($db, 'talk_attendees', Attendee::class);
 	}
 
 	/**
-	 * @param int $roomId
-	 * @param string $actorType
-	 * @param string $actorId
-	 * @return Attendee
 	 * @throws DoesNotExistException
 	 */
 	public function findByActor(int $roomId, string $actorType, string $actorId): Attendee {
@@ -63,11 +41,8 @@ class AttendeeMapper extends QBMapper {
 	}
 
 	/**
-	 * @param int $id
-	 * @return Attendee
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
-	 * @throws DBException
 	 */
 	public function getById(int $id): Attendee {
 		$query = $this->db->getQueryBuilder();
@@ -79,10 +54,20 @@ class AttendeeMapper extends QBMapper {
 	}
 
 	/**
-	 * @param int $id
-	 * @param string $token
-	 * @return Attendee
-	 * @throws DBException
+	 * @return list<Attendee>
+	 */
+	public function getByAccessToken(string $accessToken): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from($this->getTableName())
+			->where($query->expr()->eq('access_token', $query->createNamedParameter($accessToken)));
+		// There could be multiple in case of local federation,
+		// so we have to get all and afterwards check
+		// the actor id for the serverUrl.
+		return $this->findEntities($query);
+	}
+
+	/**
 	 * @throws DoesNotExistException
 	 * @throws MultipleObjectsReturnedException
 	 */
@@ -97,10 +82,7 @@ class AttendeeMapper extends QBMapper {
 	}
 
 	/**
-	 * @param int $roomId
-	 * @param string $actorType
-	 * @param int|null $lastJoinedCall
-	 * @return Attendee[]
+	 * @return list<Attendee>
 	 */
 	public function getActorsByType(int $roomId, string $actorType, ?int $lastJoinedCall = null): array {
 		$query = $this->db->getQueryBuilder();
@@ -117,9 +99,24 @@ class AttendeeMapper extends QBMapper {
 	}
 
 	/**
-	 * @param int $roomId
-	 * @param array $participantType
-	 * @return Attendee[]
+	 * @return list<Attendee>
+	 */
+	public function getActorsByTypes(int $roomId, array $actorTypes, ?int $lastJoinedCall = null): array {
+		$query = $this->db->getQueryBuilder();
+		$query->select('*')
+			->from($this->getTableName())
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->in('actor_type', $query->createNamedParameter($actorTypes, IQueryBuilder::PARAM_STR_ARRAY)));
+
+		if ($lastJoinedCall !== null) {
+			$query->andWhere($query->expr()->gte('last_joined_call', $query->createNamedParameter($lastJoinedCall, IQueryBuilder::PARAM_INT)));
+		}
+
+		return $this->findEntities($query);
+	}
+
+	/**
+	 * @return list<Attendee>
 	 * @throws DBException
 	 */
 	public function getActorsByParticipantTypes(int $roomId, array $participantType): array {
@@ -135,12 +132,6 @@ class AttendeeMapper extends QBMapper {
 		return $this->findEntities($query);
 	}
 
-	/**
-	 * @param int $roomId
-	 * @param string $actorType
-	 * @param int|null $lastJoinedCall
-	 * @return int
-	 */
 	public function getActorsCountByType(int $roomId, string $actorType, ?int $lastJoinedCall = null): int {
 		$query = $this->db->getQueryBuilder();
 		$query->select($query->func()->count('*', 'num_actors'))
@@ -153,16 +144,14 @@ class AttendeeMapper extends QBMapper {
 		}
 
 		$result = $query->executeQuery();
-		$count = (int) $result->fetchOne();
+		$count = (int)$result->fetchOne();
 		$result->closeCursor();
 
 		return $count;
 	}
 
 	/**
-	 * @param int $roomId
 	 * @param int[] $participantType
-	 * @return int
 	 */
 	public function countActorsByParticipantType(int $roomId, array $participantType): int {
 		$query = $this->db->getQueryBuilder();
@@ -182,7 +171,7 @@ class AttendeeMapper extends QBMapper {
 		$row = $result->fetch();
 		$result->closeCursor();
 
-		return (int) ($row['num_actors'] ?? 0);
+		return (int)($row['num_actors'] ?? 0);
 	}
 
 	/**
@@ -194,22 +183,16 @@ class AttendeeMapper extends QBMapper {
 		$delete->delete($this->getTableName())
 			->where($delete->expr()->in('id', $delete->createNamedParameter($ids, IQueryBuilder::PARAM_INT_ARRAY)));
 
-		return (int) $delete->executeStatement();
+		return $delete->executeStatement();
 	}
 
 	public function modifyPermissions(int $roomId, string $mode, int $newState): void {
-		$query = $this->db->getQueryBuilder();
-		$query->update($this->getTableName())
-			->where($query->expr()->eq('room_id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)))
-			->andWhere($query->expr()->notIn('actor_type', $query->createNamedParameter([
-				Attendee::ACTOR_CIRCLES,
-				Attendee::ACTOR_GROUPS,
-			], IQueryBuilder::PARAM_STR_ARRAY)));
-
 		if ($mode === Attendee::PERMISSIONS_MODIFY_SET) {
 			if ($newState !== Attendee::PERMISSIONS_DEFAULT) {
 				$newState |= Attendee::PERMISSIONS_CUSTOM;
 			}
+
+			$query = $this->getModifyPermissionsBaseQuery($roomId);
 			$query->set('permissions', $query->createNamedParameter($newState, IQueryBuilder::PARAM_INT));
 			$query->executeStatement();
 		} else {
@@ -222,6 +205,8 @@ class AttendeeMapper extends QBMapper {
 				Attendee::PERMISSIONS_LOBBY_IGNORE,
 			] as $permission) {
 				if ($permission & $newState) {
+					$query = $this->getModifyPermissionsBaseQuery($roomId);
+
 					if ($mode === Attendee::PERMISSIONS_MODIFY_ADD) {
 						$this->addSinglePermission($query, $permission);
 					} elseif ($mode === Attendee::PERMISSIONS_MODIFY_REMOVE) {
@@ -232,6 +217,18 @@ class AttendeeMapper extends QBMapper {
 		}
 	}
 
+	protected function getModifyPermissionsBaseQuery(int $roomId): IQueryBuilder {
+		$query = $this->db->getQueryBuilder();
+		$query->update($this->getTableName())
+			->where($query->expr()->eq('room_id', $query->createNamedParameter($roomId, IQueryBuilder::PARAM_INT)))
+			->andWhere($query->expr()->notIn('actor_type', $query->createNamedParameter([
+				Attendee::ACTOR_CIRCLES,
+				Attendee::ACTOR_GROUPS,
+			], IQueryBuilder::PARAM_STR_ARRAY)));
+
+		return $query;
+	}
+
 	protected function addSinglePermission(IQueryBuilder $query, int $permission): void {
 		$query->set('permissions', $query->func()->add(
 			'permissions',
@@ -250,6 +247,12 @@ class AttendeeMapper extends QBMapper {
 				$query->createNamedParameter($permission, IQueryBuilder::PARAM_INT)
 			)
 		);
+		$query->andWhere(
+			$query->expr()->neq(
+				'permissions',
+				$query->createNamedParameter(Attendee::PERMISSIONS_DEFAULT, IQueryBuilder::PARAM_INT)
+			)
+		);
 
 		$query->executeStatement();
 	}
@@ -272,6 +275,9 @@ class AttendeeMapper extends QBMapper {
 				$query->createNamedParameter($permission, IQueryBuilder::PARAM_INT)
 			)
 		);
+		// Removing permissions does not need to be explicitly prevented when
+		// the attendee has default permissions, as in that case it will not be
+		// possible to remove the permissions anyway.
 
 		$query->executeStatement();
 	}
@@ -282,20 +288,27 @@ class AttendeeMapper extends QBMapper {
 			'room_id' => $row['room_id'],
 			'actor_type' => $row['actor_type'],
 			'actor_id' => $row['actor_id'],
-			'display_name' => (string) $row['display_name'],
+			'display_name' => (string)$row['display_name'],
 			'pin' => $row['pin'],
-			'participant_type' => (int) $row['participant_type'],
-			'favorite' => (bool) $row['favorite'],
-			'notification_level' => (int) $row['notification_level'],
-			'notification_calls' => (int) $row['notification_calls'],
-			'last_joined_call' => (int) $row['last_joined_call'],
-			'last_read_message' => (int) $row['last_read_message'],
-			'last_mention_message' => (int) $row['last_mention_message'],
-			'last_mention_direct' => (int) $row['last_mention_direct'],
-			'read_privacy' => (int) $row['read_privacy'],
-			'permissions' => (int) $row['permissions'],
-			'access_token' => (string) $row['access_token'],
-			'remote_id' => (string) $row['remote_id'],
+			'participant_type' => (int)$row['participant_type'],
+			'favorite' => (bool)$row['favorite'],
+			'notification_level' => (int)$row['notification_level'],
+			'notification_calls' => (int)$row['notification_calls'],
+			'last_joined_call' => (int)$row['last_joined_call'],
+			'last_read_message' => (int)$row['last_read_message'],
+			'last_mention_message' => (int)$row['last_mention_message'],
+			'last_mention_direct' => (int)$row['last_mention_direct'],
+			'read_privacy' => (int)$row['read_privacy'],
+			'permissions' => (int)$row['permissions'],
+			'access_token' => (string)$row['access_token'],
+			'remote_id' => (string)$row['remote_id'],
+			'invited_cloud_id' => (string)$row['invited_cloud_id'],
+			'phone_number' => $row['phone_number'],
+			'call_id' => $row['call_id'],
+			'state' => (int)$row['state'],
+			'unread_messages' => (int)$row['unread_messages'],
+			'last_attendee_activity' => (int)$row['last_attendee_activity'],
+			'archived' => (bool)$row['archived'],
 		]);
 	}
 }
