@@ -8,6 +8,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Notification;
 
+use OCA\Circles\CirclesManager;
 use OCA\FederatedFileSharing\AddressHandler;
 use OCA\Talk\AppInfo\Application;
 use OCA\Talk\Chat\ChatManager;
@@ -28,6 +29,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Service\AvatarService;
 use OCA\Talk\Service\ParticipantService;
 use OCA\Talk\Webinary;
+use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\ICommentsManager;
@@ -47,9 +49,11 @@ use OCP\Notification\INotification;
 use OCP\Notification\INotifier;
 use OCP\Notification\UnknownNotificationException;
 use OCP\RichObjectStrings\Definitions;
+use OCP\Server;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager as IShareManager;
 use OCP\Share\IShare;
+use Psr\Log\LoggerInterface;
 
 class Notifier implements INotifier {
 
@@ -57,12 +61,17 @@ class Notifier implements INotifier {
 	protected array $rooms = [];
 	/** @var Participant[][] */
 	protected array $participants = [];
+	/** @var array<string, string> */
+	protected array $circleNames = [];
+	/** @var array<string, string> */
+	protected array $circleLinks = [];
 	protected ICommentsManager $commentManager;
 
 	public function __construct(
 		protected IFactory $lFactory,
 		protected IURLGenerator $url,
 		protected Config $config,
+		protected IAppManager $appManager,
 		protected IUserManager $userManager,
 		protected IGroupManager $groupManager,
 		protected GuestManager $guestManager,
@@ -81,6 +90,7 @@ class Notifier implements INotifier {
 		protected BotServerMapper $botServerMapper,
 		protected FederationManager $federationManager,
 		protected ICloudIdManager $cloudIdManager,
+		protected LoggerInterface $logger,
 	) {
 		$this->commentManager = $commentManager;
 	}
@@ -262,7 +272,7 @@ class Notifier implements INotifier {
 			}
 			return $this->parseCall($notification, $room, $l);
 		}
-		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction' || $subject === 'reminder') {
+		if ($subject === 'reply' || $subject === 'mention' || $subject === 'mention_direct' || $subject === 'mention_group' || $subject === 'mention_team' || $subject === 'mention_all' || $subject === 'chat' || $subject === 'reaction' || $subject === 'reminder') {
 			if ($participant instanceof Participant &&
 				$room->getLobbyState() !== Webinary::LOBBY_NONE &&
 				!($participant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
@@ -395,7 +405,7 @@ class Notifier implements INotifier {
 					],
 				]);
 
-		if ($notification->getSubject() !== 'transcript_failed') {
+		if ($notification->getSubject() !== 'transcript_failed' && $notification->getSubject() !== 'summary_failed') {
 			$notification->addParsedAction($shareAction);
 			$notification->addParsedAction($dismissAction);
 		}
@@ -501,7 +511,13 @@ class Notifier implements INotifier {
 
 			try {
 				$comment = $this->commentManager->get($messageParameters['commentId']);
-			} catch (NotFoundException $e) {
+			} catch (NotFoundException) {
+				throw new AlreadyProcessedException();
+			}
+
+			if ($comment->getObjectType() !== 'chat'
+				|| $room->getId() !== (int)$comment->getObjectId()) {
+				$this->logger->warning('Ignoring ' . $notification->getSubject() . ' notification for user ' . $notification->getUser() . ' as messages #' . $comment->getId() . ' could not be found for conversation ' . $room->getToken());
 				throw new AlreadyProcessedException();
 			}
 
@@ -774,6 +790,9 @@ class Notifier implements INotifier {
 				];
 
 				$subject = $l->t('{user} mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_team') {
+				$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+				$subject = $l->t('{user} mentioned team {team} in conversation {call}');
 			} elseif ($notification->getSubject() === 'mention_all') {
 				$subject = $l->t('{user} mentioned everyone in conversation {call}');
 			} else {
@@ -789,6 +808,9 @@ class Notifier implements INotifier {
 				];
 
 				$subject = $l->t('A deleted user mentioned group {group} in conversation {call}');
+			} elseif ($notification->getSubject() === 'mention_team') {
+				$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+				$subject = $l->t('A deleted user mentioned team {team} in conversation {call}');
 			} elseif ($notification->getSubject() === 'mention_all') {
 				$subject = $l->t('A deleted user mentioned everyone in conversation {call}');
 			} else {
@@ -806,6 +828,9 @@ class Notifier implements INotifier {
 					];
 
 					$subject = $l->t('{guest} (guest) mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_team') {
+					$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+					$subject = $l->t('{guest} (guest) mentioned team {team} in conversation {call}');
 				} elseif ($notification->getSubject() === 'mention_all') {
 					$subject = $l->t('{guest} (guest) mentioned everyone in conversation {call}');
 				} else {
@@ -821,6 +846,9 @@ class Notifier implements INotifier {
 					];
 
 					$subject = $l->t('A guest mentioned group {group} in conversation {call}');
+				} elseif ($notification->getSubject() === 'mention_team') {
+					$richSubjectParameters['team'] = $this->getCircle($subjectParameters['sourceId']);
+					$subject = $l->t('A guest mentioned team {team} in conversation {call}');
 				} elseif ($notification->getSubject() === 'mention_all') {
 					$subject = $l->t('A guest mentioned everyone in conversation {call}');
 				} else {
@@ -1247,4 +1275,47 @@ class Notifier implements INotifier {
 
 		return $notification;
 	}
+
+	protected function getCircle(string $circleId): array {
+		if (!$this->appManager->isEnabledForUser('circles')) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			$this->loadCircleDetails($circleId);
+		}
+
+		if (!isset($this->circleNames[$circleId])) {
+			return [
+				'type' => 'highlight',
+				'id' => $circleId,
+				'name' => $circleId,
+			];
+		}
+
+		return [
+			'type' => 'circle',
+			'id' => $circleId,
+			'name' => $this->circleNames[$circleId],
+			'link' => $this->circleLinks[$circleId],
+		];
+	}
+
+	protected function loadCircleDetails(string $circleId): void {
+		try {
+			$circlesManager = Server::get(CirclesManager::class);
+			$circlesManager->startSuperSession();
+			$circle = $circlesManager->getCircle($circleId);
+
+			$this->circleNames[$circleId] = $circle->getDisplayName();
+			$this->circleLinks[$circleId] = $circle->getUrl();
+		} catch (\Exception) {
+		} finally {
+			$circlesManager?->stopSession();
+		}
+	}
 }
