@@ -14,6 +14,7 @@ use OCA\Circles\Model\Member;
 use OCA\Talk\CachePrefix;
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Config;
+use OCA\Talk\Controller\CallNotificationController;
 use OCA\Talk\Events\AAttendeeRemovedEvent;
 use OCA\Talk\Events\AParticipantModifiedEvent;
 use OCA\Talk\Events\AttendeeRemovedEvent;
@@ -39,9 +40,9 @@ use OCA\Talk\Events\SystemMessagesMultipleSentEvent;
 use OCA\Talk\Events\UserJoinedRoomEvent;
 use OCA\Talk\Exceptions\CannotReachRemoteException;
 use OCA\Talk\Exceptions\DialOutFailedException;
-use OCA\Talk\Exceptions\ForbiddenException;
 use OCA\Talk\Exceptions\InvalidPasswordException;
 use OCA\Talk\Exceptions\ParticipantNotFoundException;
+use OCA\Talk\Exceptions\ParticipantProperty\PermissionsException;
 use OCA\Talk\Exceptions\UnauthorizedException;
 use OCA\Talk\Federation\BackendNotifier;
 use OCA\Talk\Federation\FederationManager;
@@ -139,7 +140,7 @@ class ParticipantService {
 		$attendee->setLastAttendeeActivity($this->timeFactory->getTime());
 		$this->attendeeMapper->update($attendee);
 
-		// XOR so we don't move the participant in and out when they are changed from moderator to owner or vice-versa
+		// XOR so we don't move the participant in and out when they are changed from moderator to owner or vice versa
 		if (($promotedToModerator xor $demotedFromModerator) && $room->getBreakoutRoomMode() !== BreakoutRoom::MODE_NOT_CONFIGURED) {
 			/** @var Manager $manager */
 			$manager = Server::get(Manager::class);
@@ -184,23 +185,26 @@ class ParticipantService {
 	}
 
 	/**
-	 * @throws Exception
-	 * @throws ForbiddenException
+	 * @throws PermissionsException
 	 */
-	public function updatePermissions(Room $room, Participant $participant, string $method, int $newPermissions): bool {
+	public function updatePermissions(Room $room, Participant $participant, string $method, int $newPermissions): void {
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE || $room->getType() === Room::TYPE_ONE_TO_ONE_FORMER) {
-			return false;
+			throw new PermissionsException(PermissionsException::REASON_ROOM_TYPE);
 		}
 
 		if ($participant->hasModeratorPermissions()) {
-			throw new ForbiddenException();
+			throw new PermissionsException(PermissionsException::REASON_MODERATOR);
 		}
 
 		$attendee = $participant->getAttendee();
 
 		if ($attendee->getActorType() === Attendee::ACTOR_GROUPS || $attendee->getActorType() === Attendee::ACTOR_CIRCLES) {
 			// Can not set publishing permissions for those actor types
-			return false;
+			throw new PermissionsException(PermissionsException::REASON_TYPE);
+		}
+
+		if ($newPermissions < Attendee::PERMISSIONS_DEFAULT || $newPermissions > Attendee::PERMISSIONS_MAX_CUSTOM) {
+			throw new PermissionsException(PermissionsException::REASON_VALUE);
 		}
 
 		$oldPermissions = $participant->getPermissions();
@@ -214,7 +218,7 @@ class ParticipantService {
 		} elseif ($method === Attendee::PERMISSIONS_MODIFY_REMOVE) {
 			$newPermissions = $oldPermissions & ~$newPermissions;
 		} else {
-			return false;
+			throw new PermissionsException(PermissionsException::REASON_METHOD);
 		}
 
 		$event = new BeforeParticipantModifiedEvent($room, $participant, AParticipantModifiedEvent::PROPERTY_PERMISSIONS, $newPermissions, $oldPermissions);
@@ -229,8 +233,6 @@ class ParticipantService {
 
 		$event = new ParticipantModifiedEvent($room, $participant, AParticipantModifiedEvent::PROPERTY_PERMISSIONS, $newPermissions, $oldPermissions);
 		$this->dispatcher->dispatchTyped($event);
-
-		return true;
 	}
 
 	public function updateAllPermissions(Room $room, string $method, int $newState): void {
@@ -272,7 +274,7 @@ class ParticipantService {
 			Participant::NOTIFY_MENTION,
 			Participant::NOTIFY_NEVER
 		], true)) {
-			throw new \InvalidArgumentException('Invalid notification level');
+			throw new \InvalidArgumentException('level');
 		}
 
 		$attendee = $participant->getAttendee();
@@ -284,13 +286,14 @@ class ParticipantService {
 	/**
 	 * @param Participant $participant
 	 * @param int $level
+	 * @throws \InvalidArgumentException
 	 */
 	public function updateNotificationCalls(Participant $participant, int $level): void {
 		if (!\in_array($level, [
 			Participant::NOTIFY_CALLS_OFF,
 			Participant::NOTIFY_CALLS_ON,
 		], true)) {
-			throw new \InvalidArgumentException('Invalid notification level');
+			throw new \InvalidArgumentException('level');
 		}
 
 		$attendee = $participant->getAttendee();
@@ -716,16 +719,43 @@ class ParticipantService {
 
 		$circlesManager->startSession($federatedUser);
 		try {
-			$circle = $circlesManager->getCircle($circleId);
-			$circlesManager->stopSession();
-			return $circle;
+			return $circlesManager->getCircle($circleId);
 		} catch (\Exception $e) {
+		} finally {
+			$circlesManager->stopSession();
 		}
 
-		$circlesManager->stopSession();
 		throw new ParticipantNotFoundException('Circle not found or not a member');
 	}
 
+	/**
+	 * @param string $circleId
+	 * @param string $userId
+	 * @return Member[]
+	 * @throws ParticipantNotFoundException
+	 */
+	public function getCircleMembers(string $circleId): array {
+		try {
+			$circlesManager = Server::get(CirclesManager::class);
+		} catch (\Exception) {
+			throw new ParticipantNotFoundException('Circle not found');
+		}
+
+		$circlesManager->startSuperSession();
+		try {
+			$circle = $circlesManager->getCircle($circleId);
+		} catch (\Exception) {
+			throw new ParticipantNotFoundException('Circle not found');
+		} finally {
+			$circlesManager->stopSession();
+		}
+
+		$members = $circle->getInheritedMembers();
+		return array_filter($members, static function (Member $member) {
+			return $member->getUserType() === Member::TYPE_USER;
+		});
+	}
+
 	/**
 	 * @param Room $room
 	 * @param Circle $circle
@@ -977,10 +1007,10 @@ class ParticipantService {
 				$participant = $this->getParticipant($room, $user->getUID());
 				$participantType = $participant->getAttendee()->getParticipantType();
 
-				$attendees[] = $participant->getAttendee();
 				if ($participantType === Participant::USER) {
 					// Only remove normal users, not moderators/admins
 					$this->removeAttendee($room, $participant, $reason, true);
+					$attendees[] = $participant->getAttendee();
 				}
 			} catch (ParticipantNotFoundException $e) {
 			}
@@ -1040,10 +1070,10 @@ class ParticipantService {
 				$participant = $this->getParticipant($room, $user->getUID());
 				$participantType = $participant->getAttendee()->getParticipantType();
 
-				$attendees[] = $participant->getAttendee();
 				if ($participantType === Participant::USER) {
 					// Only remove normal users, not moderators/admins
 					$this->removeAttendee($room, $participant, $reason, true);
+					$attendees[] = $participant->getAttendee();
 				}
 			} catch (ParticipantNotFoundException $e) {
 			}
@@ -1599,6 +1629,72 @@ class ParticipantService {
 		return $this->getParticipantsFromQuery($query, $room);
 	}
 
+	/**
+	 * Do not try to modernize this into using the Room, Participant or other objects.
+	 * This function is called by {@see CallNotificationController::state}
+	 * and mobile as well as desktop clients are basically ddos-ing it, to check
+	 * if the call notification / call screen should be removed.
+	 * @return CallNotificationController::CASE_*
+	 */
+	public function checkIfUserIsMissingCall(string $token, string $userId): int {
+		$query = $this->connection->getQueryBuilder();
+		$query->select('r.active_since', 'a.last_joined_call', 's.in_call')
+			->from('talk_rooms', 'r')
+			->innerJoin(
+				'r', 'talk_attendees', 'a',
+				$query->expr()->eq('r.id', 'a.room_id')
+			)
+			->leftJoin(
+				'a', 'talk_sessions', 's',
+				$query->expr()->andX(
+					$query->expr()->eq('s.attendee_id', 'a.id'),
+					$query->expr()->neq('s.in_call', $query->createNamedParameter(Participant::FLAG_DISCONNECTED, IQueryBuilder::PARAM_INT), IQueryBuilder::PARAM_INT),
+				)
+			)
+			->where($query->expr()->eq('r.token', $query->createNamedParameter($token)))
+			->andWhere($query->expr()->eq('a.actor_type', $query->createNamedParameter(Attendee::ACTOR_USERS)))
+			->andWhere($query->expr()->eq('a.actor_id', $query->createNamedParameter($userId)));
+
+		$result = $query->executeQuery();
+		$row = $result->fetch();
+		$result->closeCursor();
+
+		if ($row === false) {
+			return CallNotificationController::CASE_ROOM_NOT_FOUND;
+		}
+
+		if ($row['active_since'] === null) {
+			return CallNotificationController::CASE_MISSED_CALL;
+		}
+
+		try {
+			$activeSince = new \DateTime($row['active_since']);
+		} catch (\Throwable) {
+			return CallNotificationController::CASE_MISSED_CALL;
+		}
+
+		if ($row['in_call'] !== null) {
+			return CallNotificationController::CASE_PARTICIPANT_JOINED;
+		}
+
+		if ($activeSince->getTimestamp() >= $row['last_joined_call']) {
+			return CallNotificationController::CASE_STILL_CURRENT;
+		}
+
+		// The participant had joined the call, but left again.
+		// In this case we should not ring any more, but clients stop
+		// pinging the endpoint 45s after receiving the push anyway.
+		// However, it is also possible that the participant was ringed
+		// again by a moderator after they had joined the call before.
+		// So if a client pings the endpoint after 45s initial ringing
+		// + 15 seconds for worst case push notification delay, we will
+		// again tell them to show the call notification.
+		if (($activeSince->getTimestamp() + 45 + 15) < $this->timeFactory->getTime()) {
+			return CallNotificationController::CASE_STILL_CURRENT;
+		}
+		return CallNotificationController::CASE_PARTICIPANT_JOINED;
+	}
+
 	/**
 	 * @return Participant[]
 	 */
