@@ -20,6 +20,7 @@ use OCA\Talk\Room;
 use OCA\Talk\Webinary;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
+use OCP\AppFramework\Services\IAppConfig;
 use OCP\AppFramework\Utility\ITimeFactory;
 use OCP\Comments\IComment;
 use OCP\IConfig;
@@ -36,6 +37,7 @@ use OCP\UserStatus\IUserStatus;
 class RoomFormatter {
 	public function __construct(
 		protected Config $talkConfig,
+		protected IAppConfig $appConfig,
 		protected AvatarService $avatarService,
 		protected ParticipantService $participantService,
 		protected ChatManager $chatManager,
@@ -118,7 +120,6 @@ class RoomFormatter {
 			'lobbyTimer' => 0,
 			'lastPing' => 0,
 			'sessionId' => '0',
-			'lastMessage' => [],
 			'sipEnabled' => Webinary::SIP_DISABLED,
 			'actorType' => '',
 			'actorId' => '',
@@ -273,17 +274,6 @@ class RoomFormatter {
 			}
 		}
 
-		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
-			!$currentParticipant->hasModeratorPermissions() &&
-			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
-			// No participants and chat messages for users in the lobby.
-			$roomData['hasCall'] = false;
-			$roomData['canLeaveConversation'] = true;
-			return $roomData;
-		}
-
-		$roomData['canStartCall'] = $currentParticipant->canStartCall($this->serverConfig);
-
 		$currentUser = null;
 		if ($attendee->getActorType() === Attendee::ACTOR_USERS) {
 			$currentUser = $this->userManager->get($attendee->getActorId());
@@ -321,6 +311,13 @@ class RoomFormatter {
 					&& $room->getType() !== Room::TYPE_ONE_TO_ONE_FORMER
 					&& $currentParticipant->hasModeratorPermissions(false);
 				$roomData['canLeaveConversation'] = $room->getType() !== Room::TYPE_NOTE_TO_SELF;
+
+				if ($this->appConfig->getAppValueBool('delete_one_to_one_conversations')
+					&& in_array($room->getType(), [Room::TYPE_ONE_TO_ONE, Room::TYPE_ONE_TO_ONE_FORMER], true)) {
+					$roomData['canDeleteConversation'] = true;
+					$roomData['canLeaveConversation'] = false;
+				}
+
 				$roomData['canEnableSIP'] =
 					$this->talkConfig->isSIPConfigured()
 					&& !preg_match(Room::SIP_INCOMPATIBLE_REGEX, $room->getToken())
@@ -348,6 +345,19 @@ class RoomFormatter {
 			$roomData['remoteToken'] = $room->getRemoteToken();
 		}
 
+		if ($room->getLobbyState() === Webinary::LOBBY_NON_MODERATORS &&
+			!$currentParticipant->hasModeratorPermissions() &&
+			!($currentParticipant->getPermissions() & Attendee::PERMISSIONS_LOBBY_IGNORE)) {
+			// No participants and chat messages for users in the lobby.
+			$roomData['hasCall'] = false;
+			$roomData['unreadMessages'] = 0;
+			$roomData['unreadMention'] = false;
+			$roomData['unreadMentionDirect'] = false;
+			return $roomData;
+		}
+
+		$roomData['canStartCall'] = $currentParticipant->canStartCall($this->serverConfig);
+
 		// FIXME This should not be done, but currently all the clients use it to get the avatar of the user …
 		if ($room->getType() === Room::TYPE_ONE_TO_ONE) {
 			$participants = json_decode($room->getName(), true);
@@ -376,15 +386,17 @@ class RoomFormatter {
 			}
 		}
 
-		$roomData['lastMessage'] = [];
 		$lastMessage = $room->getLastMessage();
 		if (!$room->isFederatedConversation() && $lastMessage instanceof IComment) {
-			$roomData['lastMessage'] = $this->formatLastMessage(
+			$lastMessageData = $this->formatLastMessage(
 				$responseFormat,
 				$room,
 				$currentParticipant,
 				$lastMessage,
 			);
+			if ($lastMessageData !== null) {
+				$roomData['lastMessage'] = $lastMessageData;
+			}
 		} elseif ($room->isFederatedConversation()) {
 			$roomData['lastCommonReadMessage'] = 0;
 			try {
@@ -414,25 +426,25 @@ class RoomFormatter {
 	}
 
 	/**
-	 * @return TalkRoomLastMessage|array<empty>
+	 * @return TalkRoomLastMessage|null
 	 */
 	public function formatLastMessage(
 		string $responseFormat,
 		Room $room,
 		Participant $participant,
 		IComment $lastMessage,
-	): array {
+	): ?array {
 		$message = $this->messageParser->createMessage($room, $participant, $lastMessage, $this->l10n);
 		$this->messageParser->parseMessage($message);
 
 		if (!$message->getVisibility()) {
-			return [];
+			return null;
 		}
 
 		$now = $this->timeFactory->getDateTime();
 		$expireDate = $message->getComment()->getExpireDate();
 		if ($expireDate instanceof \DateTime && $expireDate < $now) {
-			return [];
+			return null;
 		}
 
 		return $message->toArray($responseFormat);
